@@ -1,23 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
- *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
- *  Author: Guillaume Roguez <Guillaume.Roguez@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #include <vector>
 #include <cstring>
@@ -54,9 +49,7 @@ placeCall(const std::string& accountId, const std::string& to)
 }
 
 std::string
-placeCallWithMedia(const std::string& accountId,
-                   const std::string& to,
-                   const std::vector<libjami::MediaMap>& mediaList)
+placeCallWithMedia(const std::string& accountId, const std::string& to, const std::vector<libjami::MediaMap>& mediaList)
 {
     // Check if a destination number is available
     if (to.empty()) {
@@ -91,15 +84,13 @@ refuse(const std::string& accountId, const std::string& callId)
 bool
 accept(const std::string& accountId, const std::string& callId)
 {
-    return jami::Manager::instance().answerCall(accountId, callId);
+    return jami::Manager::instance().acceptCall(accountId, callId);
 }
 
 bool
-acceptWithMedia(const std::string& accountId,
-                const std::string& callId,
-                const std::vector<libjami::MediaMap>& mediaList)
+acceptWithMedia(const std::string& accountId, const std::string& callId, const std::vector<libjami::MediaMap>& mediaList)
 {
-    return jami::Manager::instance().answerCall(accountId, callId, mediaList);
+    return jami::Manager::instance().acceptCall(accountId, callId, mediaList);
 }
 
 bool
@@ -144,10 +135,7 @@ unhold(const std::string& accountId, const std::string& callId)
 }
 
 bool
-muteLocalMedia(const std::string& accountId,
-               const std::string& callId,
-               const std::string& mediaType,
-               bool mute)
+muteLocalMedia(const std::string& accountId, const std::string& callId, const std::string& mediaType, bool mute)
 {
     if (auto account = jami::Manager::instance().getAccount(accountId)) {
         if (auto call = account->getCall(callId)) {
@@ -172,9 +160,7 @@ transfer(const std::string& accountId, const std::string& callId, const std::str
 }
 
 bool
-attendedTransfer(const std::string& accountId,
-                 const std::string& transferID,
-                 const std::string& targetID)
+attendedTransfer(const std::string& accountId, const std::string& transferID, const std::string& targetID)
 {
     if (auto account = jami::Manager::instance().getAccount(accountId))
         if (auto call = account->getCall(transferID))
@@ -192,8 +178,7 @@ joinParticipant(const std::string& accountId,
 }
 
 void
-createConfFromParticipantList(const std::string& accountId,
-                              const std::vector<std::string>& participants)
+createConfFromParticipantList(const std::string& accountId, const std::vector<std::string>& participants)
 {
     jami::Manager::instance().createConfFromParticipantList(accountId, participants);
 }
@@ -239,7 +224,7 @@ addParticipant(const std::string& accountId,
                const std::string& account2Id,
                const std::string& confId)
 {
-    return jami::Manager::instance().addParticipant(accountId, callId, account2Id, confId);
+    return jami::Manager::instance().addSubCall(accountId, callId, account2Id, confId);
 }
 
 bool
@@ -251,7 +236,7 @@ addMainParticipant(const std::string& accountId, const std::string& confId)
 bool
 detachLocalParticipant()
 {
-    return jami::Manager::instance().detachLocalParticipant();
+    return jami::Manager::instance().detachHost();
 }
 
 bool
@@ -272,14 +257,6 @@ joinConference(const std::string& accountId,
 bool
 holdConference(const std::string& accountId, const std::string& confId)
 {
-    /*
-    if (const auto account = jami::Manager::instance().getAccount(accountId))
-        if (auto conf = account->getConference(confId)) {
-            conf->detach();
-            jami::emitSignal<libjami::CallSignal::ConferenceChanged>(conf->getConfId(),
-    conf->getStateStr()); return true;
-        }
-    return false;*/
     return jami::Manager::instance().holdConference(accountId, confId);
 }
 
@@ -330,8 +307,8 @@ getParticipantList(const std::string& accountId, const std::string& confId)
 {
     if (const auto account = jami::Manager::instance().getAccount(accountId))
         if (auto conf = account->getConference(confId)) {
-            const auto& participants(conf->getParticipantList());
-            return {participants.begin(), participants.end()};
+            const auto& subcalls(conf->getSubCalls());
+            return {subcalls.begin(), subcalls.end()};
         }
     return {};
 }
@@ -465,9 +442,7 @@ switchInput(const std::string& accountId, const std::string& callId, const std::
 }
 
 bool
-switchSecondaryInput(const std::string& accountId,
-                     const std::string& confId,
-                     const std::string& resource)
+switchSecondaryInput(const std::string& accountId, const std::string& confId, const std::string& resource)
 {
     JAMI_ERR("Use requestMediaChange");
     return false;
@@ -486,29 +461,21 @@ sendTextMessage(const std::string& accountId,
 }
 
 void
-setModerator(const std::string& accountId,
-             const std::string& confId,
-             const std::string& peerId,
-             const bool& state)
+setModerator(const std::string& accountId, const std::string& confId, const std::string& peerId, const bool& state)
 {
     if (const auto account = jami::Manager::instance().getAccount(accountId)) {
         if (auto conf = account->getConference(confId)) {
             conf->setModerator(peerId, state);
         } else {
-            JAMI_WARN("Fail to change moderator %s, conference %s not found",
-                      peerId.c_str(),
-                      confId.c_str());
+            JAMI_WARN("Fail to change moderator %s, conference %s not found", peerId.c_str(), confId.c_str());
         }
     }
 }
 
 void
-muteParticipant(const std::string& accountId,
-                const std::string& confId,
-                const std::string& peerId,
-                const bool& state)
+muteParticipant(const std::string& accountId, const std::string& confId, const std::string& peerId, const bool& state)
 {
-    JAMI_ERR() << "muteParticipant is deprecated, please use muteStream";
+    JAMI_ERROR("muteParticipant is deprecated, please use muteStream");
     if (const auto account = jami::Manager::instance().getAccount(accountId)) {
         if (auto conf = account->getConference(confId)) {
             conf->muteParticipant(peerId, state);
@@ -559,9 +526,7 @@ muteStream(const std::string& accountId,
 }
 
 void
-setActiveParticipant(const std::string& accountId,
-                     const std::string& confId,
-                     const std::string& participant)
+setActiveParticipant(const std::string& accountId, const std::string& confId, const std::string& participant)
 {
     JAMI_ERR() << "setActiveParticipant is deprecated, please use setActiveStream";
     if (const auto account = jami::Manager::instance().getAccount(accountId)) {
@@ -631,8 +596,7 @@ raiseParticipantHand(const std::string& accountId,
     JAMI_ERR() << "raiseParticipantHand is deprecated, please use raiseHand";
     if (const auto account = jami::Manager::instance().getAccount(accountId)) {
         if (auto conf = account->getConference(confId)) {
-            if (auto call = std::static_pointer_cast<jami::SIPCall>(
-                    conf->getCallFromPeerID(peerId))) {
+            if (auto call = std::static_pointer_cast<jami::SIPCall>(conf->getCallFromPeerID(peerId))) {
                 if (auto* transport = call->getTransport())
                     conf->setHandRaised(std::string(transport->deviceId()), state);
             }
@@ -663,8 +627,7 @@ raiseHand(const std::string& accountId,
                 Json::Value deviceVal;
                 deviceVal["raiseHand"] = state;
                 Json::Value deviceObj;
-                std::string device = deviceId.empty() ? std::string(account->currentDeviceId())
-                                                      : deviceId;
+                std::string device = deviceId.empty() ? std::string(account->currentDeviceId()) : deviceId;
                 deviceObj[device] = deviceVal;
                 Json::Value accountVal;
                 deviceVal["devices"] = deviceObj;
