@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,12 +14,13 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "logger.h"
 #include "fileutils.h"
+#include "logger.h"
 #include "archiver.h"
 #include "compiler_intrinsics.h"
 #include "base64.h"
@@ -119,6 +120,21 @@ winGetEnv(const wchar_t* name)
 namespace jami {
 namespace fileutils {
 
+static std::filesystem::path resource_dir_path;
+
+void
+set_resource_dir_path(const std::filesystem::path& resourceDirPath)
+{
+    resource_dir_path = resourceDirPath;
+}
+
+const std::filesystem::path&
+get_resource_dir_path()
+{
+    static const std::filesystem::path jami_default_data_dir(JAMI_DATADIR);
+    return resource_dir_path.empty() ? jami_default_data_dir : resource_dir_path;
+}
+
 std::string
 expand_path(const std::string& path)
 {
@@ -171,11 +187,13 @@ isDirectoryWritable(const std::string& directory)
 bool
 createSymlink(const std::filesystem::path& linkFile, const std::filesystem::path& target)
 {
-    try {
-        std::filesystem::create_symlink(target, linkFile);
-    } catch (const std::exception& e) {
-        JAMI_ERR("Couldn't create soft link: %s", e.what());
+    std::error_code ec;
+    std::filesystem::create_symlink(target, linkFile, ec);
+    if (ec) {
+        JAMI_WARNING("Unable to create soft link from {} to {}: {}", linkFile, target, ec.message());
         return false;
+    } else {
+        JAMI_LOG("Created soft link from {} to {}", linkFile, target);
     }
     return true;
 }
@@ -183,11 +201,13 @@ createSymlink(const std::filesystem::path& linkFile, const std::filesystem::path
 bool
 createHardlink(const std::filesystem::path& linkFile, const std::filesystem::path& target)
 {
-    try {
-        std::filesystem::create_hard_link(target, linkFile);
-    } catch (const std::exception& e) {
-        JAMI_ERR("Couldn't create hard link: %s", e.what());
+    std::error_code ec;
+    std::filesystem::create_hard_link(target, linkFile, ec);
+    if (ec) {
+        JAMI_WARNING("Unable to create hard link from {} to {}: {}", linkFile, target, ec.message());
         return false;
+    } else {
+        JAMI_LOG("Created hard link from {} to {}", linkFile, target);
     }
     return true;
 }
@@ -195,6 +215,14 @@ createHardlink(const std::filesystem::path& linkFile, const std::filesystem::pat
 bool
 createFileLink(const std::filesystem::path& linkFile, const std::filesystem::path& target, bool hard)
 {
+    if (linkFile == target)
+        return true;
+    std::error_code ec;
+    if (std::filesystem::exists(linkFile, ec)) {
+        if (std::filesystem::is_symlink(linkFile, ec) && std::filesystem::read_symlink(linkFile, ec) == target)
+            return true;
+        std::filesystem::remove(linkFile, ec);
+    }
     if (not hard or not createHardlink(linkFile, target))
         return createSymlink(linkFile, target);
     return true;
@@ -247,9 +275,18 @@ std::string
 loadTextFile(const std::filesystem::path& path, const std::filesystem::path& default_dir)
 {
     std::string buffer;
-    std::ifstream file(getFullPath(default_dir, path));
+    auto fullPath = getFullPath(default_dir, path);
+
+    // Open with explicit share mode to allow reading even if file is opened elsewhere
+#ifdef _WIN32
+    std::ifstream file(fullPath, std::ios::in | std::ios::binary, _SH_DENYNO);
+#else
+    std::ifstream file(fullPath);
+#endif
+
     if (!file)
-        throw std::runtime_error("Can't read file: " + path.string());
+        throw std::runtime_error("Unable to read file: " + path.string());
+
     file.seekg(0, std::ios::end);
     auto size = file.tellg();
     if (size > std::numeric_limits<unsigned>::max())
@@ -257,19 +294,16 @@ loadTextFile(const std::filesystem::path& path, const std::filesystem::path& def
     buffer.resize(size);
     file.seekg(0, std::ios::beg);
     if (!file.read((char*) buffer.data(), size))
-        throw std::runtime_error("Can't load file: " + path.string());
+        throw std::runtime_error("Unable to load file: " + path.string());
     return buffer;
 }
 
 void
-saveFile(const std::filesystem::path& path,
-         const uint8_t* data,
-         size_t data_size,
-         mode_t UNUSED mode)
+saveFile(const std::filesystem::path& path, const uint8_t* data, size_t data_size, mode_t UNUSED mode)
 {
     std::ofstream file(path, std::ios::trunc | std::ios::binary);
     if (!file.is_open()) {
-        JAMI_ERROR("Could not write data to {}", path);
+        JAMI_ERROR("Unable to write data to {}", path);
         return;
     }
     file.write((char*) data, data_size);
@@ -284,9 +318,13 @@ std::vector<uint8_t>
 loadCacheFile(const std::filesystem::path& path, std::chrono::system_clock::duration maxAge)
 {
     // last_write_time throws exception if file doesn't exist
-    auto writeTime = std::filesystem::last_write_time(path);
-    if (decltype(writeTime)::clock::now() - writeTime > maxAge)
-        throw std::runtime_error("file too old");
+    std::error_code ec;
+    auto writeTime = std::filesystem::last_write_time(path, ec);
+    if (ec)
+        throw std::runtime_error("unable to get last write time of file");
+    auto now = decltype(writeTime)::clock::now();
+    if (now - writeTime > maxAge)
+        throw std::runtime_error("file too old " + dht::print_time_relative(now, writeTime));
 
     JAMI_LOG("Loading cache file '{}'", path);
     return dhtnet::fileutils::loadFile(path);
@@ -296,9 +334,13 @@ std::string
 loadCacheTextFile(const std::filesystem::path& path, std::chrono::system_clock::duration maxAge)
 {
     // last_write_time throws exception if file doesn't exist
-    auto writeTime = std::filesystem::last_write_time(path);
-    if (decltype(writeTime)::clock::now() - writeTime > maxAge)
-        throw std::runtime_error("file too old");
+    std::error_code ec;
+    auto writeTime = std::filesystem::last_write_time(path, ec);
+    if (ec)
+        throw std::runtime_error("unable to get last write time of file");
+    auto now = decltype(writeTime)::clock::now();
+    if (now - writeTime > maxAge)
+        throw std::runtime_error("file too old " + dht::print_time_relative(now, writeTime));
 
     JAMI_LOG("Loading cache file '{}'", path);
     return loadTextFile(path);
@@ -327,57 +369,61 @@ readArchive(const std::filesystem::path& path, std::string_view scheme, const st
         }
     };
 
-    ArchiveStorageData ret;
+    std::vector<uint8_t> fileContent;
 
     // Read file
     try {
-        ret.data = dhtnet::fileutils::loadFile(path);
+        fileContent = dhtnet::fileutils::loadFile(path);
     } catch (const std::exception& e) {
-        JAMI_ERR("Error loading archive: %s", e.what());
-        throw e;
+        JAMI_ERROR("Error loading archive: {}", e.what());
+        throw;
     }
 
-    if (isUnencryptedGzip(ret.data)) {
+    if (isUnencryptedGzip(fileContent)) {
         if (!pwd.empty())
             JAMI_WARNING("A gunzip in a gunzip is detected. A webserver may have a bad config");
-        decompress(ret.data);
+        decompress(fileContent);
     }
 
+    ArchiveStorageData ret;
+    // ret.data = {fileContent.data(), fileContent.data()+fileContent.size()};
+
     if (!pwd.empty()) {
         // Decrypt
         if (scheme == ARCHIVE_AUTH_SCHEME_KEY) {
             try {
-                ret.salt = dht::crypto::aesGetSalt(ret.data);
-                ret.data = dht::crypto::aesDecrypt(dht::crypto::aesGetEncrypted(ret.data), base64::decode(pwd));
+                ret.salt = dht::crypto::aesGetSalt(fileContent);
+                fileContent = dht::crypto::aesDecrypt(dht::crypto::aesGetEncrypted(fileContent), base64::decode(pwd));
             } catch (const std::exception& e) {
                 JAMI_ERROR("Error decrypting archive: {}", e.what());
-                throw e;
+                throw;
             }
         } else if (scheme == ARCHIVE_AUTH_SCHEME_PASSWORD) {
             try {
-                ret.salt = dht::crypto::aesGetSalt(ret.data);
-                ret.data = dht::crypto::aesDecrypt(ret.data, pwd);
+                ret.salt = dht::crypto::aesGetSalt(fileContent);
+                fileContent = dht::crypto::aesDecrypt(fileContent, pwd);
             } catch (const std::exception& e) {
                 JAMI_ERROR("Error decrypting archive: {}", e.what());
-                throw e;
+                throw;
             }
         }
-        decompress(ret.data);
-    } else if (isUnencryptedGzip(ret.data)) {
+        decompress(fileContent);
+    } else if (isUnencryptedGzip(fileContent)) {
         JAMI_WARNING("A gunzip in a gunzip is detected. A webserver may have a bad config");
-        decompress(ret.data);
+        decompress(fileContent);
     }
+    ret.data = {fileContent.data(), fileContent.data() + fileContent.size()};
     return ret;
 }
 
-void
+bool
 writeArchive(const std::string& archive_str,
              const std::filesystem::path& path,
              std::string_view scheme,
              const std::string& password,
              const std::vector<uint8_t>& password_salt)
 {
-    JAMI_LOG("Writing archive to {}", path);
+    JAMI_LOG("Writing archive to {} using scheme '{}'", path, scheme);
 
     if (scheme == ARCHIVE_AUTH_SCHEME_KEY) {
         // Encrypt using provided key
@@ -387,36 +433,26 @@ writeArchive(const std::string& archive_str,
             saveFile(path, dht::crypto::aesBuildEncrypted(newArchive, password_salt));
         } catch (const std::runtime_error& ex) {
             JAMI_ERROR("Export failed: {}", ex.what());
-            return;
+            return false;
         }
     } else if (scheme == ARCHIVE_AUTH_SCHEME_PASSWORD and not password.empty()) {
         // Encrypt using provided password
         try {
-            saveFile(path, dht::crypto::aesEncrypt(archiver::compress(archive_str), password));
+            saveFile(path, dht::crypto::aesEncrypt(archiver::compress(archive_str), password, password_salt));
         } catch (const std::runtime_error& ex) {
             JAMI_ERROR("Export failed: {}", ex.what());
-            return;
+            return false;
         }
-    } else {
+    } else if (scheme == ARCHIVE_AUTH_SCHEME_NONE || (scheme == ARCHIVE_AUTH_SCHEME_PASSWORD && password.empty())) {
         JAMI_WARNING("Unsecured archiving (no password)");
         archiver::compressGzip(archive_str, path.string());
+    } else {
+        JAMI_ERROR("Unsupported scheme: {}", scheme);
+        return false;
     }
+    return true;
 }
 
-#if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
-#else
-static char* program_dir = NULL;
-void
-set_program_dir(char* program_path)
-{
-#ifdef _MSC_VER
-    _splitpath(program_path, nullptr, program_dir, nullptr, nullptr);
-#else
-    program_dir = dirname(program_path);
-#endif
-}
-#endif
-
 std::filesystem::path
 get_cache_dir(const char* pkg)
 {
@@ -443,14 +479,15 @@ get_cache_dir(const char* pkg)
 #endif
 }
 
-std::filesystem::path
+const std::filesystem::path&
 get_cache_dir()
 {
-    return get_cache_dir(PACKAGE);
+    static const std::filesystem::path cache_dir = get_cache_dir(PACKAGE);
+    return cache_dir;
 }
 
 std::filesystem::path
-get_home_dir()
+get_home_dir_impl()
 {
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
     std::vector<std::string> paths;
@@ -464,7 +501,7 @@ get_home_dir()
     if (SUCCEEDED(SHGetFolderPath(nullptr, CSIDL_PROFILE, nullptr, 0, path))) {
         return jami::to_string(path);
     }
-    return program_dir;
+    return {};
 #else
 
     // 1) try getting user's home directory from the environment
@@ -485,6 +522,13 @@ get_home_dir()
 #endif
 }
 
+const std::filesystem::path&
+get_home_dir()
+{
+    static const std::filesystem::path home_dir = get_home_dir_impl();
+    return home_dir;
+}
+
 std::filesystem::path
 get_data_dir(const char* pkg)
 {
@@ -517,10 +561,11 @@ get_data_dir(const char* pkg)
 #endif
 }
 
-std::filesystem::path
+const std::filesystem::path&
 get_data_dir()
 {
-    return get_data_dir(PACKAGE);
+    static const std::filesystem::path data_dir = get_data_dir(PACKAGE);
+    return data_dir;
 }
 
 std::filesystem::path
@@ -550,18 +595,19 @@ get_config_dir(const char* pkg)
     else
         configdir = fileutils::get_home_dir() / ".config" / pkg;
 #endif
-    if (dhtnet::fileutils::recursive_mkdir(configdir, 0700) != true) {
+    if (!dhtnet::fileutils::recursive_mkdir(configdir, 0700)) {
         // If directory creation failed
         if (errno != EEXIST)
-            JAMI_DBG("Cannot create directory: %s!", configdir.c_str());
+            JAMI_DBG("Unable to create directory: %s!", configdir.c_str());
     }
     return configdir;
 }
 
-std::filesystem::path
+const std::filesystem::path&
 get_config_dir()
 {
-    return get_config_dir(PACKAGE);
+    static const std::filesystem::path config_dir = get_config_dir(PACKAGE);
+    return config_dir;
 }
 
 #ifdef _WIN32
@@ -572,16 +618,15 @@ eraseFile_win32(const std::string& path, bool dosync)
     // https://learn.microsoft.com/en-us/windows/win32/api/fileapi/nf-fileapi-deletefilea#remarks To
     // delete a read-only file, first you must remove the read-only attribute.
     SetFileAttributesA(path.c_str(), GetFileAttributesA(path.c_str()) & ~FILE_ATTRIBUTE_READONLY);
-    HANDLE h
-        = CreateFileA(path.c_str(), GENERIC_WRITE, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
+    HANDLE h = CreateFileA(path.c_str(), GENERIC_WRITE, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
     if (h == INVALID_HANDLE_VALUE) {
-        JAMI_WARN("Can not open file %s for erasing.", path.c_str());
+        JAMI_WARN("Unable to open file %s for erasing.", path.c_str());
         return false;
     }
 
     LARGE_INTEGER size;
     if (!GetFileSizeEx(h, &size)) {
-        JAMI_WARN("Can not erase file %s: GetFileSizeEx() failed.", path.c_str());
+        JAMI_WARN("Unable to erase file %s: GetFileSizeEx() failed.", path.c_str());
         CloseHandle(h);
         return false;
     }
@@ -598,7 +643,7 @@ eraseFile_win32(const std::string& path, bool dosync)
     try {
         buffer = new char[ERASE_BLOCK];
     } catch (std::bad_alloc& ba) {
-        JAMI_WARN("Can not allocate buffer for erasing %s.", path.c_str());
+        JAMI_WARN("Unable to allocate buffer for erasing %s.", path.c_str());
         CloseHandle(h);
         return false;
     }
@@ -634,7 +679,7 @@ eraseFile_posix(const std::string& path, bool dosync)
 {
     struct stat st;
     if (stat(path.c_str(), &st) == -1) {
-        JAMI_WARN("Can not erase file %s: fstat() failed.", path.c_str());
+        JAMI_WARN("Unable to erase file %s: fstat() failed.", path.c_str());
         return false;
     }
     // Remove read-only flag if possible
@@ -642,7 +687,7 @@ eraseFile_posix(const std::string& path, bool dosync)
 
     int fd = open(path.c_str(), O_WRONLY);
     if (fd == -1) {
-        JAMI_WARN("Can not open file %s for erasing.", path.c_str());
+        JAMI_WARN("Unable to open file %s for erasing.", path.c_str());
         return false;
     }
 
@@ -719,18 +764,23 @@ sha3File(const std::filesystem::path& path)
     sha3_512_init(&ctx);
 
     try {
-        if (not std::filesystem::is_regular_file(path))
+        if (not std::filesystem::is_regular_file(path)) {
+            JAMI_ERROR("Unable to compute sha3sum of {}: not a regular file", path);
             return {};
+        }
         std::ifstream file(path, std::ios::binary | std::ios::in);
-        if (!file)
+        if (!file) {
+            JAMI_ERROR("Unable to compute sha3sum of {}: failed to open file", path);
             return {};
+        }
         std::vector<char> buffer(8192, 0);
         while (!file.eof()) {
             file.read(buffer.data(), buffer.size());
             std::streamsize readSize = file.gcount();
             sha3_512_update(&ctx, readSize, (const uint8_t*) buffer.data());
         }
-    } catch (...) {
+    } catch (const std::exception& e) {
+        JAMI_ERROR("Unable to compute sha3sum of {}: {}", path, e.what());
         return {};
     }
 
@@ -769,9 +819,13 @@ accessFile(const std::string& file, int mode)
 uint64_t
 lastWriteTimeInSeconds(const std::filesystem::path& filePath)
 {
-    return std::chrono::duration_cast<std::chrono::seconds>(
-               std::filesystem::last_write_time(filePath).time_since_epoch())
-        .count();
+    std::error_code ec;
+    auto lastWrite = std::filesystem::last_write_time(filePath, ec);
+    if (ec) {
+        JAMI_WARNING("Unable to get last write time of {}: {}", filePath, ec.message());
+        return 0;
+    }
+    return std::chrono::duration_cast<std::chrono::seconds>(lastWrite.time_since_epoch()).count();
 }
 
 } // namespace fileutils
