@@ -1,22 +1,19 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #include <string>
@@ -27,6 +24,9 @@
 #include <cstdint>
 #include <filesystem>
 
+#include <msgpack.hpp>
+#include <asio/steady_timer.hpp>
+
 namespace jami {
 
 class SIPAccountBase;
@@ -35,7 +35,7 @@ namespace im {
 
 using MessageToken = uint64_t;
 
-enum class MessageStatus { UNKNOWN = 0, IDLE, SENDING, SENT, DISPLAYED, FAILURE, CANCELLED };
+enum class MessageStatus { UNKNOWN = 0, IDLE, SENDING, SENT, FAILURE };
 
 class MessageEngine
 {
@@ -56,24 +56,13 @@ public:
 
     MessageStatus getStatus(MessageToken t) const;
 
-    bool cancel(MessageToken t);
-
-    bool isSent(MessageToken t) const { return getStatus(t) == MessageStatus::SENT; }
-
-    void onMessageSent(const std::string& peer,
-                       MessageToken t,
-                       bool success,
-                       const std::string& deviceId = {});
-
-    void onMessageDisplayed(const std::string& peer, MessageToken t, bool displayed);
+    void onMessageSent(const std::string& peer, MessageToken t, bool success, const std::string& deviceId = {});
 
     /**
      * @TODO change MessageEngine by a queue,
      * @NOTE retryOnTimeout is used for failing SIP messages (jamiAccount::sendTextMessage)
      */
-    void onPeerOnline(const std::string& peer,
-                      bool retryOnTimeout = true,
-                      const std::string& deviceId = {});
+    void onPeerOnline(const std::string& peer, const std::string& deviceId = {}, bool retryOnTimeout = true);
 
     /**
      * Load persisted messages
@@ -87,34 +76,37 @@ public:
 
 private:
     static const constexpr unsigned MAX_RETRIES = 20;
-    static const std::chrono::minutes RETRY_PERIOD;
-    using clock = std::chrono::steady_clock;
+    using clock = std::chrono::system_clock;
 
-    void retrySend(const std::string& peer,
-                   bool retryOnTimeout = true,
-                   const std::string& deviceId = {});
+    void retrySend(const std::string& peer, const std::string& deviceId, bool retryOnTimeout);
 
     void save_() const;
+    void scheduleSave();
 
     struct Message
     {
-        std::string to;
-        std::map<std::string, std::string> payloads;
-        MessageStatus status {MessageStatus::UNKNOWN};
+        MessageToken token {};
+        std::string to {};
+        std::map<std::string, std::string> payloads {};
+        MessageStatus status {MessageStatus::IDLE};
         unsigned retried {0};
-        clock::time_point last_op;
+        clock::time_point last_op {};
+
+        MSGPACK_DEFINE_MAP(token, to, payloads, status, retried, last_op)
     };
 
     SIPAccountBase& account_;
     const std::filesystem::path savePath_;
+    std::shared_ptr<asio::io_context> ioContext_;
+    asio::steady_timer saveTimer_;
 
-    std::map<std::string, std::map<MessageToken, Message>> messages_;
-    std::map<std::string, std::map<MessageToken, Message>> messagesDevices_;
-
-    std::set<MessageToken> sentMessages_;
+    std::map<std::string, std::list<Message>> messages_;
+    std::map<std::string, std::list<Message>> messagesDevices_;
 
     mutable std::mutex messagesMutex_ {};
 };
 
 } // namespace im
 } // namespace jami
+
+MSGPACK_ADD_ENUM(jami::im::MessageStatus);
