@@ -22,6 +22,7 @@
 #include "swarm/swarm_protocol.h"
 #include "jami/conversation_interface.h"
 #include "jamidht/typers.h"
+#include "string_utils.h"
 
 #include <json/json.h>
 #include <msgpack.hpp>
@@ -42,27 +43,38 @@ class ChannelSocket;
 namespace jami {
 
 namespace ConversationMapKeys {
-static constexpr const char* ID = "id";
-static constexpr const char* CREATED = "created";
-static constexpr const char* REMOVED = "removed";
-static constexpr const char* ERASED = "erased";
-static constexpr const char* MEMBERS = "members";
-static constexpr const char* LAST_DISPLAYED = "lastDisplayed";
-static constexpr const char* PREFERENCES = "preferences";
-static constexpr const char* ACTIVE_CALLS = "activeCalls";
-static constexpr const char* HOSTED_CALLS = "hostedCalls";
-static constexpr const char* CACHED = "cached";
-static constexpr const char* RECEIVED = "received";
-static constexpr const char* DECLINED = "declined";
-static constexpr const char* FROM = "from";
-static constexpr const char* CONVERSATIONID = "conversationId";
-static constexpr const char* METADATAS = "metadatas";
+static constexpr const char* ID {"id"};
+static constexpr const char* CREATED {"created"};
+static constexpr const char* REMOVED {"removed"};
+static constexpr const char* ERASED {"erased"};
+static constexpr const char* MEMBERS {"members"};
+static constexpr const char* LAST_DISPLAYED {"lastDisplayed"};
+static constexpr const char* RECEIVED {"received"};
+static constexpr const char* DECLINED {"declined"};
+static constexpr const char* FROM {"from"};
+static constexpr const char* CONVERSATIONID {"conversationId"};
+static constexpr const char* METADATAS {"metadatas"};
 } // namespace ConversationMapKeys
 
+namespace ConversationDirectories {
+static constexpr std::string_view PREFERENCES {"preferences"};
+static constexpr std::string_view STATUS {"status"};
+static constexpr std::string_view SENDING {"sending"};
+static constexpr std::string_view FETCHED {"fetched"};
+static constexpr std::string_view ACTIVE_CALLS {"activeCalls"};
+static constexpr std::string_view HOSTED_CALLS {"hostedCalls"};
+static constexpr std::string_view CACHED {"cached"};
+} // namespace ConversationDirectories
+
 namespace ConversationPreferences {
 static constexpr const char* HOST_CONFERENCES = "hostConferences";
 }
 
+class JamiAccount;
+class ConversationRepository;
+class TransferManager;
+enum class ConversationMode;
+
 /**
  * A ConversationRequest is a request which corresponds to a trust request, but for conversations
  * It's signed by the sender and contains the members list, the conversationId, and the metadatas
@@ -100,6 +112,15 @@ struct ConversationRequest
         return true;
     }
 
+    ConversationMode mode() const
+    {
+        try {
+            return to_enum<ConversationMode>(metadatas.at("mode"));
+        } catch (...) {
+        }
+        return ConversationMode::ONE_TO_ONE;
+    }
+
     MSGPACK_DEFINE_MAP(from, conversationId, metadatas, received, declined)
 };
 
@@ -111,6 +132,7 @@ struct ConvInfo
     time_t erased {0};
     std::set<std::string> members;
     std::string lastDisplayed {};
+    ConversationMode mode {0};
 
     ConvInfo() = default;
     ConvInfo(const ConvInfo&) = default;
@@ -126,14 +148,9 @@ struct ConvInfo
 
     Json::Value toJson() const;
 
-    MSGPACK_DEFINE_MAP(id, created, removed, erased, members, lastDisplayed)
+    MSGPACK_DEFINE_MAP(id, created, removed, erased, members, lastDisplayed, mode)
 };
 
-class JamiAccount;
-class ConversationRepository;
-class TransferManager;
-enum class ConversationMode;
-
 using OnPullCb = std::function<void(bool fetchOk)>;
 using OnLoadMessages = std::function<void(std::vector<std::map<std::string, std::string>>&& messages)>;
 using OnLoadMessages2 = std::function<void(std::vector<libjami::SwarmMessage>&& messages)>;
