@@ -1,26 +1,21 @@
 /*
- *  Copyright (C) 2021-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
-#include "conversation.h"
 #include "scheduled_executor.h"
 #include "jamidht/account_manager.h"
 #include "jamidht/conversation.h"
@@ -44,38 +39,54 @@ struct SyncMsg
     // p is conversation's preferences. It's not stored in c, as
     // we can update the preferences without touching any confInfo.
     std::map<std::string, std::map<std::string, std::string>> p;
-    // Last displayed messages
+    // Last displayed messages [[deprecated]]
     std::map<std::string, std::map<std::string, std::string>> ld;
-    MSGPACK_DEFINE(ds, c, cr, p, ld)
+    // Read & fetched status
+    /*
+     * {{ convId,
+     *      { memberUri,, {
+     *          {"fetch", "commitId"},
+     *          {"fetched_ts", "timestamp"},
+     *          {"read", "commitId"},
+     *          {"read_ts", "timestamp"}
+     *       }
+     * }}
+     */
+    std::map<std::string, std::map<std::string, std::map<std::string, std::string>>> ms;
+
+    MSGPACK_DEFINE(ds, c, cr, p, ld, ms)
 };
 
 using ChannelCb = std::function<bool(const std::shared_ptr<dhtnet::ChannelSocket>&)>;
-using NeedSocketCb
-    = std::function<void(const std::string&, const std::string&, ChannelCb&&, const std::string&)>;
-using SengMsgCb = std::function<
-    uint64_t(const std::string&, const DeviceId&, std::map<std::string, std::string>, uint64_t)>;
+using NeedSocketCb = std::function<void(const std::string&, const std::string&, ChannelCb&&, const std::string&)>;
+using SengMsgCb
+    = std::function<uint64_t(const std::string&, const DeviceId&, std::map<std::string, std::string>, uint64_t)>;
 using NeedsSyncingCb = std::function<void(std::shared_ptr<SyncMsg>&&)>;
-using UpdateConvReq = std::function<void(const std::string&, const std::string&, bool)>;
 using OneToOneRecvCb = std::function<void(const std::string&, const std::string&)>;
 
 class ConversationModule
 {
 public:
-    ConversationModule(std::weak_ptr<JamiAccount>&& account,
+    ConversationModule(std::shared_ptr<JamiAccount> account,
+                       std::shared_ptr<AccountManager> accountManager,
                        NeedsSyncingCb&& needsSyncingCb,
                        SengMsgCb&& sendMsgCb,
                        NeedSocketCb&& onNeedSocket,
                        NeedSocketCb&& onNeedSwarmSocket,
-                       UpdateConvReq&& updateConvReqCb,
-                       OneToOneRecvCb&& oneToOneRecvCb);
+                       OneToOneRecvCb&& oneToOneRecvCb,
+                       bool autoLoadConversations = true);
     ~ConversationModule() = default;
 
+    void setAccountManager(std::shared_ptr<AccountManager> accountManager);
+
     /**
-     * Refresh informations about conversations
+     * Refresh information about conversations
      */
     void loadConversations();
 
-#ifdef LIBJAMI_TESTABLE
+    void loadSingleConversation(const std::string& convId);
+
+#ifdef LIBJAMI_TEST
     void onBootstrapStatus(const std::function<void(std::string, Conversation::BootstrapStatus)>& cb);
 #endif
 
@@ -108,6 +119,15 @@ public:
      */
     std::string getOneToOneConversation(const std::string& uri) const noexcept;
 
+    /**
+     * Replace linked conversation in contact's details
+     * @param uri           Of the contact
+     * @param oldConv       Current conversation
+     * @param newConv
+     * @return if replaced
+     */
+    bool updateConvForContact(const std::string& uri, const std::string& oldConv, const std::string& newConv);
+
     /**
      * Return conversation's requests
      */
@@ -150,8 +170,9 @@ public:
     /**
      * Accept a conversation's request
      * @param convId
+     * @param deviceId      If a trust request is accepted from a device (can help to sync)
      */
-    void acceptConversationRequest(const std::string& conversationId);
+    void acceptConversationRequest(const std::string& conversationId, const std::string& deviceId = "");
 
     /**
      * Decline a conversation's request
@@ -177,7 +198,7 @@ public:
      * @return conversation's id
      */
     std::string startConversation(ConversationMode mode = ConversationMode::INVITES_ONLY,
-                                  const std::string& otherMember = "");
+                                  const dht::InfoHash& otherMember = {});
 
     // Message send/load
     void sendMessage(const std::string& conversationId,
@@ -195,25 +216,22 @@ public:
                      OnCommitCb&& onCommit = {},
                      OnDoneCb&& cb = {});
 
-    void editMessage(const std::string& conversationId,
-                     const std::string& newBody,
-                     const std::string& editedId);
-    void reactToMessage(const std::string& conversationId,
-                        const std::string& newBody,
-                        const std::string& reactToId);
+    void editMessage(const std::string& conversationId, const std::string& newBody, const std::string& editedId);
+    void reactToMessage(const std::string& conversationId, const std::string& newBody, const std::string& reactToId);
 
     /**
      * Add to the related conversation the call history message
      * @param uri           Peer number
      * @param duration_ms   The call duration in ms
+     * @param reason
      */
-    void addCallHistoryMessage(const std::string& uri, uint64_t duration_ms);
+    void addCallHistoryMessage(const std::string& uri, uint64_t duration_ms, const std::string& reason);
 
     // Received that a peer displayed a message
     bool onMessageDisplayed(const std::string& peer,
                             const std::string& conversationId,
                             const std::string& interactionId);
-    std::map<std::string, std::map<std::string, std::string>> convDisplayed() const;
+    std::map<std::string, std::map<std::string, std::map<std::string, std::string>>> convMessageStatus() const;
 
     /**
      * Load conversation's messages
@@ -225,9 +243,18 @@ public:
     uint32_t loadConversationMessages(const std::string& conversationId,
                                       const std::string& fromMessage = "",
                                       size_t n = 0);
+    uint32_t loadConversation(const std::string& conversationId, const std::string& fromMessage = "", size_t n = 0);
     uint32_t loadConversationUntil(const std::string& conversationId,
                                    const std::string& fromMessage,
                                    const std::string& to);
+    uint32_t loadSwarmUntil(const std::string& conversationId,
+                            const std::string& fromMessage,
+                            const std::string& toMessage);
+    /**
+     * Clear loaded interactions
+     * @param conversationId
+     */
+    void clearCache(const std::string& conversationId);
 
     // File transfer
     /**
@@ -259,9 +286,7 @@ public:
     bool downloadFile(const std::string& conversationId,
                       const std::string& interactionId,
                       const std::string& fileId,
-                      const std::string& path,
-                      size_t start = 0,
-                      size_t end = 0);
+                      const std::string& path);
 
     // Sync
     /**
@@ -292,9 +317,7 @@ public:
      * @param deviceId          Device who synced
      * @param commit            HEAD synced
      */
-    void setFetched(const std::string& conversationId,
-                    const std::string& deviceId,
-                    const std::string& commit);
+    void setFetched(const std::string& conversationId, const std::string& deviceId, const std::string& commit);
 
     /**
      * Launch fetch on new commit
@@ -303,10 +326,10 @@ public:
      * @param conversationId    Related conversation
      * @param commitId          Commit to retrieve
      */
-    void onNewCommit(const std::string& peer,
-                     const std::string& deviceId,
-                     const std::string& conversationId,
-                     const std::string& commitId);
+    void fetchNewCommits(const std::string& peer,
+                         const std::string& deviceId,
+                         const std::string& conversationId,
+                         const std::string& commitId);
 
     // Conversation's member
     /**
@@ -316,7 +339,7 @@ public:
      * @param sendRequest   If we need to inform the peer (used for tests)
      */
     void addConversationMember(const std::string& conversationId,
-                               const std::string& contactUri,
+                               const dht::InfoHash& contactUri,
                                bool sendRequest = true);
     /**
      * Remove a member from a conversation (this will trigger a member event + new message on success)
@@ -325,7 +348,7 @@ public:
      * @param isDevice
      */
     void removeConversationMember(const std::string& conversationId,
-                                  const std::string& contactUri,
+                                  const dht::InfoHash& contactUri,
                                   bool isDevice = false);
     /**
      * Get members
@@ -333,8 +356,8 @@ public:
      * @param includeBanned
      * @return a map of members with their role and details
      */
-    std::vector<std::map<std::string, std::string>> getConversationMembers(
-        const std::string& conversationId, bool includeBanned = false) const;
+    std::vector<std::map<std::string, std::string>> getConversationMembers(const std::string& conversationId,
+                                                                           bool includeBanned = false) const;
     /**
      * Retrieve the number of interactions from interactionId to HEAD
      * @param convId
@@ -372,8 +395,7 @@ public:
      * @param conversationId
      * @param preferences
      */
-    void setConversationPreferences(const std::string& conversationId,
-                                    const std::map<std::string, std::string>& prefs);
+    void setConversationPreferences(const std::string& conversationId, const std::map<std::string, std::string>& prefs);
     std::map<std::string, std::string> getConversationPreferences(const std::string& conversationId,
                                                                   bool includeCreated = false) const;
     /**
@@ -404,6 +426,15 @@ public:
      * @return if successfully removed
      */
     bool removeConversation(const std::string& conversationId);
+    /**
+     * Search for an existing one-to-one conversation
+     * that exactly matches the given set of member URIs.
+     * @param excludedConversationId   Conversation ID to be ignored during the search.
+     * @param targetUris               The set of member URIs that must match exactly.
+     * @return The ID of the matching conversation if found, otherwise an empty string.
+     */
+    std::string findMatchingOneToOneConversation(const std::string& excludedConversationId,
+                                                 const std::set<std::string>& targetUris) const;
     void initReplay(const std::string& oldConvId, const std::string& newConvId);
     /**
      * Check if we're hosting a specific conference
@@ -417,32 +448,31 @@ public:
      * @param convId        Which conversation to choose
      * @return {{"id":id}, {"uri":uri}, {"device":device}}
      */
-    std::vector<std::map<std::string, std::string>> getActiveCalls(
-        const std::string& conversationId) const;
+    std::vector<std::map<std::string, std::string>> getActiveCalls(const std::string& conversationId) const;
     /**
      * Call the conversation
      * @param url       Url to call (swarm:conversation or swarm:conv/account/device/conf to join)
-     * @param call      Call to use
+     * @param mediaList The media list
      * @param cb        Callback to pass which device to call (called in the same thread)
+     * @return call if a call is started, else nullptr
      */
-    void call(const std::string& url,
-              const std::shared_ptr<SIPCall>& call,
-              std::function<void(const std::string&, const DeviceId&)>&& cb);
+    std::shared_ptr<SIPCall> call(
+        const std::string& url,
+        const std::vector<libjami::MediaMap>& mediaList,
+        std::function<void(const std::string&, const DeviceId&, const std::shared_ptr<SIPCall>&)>&& cb);
     void hostConference(const std::string& conversationId,
                         const std::string& confId,
-                        const std::string& callId);
+                        const std::string& callId,
+                        const std::vector<libjami::MediaMap>& mediaList = {});
 
     // The following methods modify what is stored on the disk
-    static void saveConvInfos(const std::string& accountId,
-                              const std::map<std::string, ConvInfo>& conversations);
+    static void saveConvInfos(const std::string& accountId, const std::map<std::string, ConvInfo>& conversations);
     static void saveConvInfosToPath(const std::filesystem::path& path,
                                     const std::map<std::string, ConvInfo>& conversations);
-    static void saveConvRequests(
-        const std::string& accountId,
-        const std::map<std::string, ConversationRequest>& conversationsRequests);
-    static void saveConvRequestsToPath(
-        const std::filesystem::path& path,
-        const std::map<std::string, ConversationRequest>& conversationsRequests);
+    static void saveConvRequests(const std::string& accountId,
+                                 const std::map<std::string, ConversationRequest>& conversationsRequests);
+    static void saveConvRequestsToPath(const std::filesystem::path& path,
+                                       const std::map<std::string, ConversationRequest>& conversationsRequests);
 
     static std::map<std::string, ConvInfo> convInfos(const std::string& accountId);
     static std::map<std::string, ConvInfo> convInfosFromPath(const std::filesystem::path& path);
@@ -461,8 +491,7 @@ public:
      * @param conversationId    Related conversation
      * @return the related socket
      */
-    std::shared_ptr<dhtnet::ChannelSocket> gitSocket(std::string_view deviceId,
-                                             std::string_view convId) const;
+    std::shared_ptr<dhtnet::ChannelSocket> gitSocket(std::string_view deviceId, std::string_view convId) const;
     void removeGitSocket(std::string_view deviceId, std::string_view convId);
     void addGitSocket(std::string_view deviceId,
                       std::string_view convId,
@@ -482,6 +511,13 @@ public:
      */
     void connectivityChanged();
 
+    /**
+     * Get Typers object for a conversation
+     * @param convId
+     * @return the Typer object
+     */
+    std::shared_ptr<Typers> getTypers(const std::string& convId);
+
 private:
     class Impl;
     std::shared_ptr<Impl> pimpl_;
