@@ -1,15 +1,14 @@
 /*
- *  Copyright (C) 2019-2024 Savoir-faire Linux Inc.
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
@@ -23,6 +22,7 @@
 #include "manager.h"
 #include <opendht/thread_pool.h>
 #include <dhtnet/multiplexed_socket.h>
+#include <fmt/compile.h>
 
 #include <charconv>
 #include <ctime>
@@ -36,21 +36,23 @@ constexpr auto NAK_PKT = "0008NAK\n"sv;
 constexpr auto DONE_CMD = "done\n"sv;
 constexpr auto WANT_CMD = "want"sv;
 constexpr auto HAVE_CMD = "have"sv;
-constexpr auto SERVER_CAPABILITIES
-    = " HEAD\0side-band side-band-64k shallow no-progress include-tag"sv;
+constexpr auto SERVER_CAPABILITIES = " HEAD\0side-band side-band-64k shallow no-progress include-tag"sv;
 
 namespace jami {
 
 class GitServer::Impl
 {
 public:
-    Impl(const std::string& repositoryId,
+    Impl(const std::string& accountId,
+         const std::string& repositoryId,
          const std::string& repository,
          const std::shared_ptr<dhtnet::ChannelSocket>& socket)
-        : repositoryId_(repositoryId)
+        : accountId_(accountId)
+        , repositoryId_(repositoryId)
         , repository_(repository)
         , socket_(socket)
     {
+        JAMI_DEBUG("[Account {}] [Conversation {}] [GitServer {}] created", accountId_, repositoryId_, fmt::ptr(this));
         // Check at least if repository is correct
         git_repository* repo;
         if (git_repository_open(&repo, repository_.c_str()) != 0) {
@@ -63,12 +65,17 @@ public:
             std::lock_guard lk(destroyMtx_);
             if (isDestroying_)
                 return len;
-            if (parseOrder(std::string_view((const char*)buf, len)))
-                while(parseOrder());
+            if (parseOrder(std::string_view((const char*) buf, len)))
+                while (parseOrder())
+                    ;
             return len;
         });
     }
-    ~Impl() { stop(); }
+    ~Impl()
+    {
+        stop();
+        JAMI_DEBUG("[Account {}] [Conversation {}] [GitServer {}] destroyed", accountId_, repositoryId_, fmt::ptr(this));
+    }
     void stop()
     {
         std::lock_guard lk(destroyMtx_);
@@ -86,6 +93,7 @@ public:
     void sendPackData();
     std::map<std::string, std::string> getParameters(std::string_view pkt_line);
 
+    std::string accountId_ {};
     std::string repositoryId_ {};
     std::string repository_ {};
     std::shared_ptr<dhtnet::ChannelSocket> socket_ {};
@@ -112,7 +120,10 @@ GitServer::Impl::parseOrder(std::string_view buf)
     unsigned int pkt_len = 0;
     auto [p, ec] = std::from_chars(pkt.data(), pkt.data() + 4, pkt_len, 16);
     if (ec != std::errc()) {
-        JAMI_ERROR("Can't parse packet size");
+        JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to parse packet size",
+                   accountId_,
+                   repositoryId_,
+                   fmt::ptr(this));
     }
     if (pkt_len != pkt.size()) {
         // Store next packet part
@@ -129,7 +140,10 @@ GitServer::Impl::parseOrder(std::string_view buf)
         // https://github.com/git/git/blob/master/Documentation/technical/pack-protocol.txt#L390 Do
         // not do multi-ack, just send ACK + pack file
         // In case of no common base, send NAK
-        JAMI_INFO("Peer negotiation is done. Answering to want order");
+        JAMI_LOG("[Account {}] [Conversation {}] [GitServer {}] Peer negotiation is done. Answering to want order",
+                 accountId_,
+                 repositoryId_,
+                 fmt::ptr(this));
         bool sendData;
         if (common_.empty())
             sendData = NAK();
@@ -151,34 +165,52 @@ GitServer::Impl::parseOrder(std::string_view buf)
 
     auto lim = pack.find(' ');
     auto cmd = pack.substr(0, lim);
-    auto dat = (lim < pack.size()) ? pack.substr(lim+1) : std::string_view{};
+    auto dat = (lim < pack.size()) ? pack.substr(lim + 1) : std::string_view {};
     if (cmd == UPLOAD_PACK_CMD) {
         // Cf: https://github.com/git/git/blob/master/Documentation/technical/pack-protocol.txt#L166
         // References discovery
-        JAMI_INFO("Upload pack command detected.");
+        JAMI_LOG("[Account {}] [Conversation {}] [GitServer {}] Upload pack command detected.",
+                 accountId_,
+                 repositoryId_,
+                 fmt::ptr(this));
         auto version = 1;
         auto parameters = getParameters(dat);
         auto versionIt = parameters.find("version");
         bool sendVersion = false;
         if (versionIt != parameters.end()) {
-            try {
-                version = std::stoi(versionIt->second);
+            auto [p, ec] = std::from_chars(versionIt->second.data(),
+                                           versionIt->second.data() + versionIt->second.size(),
+                                           version);
+            if (ec == std::errc()) {
                 sendVersion = true;
-            } catch (...) {
-                JAMI_WARNING("Invalid version detected: {}", versionIt->second);
+            } else {
+                JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Invalid version detected: {}",
+                             accountId_,
+                             repositoryId_,
+                             fmt::ptr(this),
+                             versionIt->second);
             }
         }
         if (version == 1) {
             sendReferenceCapabilities(sendVersion);
         } else {
-            JAMI_ERR("That protocol version is not yet supported (version: %u)", version);
+            JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] That protocol version is not yet supported "
+                       "(version: {:d})",
+                       accountId_,
+                       repositoryId_,
+                       fmt::ptr(this),
+                       version);
         }
     } else if (cmd == WANT_CMD) {
         // Reference:
         // https://github.com/git/git/blob/master/Documentation/technical/pack-protocol.txt#L229
         // TODO can have more want
         wantedReference_ = dat.substr(0, 40);
-        JAMI_INFO("Peer want ref: %s", wantedReference_.c_str());
+        JAMI_LOG("[Account {}] [Conversation {}] [GitServer {}] Peer want ref: {}",
+                 accountId_,
+                 repositoryId_,
+                 fmt::ptr(this),
+                 wantedReference_);
     } else if (cmd == HAVE_CMD) {
         const auto& commit = haveRefs_.emplace_back(dat.substr(0, 40));
         if (common_.empty()) {
@@ -188,7 +220,11 @@ GitServer::Impl::parseOrder(std::string_view buf)
             // TODO do not open repository every time
             git_repository* repo;
             if (git_repository_open(&repo, repository_.c_str()) != 0) {
-                JAMI_WARN("Couldn't open %s", repository_.c_str());
+                JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open {}",
+                             accountId_,
+                             repositoryId_,
+                             fmt::ptr(this),
+                             repository_);
                 return !cachedPkt_.empty();
             }
             GitRepository rep {repo, git_repository_free};
@@ -199,11 +235,21 @@ GitServer::Impl::parseOrder(std::string_view buf)
             }
         }
     } else {
-        JAMI_WARNING("Unwanted packet received: {}", pkt);
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unwanted packet received: {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     pkt);
     }
     return !cachedPkt_.empty();
 }
 
+std::string
+toGitHex(size_t value)
+{
+    return fmt::format(FMT_COMPILE("{:04x}"), value & 0x0FFFF);
+}
+
 void
 GitServer::Impl::sendReferenceCapabilities(bool sendVersion)
 {
@@ -212,7 +258,11 @@ GitServer::Impl::sendReferenceCapabilities(bool sendVersion)
     // https://github.com/git/git/blob/master/Documentation/technical/pack-protocol.txt#L166
     git_repository* repo;
     if (git_repository_open(&repo, repository_.c_str()) != 0) {
-        JAMI_WARNING("Couldn't open {}", repository_);
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_);
         socket_->shutdown();
         return;
     }
@@ -221,16 +271,17 @@ GitServer::Impl::sendReferenceCapabilities(bool sendVersion)
     // Answer with the version number
     // **** When the client initially connects the server will immediately respond
     // **** with a version number (if "version=1" is sent as an Extra Parameter),
-    std::string currentHead;
     std::error_code ec;
-    std::stringstream packet;
     if (sendVersion) {
-        packet << "000eversion 1\0";
-        socket_->write(reinterpret_cast<const unsigned char*>(packet.str().c_str()),
-                       packet.str().size(),
-                       ec);
+        constexpr auto toSend = "000eversion 1\0"sv;
+        socket_->write(reinterpret_cast<const unsigned char*>(toSend.data()), toSend.size(), ec);
         if (ec) {
-            JAMI_WARNING("Couldn't send data for {}: {}", repository_, ec.message());
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         repository_,
+                         ec.message());
             socket_->shutdown();
             return;
         }
@@ -238,32 +289,36 @@ GitServer::Impl::sendReferenceCapabilities(bool sendVersion)
 
     git_oid commit_id;
     if (git_reference_name_to_id(&commit_id, rep.get(), "HEAD") < 0) {
-        JAMI_ERROR("Cannot get reference for HEAD");
+        JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to get reference for HEAD",
+                   accountId_,
+                   repositoryId_,
+                   fmt::ptr(this));
         socket_->shutdown();
         return;
     }
-    currentHead = git_oid_tostr_s(&commit_id);
+    std::string_view currentHead = git_oid_tostr_s(&commit_id);
 
     // Send references
-    std::string capStr = currentHead + SERVER_CAPABILITIES;
-
-    packet.str("");
-    packet << std::setw(4) << std::setfill('0') << std::hex << ((5 + capStr.size()) & 0x0FFFF);
-    packet << capStr << "\n";
+    std::ostringstream packet;
+    packet << toGitHex(5 + currentHead.size() + SERVER_CAPABILITIES.size());
+    packet << currentHead << SERVER_CAPABILITIES << "\n";
 
     // Now, add other references
     git_strarray refs;
     if (git_reference_list(&refs, rep.get()) == 0) {
         for (std::size_t i = 0; i < refs.count; ++i) {
-            std::string ref = refs.strings[i];
-            if (git_reference_name_to_id(&commit_id, rep.get(), ref.c_str()) < 0) {
-                JAMI_WARNING("Cannot get reference for {}", ref);
+            std::string_view ref = refs.strings[i];
+            if (git_reference_name_to_id(&commit_id, rep.get(), ref.data()) < 0) {
+                JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to get reference for {}",
+                             accountId_,
+                             repositoryId_,
+                             fmt::ptr(this),
+                             ref);
                 continue;
             }
             currentHead = git_oid_tostr_s(&commit_id);
 
-            packet << std::setw(4) << std::setfill('0') << std::hex
-                   << ((6 /* size + space + \n */ + currentHead.size() + ref.size()) & 0x0FFFF);
+            packet << toGitHex(6 /* size + space + \n */ + currentHead.size() + ref.size());
             packet << currentHead << " " << ref << "\n";
         }
     }
@@ -272,9 +327,14 @@ GitServer::Impl::sendReferenceCapabilities(bool sendVersion)
     // And add FLUSH
     packet << FLUSH_PKT;
     auto toSend = packet.str();
-    socket_->write(reinterpret_cast<const unsigned char*>(toSend.c_str()), toSend.size(), ec);
+    socket_->write(reinterpret_cast<const unsigned char*>(toSend.data()), toSend.size(), ec);
     if (ec) {
-        JAMI_WARNING("Couldn't send data for {}: {}", repository_, ec.message());
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_,
+                     ec.message());
         socket_->shutdown();
     }
 }
@@ -285,14 +345,17 @@ GitServer::Impl::ACKCommon()
     std::error_code ec;
     // Ack common base
     if (!common_.empty()) {
-        std::stringstream packet;
-        packet << std::setw(4) << std::setfill('0') << std::hex
-               << ((18 /* size + ACK + space * 2 + continue + \n */ + common_.size()) & 0x0FFFF);
-        packet << "ACK " << common_ << " continue\n";
-        auto toSend = packet.str();
+        auto toSend = fmt::format(FMT_COMPILE("{:04x}ACK {} continue\n"),
+                                  18 + common_.size() /* size + ACK + space * 2 + continue + \n */,
+                                  common_);
         socket_->write(reinterpret_cast<const unsigned char*>(toSend.c_str()), toSend.size(), ec);
         if (ec) {
-            JAMI_WARNING("Couldn't send data for {}: {}", repository_, ec.message());
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         repository_,
+                         ec.message());
             socket_->shutdown();
         }
     }
@@ -304,14 +367,17 @@ GitServer::Impl::ACKFirst()
     std::error_code ec;
     // Ack common base
     if (!common_.empty()) {
-        std::stringstream packet;
-        packet << std::setw(4) << std::setfill('0') << std::hex
-               << ((9 /* size + ACK + space + \n */ + common_.size()) & 0x0FFFF);
-        packet << "ACK " << common_ << "\n";
-        auto toSend = packet.str();
+        auto toSend = fmt::format(FMT_COMPILE("{:04x}ACK {}\n"),
+                                  9 + common_.size() /* size + ACK + space + \n */,
+                                  common_);
         socket_->write(reinterpret_cast<const unsigned char*>(toSend.c_str()), toSend.size(), ec);
         if (ec) {
-            JAMI_WARNING("Couldn't send data for {}: {}", repository_, ec.message());
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         repository_,
+                         ec.message());
             socket_->shutdown();
             return false;
         }
@@ -326,7 +392,12 @@ GitServer::Impl::NAK()
     // NAK
     socket_->write(reinterpret_cast<const unsigned char*>(NAK_PKT.data()), NAK_PKT.size(), ec);
     if (ec) {
-        JAMI_WARNING("Couldn't send data for {}: {}", repository_, ec.message());
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_,
+                     ec.message());
         socket_->shutdown();
         return false;
     }
@@ -338,22 +409,34 @@ GitServer::Impl::sendPackData()
 {
     git_repository* repo_ptr;
     if (git_repository_open(&repo_ptr, repository_.c_str()) != 0) {
-        JAMI_WARN("Couldn't open %s", repository_.c_str());
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_);
         return;
     }
     GitRepository repo {repo_ptr, git_repository_free};
 
     git_packbuilder* pb_ptr;
     if (git_packbuilder_new(&pb_ptr, repo.get()) != 0) {
-        JAMI_WARNING("Couldn't open packbuilder for {}", repository_);
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open packbuilder for {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_);
         return;
     }
     GitPackBuilder pb {pb_ptr, git_packbuilder_free};
 
     std::string fetched = wantedReference_;
     git_oid oid;
-    if (git_oid_fromstr(&oid, wantedReference_.c_str()) < 0) {
-        JAMI_ERROR("Cannot get reference for commit {}", wantedReference_);
+    if (git_oid_fromstr(&oid, fetched.c_str()) < 0) {
+        JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to get reference for commit {}",
+                   accountId_,
+                   repositoryId_,
+                   fmt::ptr(this),
+                   fetched);
         return;
     }
 
@@ -379,16 +462,22 @@ GitServer::Impl::sendPackData()
         if (haveCommit && parents.size() == 0 /* We are sure that all commits are there */)
             break;
         if (git_packbuilder_insert_commit(pb.get(), &oid) != 0) {
-            JAMI_WARN("Couldn't open insert commit %s for %s",
-                      git_oid_tostr_s(&oid),
-                      repository_.c_str());
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to open insert commit {} for {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         git_oid_tostr_s(&oid),
+                         repository_);
             return;
         }
 
         // Get next commit to pack
         git_commit* commit_ptr;
         if (git_commit_lookup(&commit_ptr, repo.get(), &oid) < 0) {
-            JAMI_ERR("Could not look up current commit");
+            JAMI_ERROR("[Account {}] [Conversation {}] [GitServer {}] Unable to look up current commit",
+                       accountId_,
+                       repositoryId_,
+                       fmt::ptr(this));
             return;
         }
         GitCommit commit {commit_ptr, git_commit_free};
@@ -403,39 +492,55 @@ GitServer::Impl::sendPackData()
 
     git_buf data = {};
     if (git_packbuilder_write_buf(&data, pb.get()) != 0) {
-        JAMI_WARN("Couldn't write pack data for %s", repository_.c_str());
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to write pack data for {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_);
         return;
     }
 
     std::size_t sent = 0;
     std::size_t len = data.size;
     std::error_code ec;
+    std::vector<uint8_t> toSendData;
     do {
         // cf https://github.com/git/git/blob/master/Documentation/technical/pack-protocol.txt#L166
         // In 'side-band-64k' mode it will send up to 65519 data bytes plus 1 control code, for a
         // total of up to 65520 bytes in a pkt-line.
         std::size_t pkt_size = std::min(static_cast<std::size_t>(65515), len - sent);
-        std::stringstream toSend;
-        toSend << std::setw(4) << std::setfill('0') << std::hex << ((pkt_size + 5) & 0x0FFFF);
-        toSend << "\x1" << std::string_view(data.ptr + sent, pkt_size);
-        std::string toSendStr = toSend.str();
+        std::string toSendHeader = toGitHex(pkt_size + 5);
+        toSendData.clear();
+        toSendData.reserve(pkt_size + 5);
+        toSendData.insert(toSendData.end(), toSendHeader.begin(), toSendHeader.end());
+        toSendData.push_back(0x1);
+        toSendData.insert(toSendData.end(), data.ptr + sent, data.ptr + sent + pkt_size);
 
-        socket_->write(reinterpret_cast<const unsigned char*>(toSendStr.c_str()),
-                       toSendStr.size(),
-                       ec);
+        socket_->write(reinterpret_cast<const unsigned char*>(toSendData.data()), toSendData.size(), ec);
         if (ec) {
-            JAMI_WARNING("Couldn't send data for {}: {}", repository_, ec.message());
+            JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                         accountId_,
+                         repositoryId_,
+                         fmt::ptr(this),
+                         repository_,
+                         ec.message());
             git_buf_dispose(&data);
             return;
         }
         sent += pkt_size;
     } while (sent < len);
     git_buf_dispose(&data);
+    toSendData = {};
 
     // And finish by a little FLUSH
     socket_->write(reinterpret_cast<const uint8_t*>(FLUSH_PKT.data()), FLUSH_PKT.size(), ec);
     if (ec) {
-        JAMI_WARNING("Couldn't send data for {}: {}", repository_, ec.message());
+        JAMI_WARNING("[Account {}] [Conversation {}] [GitServer {}] Unable to send data for {}: {}",
+                     accountId_,
+                     repositoryId_,
+                     fmt::ptr(this),
+                     repository_,
+                     ec.message());
     }
 
     // Clear sent data
@@ -453,11 +558,11 @@ GitServer::Impl::getParameters(std::string_view pkt_line)
     std::string key, value;
     auto isKey = true;
     auto nullChar = 0;
-    for (auto letter: pkt_line) {
+    for (auto letter : pkt_line) {
         if (letter == '\0') {
             // parameters such as host or version are after the first \0
             if (nullChar != 0 && !key.empty()) {
-                parameters[std::move(key)] = std::move(value);
+                parameters.try_emplace(std::move(key), std::move(value));
             }
             nullChar += 1;
             isKey = true;
@@ -481,14 +586,13 @@ GitServer::GitServer(const std::string& accountId,
                      const std::shared_ptr<dhtnet::ChannelSocket>& client)
 {
     auto path = (fileutils::get_data_dir() / accountId / "conversations" / conversationId).string();
-    pimpl_ = std::make_unique<GitServer::Impl>(conversationId, path, client);
+    pimpl_ = std::make_unique<GitServer::Impl>(accountId, conversationId, path, client);
 }
 
 GitServer::~GitServer()
 {
     stop();
     pimpl_.reset();
-    JAMI_INFO("GitServer destroyed");
 }
 
 void
