@@ -1,23 +1,19 @@
 /*
- *  Copyright (C) 2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Fadi Shehadeh <fadi.shehadeh@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #include "routing_table.h"
@@ -54,8 +50,9 @@ public:
     /**
      * Set list of nodes to the routing table known_nodes
      * @param known_nodes
+     * @return if some are new
      */
-    void setKnownNodes(const std::vector<NodeId>& known_nodes);
+    bool setKnownNodes(const std::vector<NodeId>& known_nodes);
 
     /**
      * Set list of nodes to the routing table mobile_nodes
@@ -82,6 +79,12 @@ public:
      */
     void changeMobility(const NodeId& nodeId, bool isMobile);
 
+    /**
+     * Check if swarm manager is connected
+     * @return true if the swarm has at least one connected node, false if not
+     */
+    bool isConnected() const;
+
     /**
      * get all nodes from the different tables in bucket
      */
@@ -111,6 +114,14 @@ public:
      */
     void shutdown();
 
+    /**
+     * Restart the swarm manager.
+     *
+     * This function must be called in situations where we want
+     * to use a swarm manager that was previously shut down.
+     */
+    void restart();
+
     /**
      * Display swarm manager info
      */
@@ -118,7 +129,7 @@ public:
     {
         JAMI_DEBUG("SwarmManager {:s} has {:d} nodes in table [P = {}]",
                    getId().to_c_str(),
-                   routing_table.getRoutingTableNodeCount(),
+                   routing_table.getNodeCount(),
                    isMobile_);
         // print nodes of routingtable
         for (auto& bucket : routing_table.getBuckets()) {
@@ -187,7 +198,7 @@ private:
      * @param numberNodes
      */
     void sendRequest(const std::shared_ptr<dhtnet::ChannelSocketInterface>& socket,
-                     NodeId& nodeId,
+                     const NodeId& nodeId,
                      Query q,
                      int numberNodes = Bucket::BUCKET_MAX_SIZE);
 
