@@ -27,6 +27,8 @@
 #include "fileutils.h"
 #include "gittransport.h"
 #include "map_utils.h"
+#include "jami.h"
+#include "media_attribute.h"
 #include "account.h"
 #include "string_utils.h"
 #include "jamidht/jamiaccount.h"
@@ -246,9 +248,7 @@ setGnuTlsLogLevel()
     }
 
     gnutls_global_set_log_level(level);
-    gnutls_global_set_log_function([](int level, const char* msg) {
-        JAMI_XDBG("[{:d}]GnuTLS: {:s}", level, msg);
-    });
+    gnutls_global_set_log_function([](int level, const char* msg) { JAMI_XDBG("[{:d}]GnuTLS: {:s}", level, msg); });
 }
 
 //==============================================================================
@@ -625,9 +625,7 @@ Manager::ManagerPimpl::sendTextMessageToConference(const Conference& conf,
                 throw std::runtime_error("No associated call");
             call->sendTextMessage(messages, from);
         } catch (const std::exception& e) {
-            JAMI_ERR("Failed to send message to conference participant %s: %s",
-                     callId.c_str(),
-                     e.what());
+            JAMI_ERR("Failed to send message to conference participant %s: %s", callId.c_str(), e.what());
         }
     }
 }
@@ -823,9 +821,8 @@ Manager::init(const std::filesystem::path& config_file, libjami::InitFlag flags)
         if (pimpl_->audiodriver_) {
             auto format = pimpl_->audiodriver_->getFormat();
             pimpl_->toneCtrl_.setSampleRate(format.sample_rate, format.sampleFormat);
-            pimpl_->dtmfKey_.reset(
-                new DTMF(getRingBufferPool().getInternalSamplingRate(),
-                         getRingBufferPool().getInternalAudioFormat().sampleFormat));
+            pimpl_->dtmfKey_.reset(new DTMF(getRingBufferPool().getInternalSamplingRate(),
+                                            getRingBufferPool().getInternalAudioFormat().sampleFormat));
         }
     }
 
@@ -912,7 +909,7 @@ Manager::finish() noexcept
         git_libgit2_shutdown();
 
         if (!pimpl_->ioContext_->stopped()) {
-            pimpl_->ioContext_->stop();  // make thread stop
+            pimpl_->ioContext_->stop(); // make thread stop
         }
         if (pimpl_->ioContextRunner_.joinable())
             pimpl_->ioContextRunner_.join();
@@ -938,8 +935,7 @@ Manager::monitor(bool continuous)
 #ifdef __linux__
 #if defined(__ANDROID__)
 #else
-    auto opened_files
-        = dhtnet::fileutils::readDirectory("/proc/" + std::to_string(getpid()) + "/fd").size();
+    auto opened_files = dhtnet::fileutils::readDirectory("/proc/" + std::to_string(getpid()) + "/fd").size();
     JAMI_DBG("Opened files: %lu", opened_files);
 #endif
 #endif
@@ -1062,8 +1058,7 @@ Manager::outgoingCall(const std::string& account_id,
                       const std::string& to,
                       const std::vector<libjami::MediaMap>& mediaList)
 {
-    JAMI_DBG() << "Attempt outgoing call to '" << to << "'"
-               << " with account '" << account_id << "'";
+    JAMI_DBG() << "Attempt outgoing call to '" << to << "'" << " with account '" << account_id << "'";
 
     std::shared_ptr<Call> call;
 
@@ -1316,9 +1311,7 @@ Manager::holdConference(const std::string& accountId, const std::string& confId)
     if (const auto account = getAccount(accountId)) {
         if (auto conf = account->getConference(confId)) {
             conf->detachHost();
-            emitSignal<libjami::CallSignal::ConferenceChanged>(accountId,
-                                                               conf->getConfId(),
-                                                               conf->getStateStr());
+            emitSignal<libjami::CallSignal::ConferenceChanged>(accountId, conf->getConfId(), conf->getStateStr());
             return true;
         }
     }
@@ -1340,9 +1333,7 @@ Manager::unHoldConference(const std::string& accountId, const std::string& confI
 
                 pimpl_->switchCall(confId);
                 conf->setState(Conference::State::ACTIVE_ATTACHED);
-                emitSignal<libjami::CallSignal::ConferenceChanged>(accountId,
-                                                                   conf->getConfId(),
-                                                                   conf->getStateStr());
+                emitSignal<libjami::CallSignal::ConferenceChanged>(accountId, conf->getConfId(), conf->getStateStr());
                 return true;
             } else if (conf->getState() == Conference::State::ACTIVE_DETACHED) {
                 pimpl_->addMainParticipant(*conf);
@@ -1354,9 +1345,9 @@ Manager::unHoldConference(const std::string& accountId, const std::string& confI
 
 bool
 Manager::addSubCall(const std::string& accountId,
-                        const std::string& callId,
-                        const std::string& account2Id,
-                        const std::string& conferenceId)
+                    const std::string& callId,
+                    const std::string& account2Id,
+                    const std::string& conferenceId)
 {
     auto account = getAccount(accountId);
     auto account2 = getAccount(account2Id);
@@ -1399,10 +1390,9 @@ Manager::addSubCall(Call& call, Conference& conference)
 void
 Manager::ManagerPimpl::addMainParticipant(Conference& conf)
 {
-    conf.attachHost();
-    emitSignal<libjami::CallSignal::ConferenceChanged>(conf.getAccountId(),
-                                                       conf.getConfId(),
-                                                       conf.getStateStr());
+    JAMI_DEBUG("[conf:{:s}] Adding main participant to conference", conf.getConfId());
+    conf.attachHost(conf.getLastMediaList());
+    emitSignal<libjami::CallSignal::ConferenceChanged>(conf.getAccountId(), conf.getConfId(), conf.getStateStr());
     switchCall(conf.getConfId());
 }
 
@@ -1487,8 +1477,9 @@ Manager::joinParticipant(const std::string& accountId,
     auto mediaAttr = call1->getMediaAttributeList();
     if (mediaAttr.empty())
         mediaAttr = call2->getMediaAttributeList();
+
     auto conf = std::make_shared<Conference>(account);
-    conf->attachHost();
+    conf->attachHost(MediaAttribute::mediaAttributesToMediaMaps(mediaAttr));
     account->attach(conf);
     emitSignal<libjami::CallSignal::ConferenceCreated>(account->getAccountID(), "", conf->getConfId());
 
@@ -1503,16 +1494,13 @@ Manager::joinParticipant(const std::string& accountId,
     } else {
         conf->detachHost();
     }
-    emitSignal<libjami::CallSignal::ConferenceChanged>(account->getAccountID(),
-                                                       conf->getConfId(),
-                                                       conf->getStateStr());
+    emitSignal<libjami::CallSignal::ConferenceChanged>(account->getAccountID(), conf->getConfId(), conf->getStateStr());
 
     return true;
 }
 
 void
-Manager::createConfFromParticipantList(const std::string& accountId,
-                                       const std::vector<std::string>& participantList)
+Manager::createConfFromParticipantList(const std::string& accountId, const std::vector<std::string>& participantList)
 {
     auto account = getAccount(accountId);
     if (not account) {
@@ -1527,7 +1515,9 @@ Manager::createConfFromParticipantList(const std::string& accountId,
     }
 
     auto conf = std::make_shared<Conference>(account);
-    conf->attachHost();
+    // attach host with empty medialist
+    // which will result in a default list set by initSourcesForHost
+    conf->attachHost({});
 
     unsigned successCounter = 0;
     for (const auto& numberaccount : participantList) {
@@ -1561,9 +1551,7 @@ Manager::detachHost(const std::shared_ptr<Conference>& conf)
 
     JAMI_LOG("Detach local participant from conference {}", conf->getConfId());
     conf->detachHost();
-    emitSignal<libjami::CallSignal::ConferenceChanged>(conf->getAccountId(),
-                                                       conf->getConfId(),
-                                                       conf->getStateStr());
+    emitSignal<libjami::CallSignal::ConferenceChanged>(conf->getAccountId(), conf->getConfId(), conf->getStateStr());
     pimpl_->unsetCurrentCall();
     return true;
 }
@@ -1602,9 +1590,7 @@ Manager::removeParticipant(Call& call)
 
     removeAudio(call);
 
-    emitSignal<libjami::CallSignal::ConferenceChanged>(conf->getAccountId(),
-                                                       conf->getConfId(),
-                                                       conf->getStateStr());
+    emitSignal<libjami::CallSignal::ConferenceChanged>(conf->getAccountId(), conf->getConfId(), conf->getStateStr());
 
     pimpl_->processRemainingParticipants(*conf);
 }
@@ -1675,7 +1661,7 @@ Manager::addAudio(Call& call)
     // bind to main
     auto medias = call.getAudioStreams();
     for (const auto& media : medias) {
-        JAMI_DEBUG("[call:{}] Attach audio", media.first);
+        JAMI_DEBUG("[call:{}] Attach audio stream {}", callId, media.first);
         getRingBufferPool().bindRingBuffers(media.first, RingBufferPool::DEFAULT_ID);
     }
     auto oldGuard = std::move(call.audioGuard);
@@ -1853,8 +1839,7 @@ Manager::playDtmf(char code)
         pimpl_->audiodriver_->putUrgent(pimpl_->dtmfBuf_);
     }
 
-    scheduler().scheduleIn([audioGuard] { JAMI_WARN("End of dtmf"); },
-                           std::chrono::milliseconds(pulselen));
+    scheduler().scheduleIn([audioGuard] { JAMI_WARN("End of dtmf"); }, std::chrono::milliseconds(pulselen));
 
     // TODO Cache the DTMF
 }
@@ -1876,9 +1861,7 @@ Manager::incomingCall(const std::string& accountId, Call& call)
 
     auto const& account = getAccount(accountId);
     if (not account) {
-        JAMI_ERROR("Incoming call {} on unknown account {}",
-                 call.getCallId(),
-                 accountId);
+        JAMI_ERROR("Incoming call {} on unknown account {}", call.getCallId(), accountId);
         return;
     }
 
@@ -1913,10 +1896,7 @@ Manager::incomingMessage(const std::string& accountId,
                 }
 
                 // in case of a conference we must notify client using conference id
-                emitSignal<libjami::CallSignal::IncomingMessage>(accountId,
-                                                                 conf->getConfId(),
-                                                                 from,
-                                                                 messages);
+                emitSignal<libjami::CallSignal::IncomingMessage>(accountId, conf->getConfId(), from, messages);
             } else {
                 JAMI_ERR("No conference associated to ID %s", callId.c_str());
             }
@@ -1953,9 +1933,7 @@ Manager::sendCallTextMessage(const std::string& accountId,
             try {
                 call->sendTextMessage(messages, from);
             } catch (const im::InstantMessageException& e) {
-                JAMI_ERR("Failed to send message to call %s: %s",
-                         call->getCallId().c_str(),
-                         e.what());
+                JAMI_ERR("Failed to send message to call %s: %s", call->getCallId().c_str(), e.what());
             }
         }
     } else {
@@ -2040,9 +2018,7 @@ Manager::callBusy(Call& call)
 void
 Manager::callFailure(Call& call)
 {
-    JAMI_LOG("[call:{}] {} failed",
-             call.getCallId(),
-             call.isSubcall() ? "Sub-call" : "Parent call");
+    JAMI_LOG("[call:{}] {} failed", call.getCallId(), call.isSubcall() ? "Sub-call" : "Parent call");
 
     if (isCurrentCall(call)) {
         pimpl_->unsetCurrentCall();
@@ -2460,6 +2436,30 @@ Manager::setNoiseSuppressState(const std::string& state)
     audioPreference.setNoiseReduce(state);
 }
 
+std::string
+Manager::getEchoCancellationState() const
+{
+    return audioPreference.getEchoCanceller();
+}
+
+void
+Manager::setEchoCancellationState(const std::string& state)
+{
+    audioPreference.setEchoCancel(state);
+}
+
+bool
+Manager::getVoiceActivityDetectionState() const
+{
+    return audioPreference.getVadEnabled();
+}
+
+void
+Manager::setVoiceActivityDetectionState(bool state)
+{
+    audioPreference.setVad(state);
+}
+
 bool
 Manager::isAGCEnabled() const
 {
@@ -2527,21 +2527,14 @@ Manager::ManagerPimpl::processIncomingCall(const std::string& accountId, Call& i
         return;
     }
 
-    auto const& mediaList = MediaAttribute::mediaAttributesToMediaMaps(
-        incomCall.getMediaAttributeList());
+    auto const& mediaList = MediaAttribute::mediaAttributesToMediaMaps(incomCall.getMediaAttributeList());
 
     if (mediaList.empty())
         JAMI_WARNING("Incoming call {} has an empty media list", incomCallId);
 
-    JAMI_DEBUG("Incoming call {} on account {} with {} media",
-               incomCallId,
-               accountId,
-               mediaList.size());
+    JAMI_DEBUG("Incoming call {} on account {} with {} media", incomCallId, accountId, mediaList.size());
 
-    emitSignal<libjami::CallSignal::IncomingCallWithMedia>(accountId,
-                                                           incomCallId,
-                                                           incomCall.getPeerNumber(),
-                                                           mediaList);
+    emitSignal<libjami::CallSignal::IncomingCallWithMedia>(accountId, incomCallId, incomCall.getPeerNumber(), mediaList);
 
     if (not base_.hasCurrentCall()) {
         incomCall.setState(Call::ConnectionState::RINGING);
@@ -2584,8 +2577,7 @@ Manager::ManagerPimpl::processIncomingCall(const std::string& accountId, Call& i
             // First call
             auto conf = std::make_shared<Conference>(account);
             account->attach(conf);
-            emitSignal<libjami::CallSignal::ConferenceCreated>(account->getAccountID(), "",
-                                                               conf->getConfId());
+            emitSignal<libjami::CallSignal::ConferenceCreated>(account->getAccountID(), "", conf->getConfId());
 
             // Bind calls according to their state
             bindCallToConference(*incomCall, *conf);
@@ -2595,16 +2587,14 @@ Manager::ManagerPimpl::processIncomingCall(const std::string& accountId, Call& i
                                                                conf->getStateStr());
         });
     } else if (autoAnswer_ || account->isAutoAnswerEnabled()) {
-        dht::ThreadPool::io().run(
-            [this, incomCall = incomCall.shared_from_this()] { base_.acceptCall(*incomCall); });
+        dht::ThreadPool::io().run([this, incomCall = incomCall.shared_from_this()] { base_.acceptCall(*incomCall); });
     } else if (currentCall && currentCall->getCallId() != incomCallId) {
         // Test if already calling this person
         auto peerNumber = incomCall.getPeerNumber();
         auto currentPeerNumber = currentCall->getPeerNumber();
         string_replace(peerNumber, "@ring.dht", "");
         string_replace(currentPeerNumber, "@ring.dht", "");
-        if (currentCall->getAccountId() == account->getAccountID()
-            && currentPeerNumber == peerNumber) {
+        if (currentCall->getAccountId() == account->getAccountID() && currentPeerNumber == peerNumber) {
             auto answerToCall = false;
             auto downgradeToAudioOnly = currentCall->isAudioOnly() != incomCall.isAudioOnly();
             if (downgradeToAudioOnly)
@@ -2693,15 +2683,13 @@ Manager::getVolatileAccountDetails(const std::string& accountID) const
     if (account) {
         return account->getVolatileAccountDetails();
     } else {
-        JAMI_ERR("Unable to get volatile account details on a nonexistent accountID %s",
-                 accountID.c_str());
+        JAMI_ERR("Unable to get volatile account details on a nonexistent accountID %s", accountID.c_str());
         return {};
     }
 }
 
 void
-Manager::setAccountDetails(const std::string& accountID,
-                           const std::map<std::string, std::string>& details)
+Manager::setAccountDetails(const std::string& accountID, const std::map<std::string, std::string>& details)
 {
     JAMI_DBG("Set account details for %s", accountID.c_str());
 
@@ -2732,6 +2720,7 @@ Manager::setAccountDetails(const std::string& accountID,
 std::mt19937_64
 Manager::getSeededRandomEngine()
 {
+    std::lock_guard l(randMutex_);
     return dht::crypto::getDerivedRandomEngine(rand_);
 }
 
@@ -2763,9 +2752,7 @@ Manager::addAccount(const std::map<std::string, std::string>& details, const std
 
     auto newAccount = accountFactory.createAccount(accountType, newAccountID);
     if (!newAccount) {
-        JAMI_ERROR("Unknown {:s} param when calling addAccount(): {:s}",
-                   Conf::CONFIG_ACCOUNT_TYPE,
-                   accountType);
+        JAMI_ERROR("Unknown {:s} param when calling addAccount(): {:s}", Conf::CONFIG_ACCOUNT_TYPE, accountType);
         return "";
     }
 
@@ -2981,14 +2968,11 @@ Manager::setAccountActive(const std::string& accountID, bool active, bool shutdo
             acc->doUnregister(shutdownConnections);
         }
     }
-    emitSignal<libjami::ConfigurationSignal::VolatileDetailsChanged>(
-        accountID, acc->getVolatileAccountDetails());
+    emitSignal<libjami::ConfigurationSignal::VolatileDetailsChanged>(accountID, acc->getVolatileAccountDetails());
 }
 
 void
-Manager::loadAccountAndConversation(const std::string& accountId,
-                                    bool loadAll,
-                                    const std::string& convId)
+Manager::loadAccountAndConversation(const std::string& accountId, bool loadAll, const std::string& convId)
 {
     auto account = getAccount(accountId);
     if (!account && !autoLoad) {
@@ -3065,30 +3049,29 @@ Manager::newOutgoingCall(std::string_view toUrl,
 std::shared_ptr<video::SinkClient>
 Manager::createSinkClient(const std::string& id, bool mixer)
 {
-    const auto& iter = pimpl_->sinkMap_.find(id);
-    if (iter != std::end(pimpl_->sinkMap_)) {
-        if (auto sink = iter->second.lock())
-            return sink;
-        pimpl_->sinkMap_.erase(iter); // remove expired weak_ptr
-    }
-
+    std::lock_guard lk(pimpl_->sinksMutex_);
+    auto& sinkRef = pimpl_->sinkMap_[id];
+    if (auto sink = sinkRef.lock())
+        return sink;
     auto sink = std::make_shared<video::SinkClient>(id, mixer);
-    pimpl_->sinkMap_.emplace(id, sink);
+    sinkRef = sink;
     return sink;
 }
 
 void
-Manager::createSinkClients(
-    const std::string& callId,
-    const ConfInfo& infos,
-    const std::vector<std::shared_ptr<video::VideoFrameActiveWriter>>& videoStreams,
-    std::map<std::string, std::shared_ptr<video::SinkClient>>& sinksMap,
-    const std::string& accountId)
+Manager::createSinkClients(const std::string& callId,
+                           const ConfInfo& infos,
+                           const std::vector<std::shared_ptr<video::VideoFrameActiveWriter>>& videoStreams,
+                           std::map<std::string, std::shared_ptr<video::SinkClient>>& sinksMap,
+                           const std::string& accountId)
 {
-    std::lock_guard lk(pimpl_->sinksMutex_);
+    auto account = accountId.empty() ? nullptr : getAccount<JamiAccount>(accountId);
+
     std::set<std::string> sinkIdsList {};
+    std::vector<std::pair<std::shared_ptr<video::SinkClient>, std::pair<int, int>>> newSinks;
 
     // create video sinks
+    std::unique_lock lk(pimpl_->sinksMutex_);
     for (const auto& participant : infos) {
         std::string sinkId = participant.sinkId;
         if (sinkId.empty()) {
@@ -3096,33 +3079,29 @@ Manager::createSinkClients(
             sinkId += string_remove_suffix(participant.uri, '@') + participant.device;
         }
         if (participant.w && participant.h && !participant.videoMuted) {
-            auto currentSink = getSinkClient(sinkId);
-            if (!accountId.empty() && currentSink
-                && string_remove_suffix(participant.uri, '@') == getAccount(accountId)->getUsername()
-                && participant.device == getAccount<JamiAccount>(accountId)->currentDeviceId()) {
+            auto& currentSinkW = pimpl_->sinkMap_[sinkId];
+            if (account && string_remove_suffix(participant.uri, '@') == account->getUsername()
+                && participant.device == account->currentDeviceId()) {
                 // This is a local sink that must already exist
                 continue;
             }
-            if (currentSink) {
+            if (auto currentSink = currentSinkW.lock()) {
                 // If sink exists, update it
                 currentSink->setCrop(participant.x, participant.y, participant.w, participant.h);
                 sinkIdsList.emplace(sinkId);
                 continue;
             }
-            auto newSink = createSinkClient(sinkId);
-            newSink->start();
+            auto newSink = std::make_shared<video::SinkClient>(sinkId, false);
+            currentSinkW = newSink;
             newSink->setCrop(participant.x, participant.y, participant.w, participant.h);
-            newSink->setFrameSize(participant.w, participant.h);
-
-            for (auto& videoStream : videoStreams)
-                videoStream->attach(newSink.get());
-
-            sinksMap.emplace(sinkId, newSink);
+            newSinks.emplace_back(newSink, std::make_pair(participant.w, participant.h));
+            sinksMap.emplace(sinkId, std::move(newSink));
             sinkIdsList.emplace(sinkId);
         } else {
             sinkIdsList.erase(sinkId);
         }
     }
+    lk.unlock();
 
     // remove unused video sinks
     for (auto it = sinksMap.begin(); it != sinksMap.end();) {
@@ -3135,11 +3114,20 @@ Manager::createSinkClients(
             it++;
         }
     }
+
+    // create new video sinks
+    for (const auto& [sink, size] : newSinks) {
+        sink->start();
+        sink->setFrameSize(size.first, size.second);
+        for (auto& videoStream : videoStreams)
+            videoStream->attach(sink.get());
+    }
 }
 
 std::shared_ptr<video::SinkClient>
 Manager::getSinkClient(const std::string& id)
 {
+    std::lock_guard lk(pimpl_->sinksMutex_);
     const auto& iter = pimpl_->sinkMap_.find(id);
     if (iter != std::end(pimpl_->sinkMap_))
         if (auto sink = iter->second.lock())
@@ -3195,9 +3183,7 @@ Manager::getJamiPluginManager() const
 #endif
 
 std::shared_ptr<dhtnet::ChannelSocket>
-Manager::gitSocket(std::string_view accountId,
-                   std::string_view deviceId,
-                   std::string_view conversationId)
+Manager::gitSocket(std::string_view accountId, std::string_view deviceId, std::string_view conversationId)
 {
     if (const auto acc = getAccount<JamiAccount>(accountId))
         if (auto convModule = acc->convModule(true))
@@ -3246,8 +3232,7 @@ void
 Manager::enableLocalModerators(const std::string& accountID, bool isModEnabled)
 {
     if (auto acc = getAccount(accountID))
-        acc->editConfig(
-            [&](AccountConfig& config) { config.localModeratorsEnabled = isModEnabled; });
+        acc->editConfig([&](AccountConfig& config) { config.localModeratorsEnabled = isModEnabled; });
 }
 
 bool
