@@ -1,21 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Philippe Groarke <philippe.groarke@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "corelayer.h"
@@ -33,6 +30,35 @@ dispatch_queue_t audioConfigurationQueueMacOS() {
     return queue;
 }
 
+enum AVSampleFormat
+getFormatFromStreamDescription(const AudioStreamBasicDescription& descr) {
+    if(descr.mFormatID == kAudioFormatLinearPCM) {
+        BOOL isPlanar = descr.mFormatFlags & kAudioFormatFlagIsNonInterleaved;
+        if(descr.mBitsPerChannel == 16) {
+            if(descr.mFormatFlags & kAudioFormatFlagIsSignedInteger) {
+                return isPlanar ? AV_SAMPLE_FMT_S16P : AV_SAMPLE_FMT_S16;
+            }
+        }
+        else if(descr.mBitsPerChannel == 32) {
+            if(descr.mFormatFlags & kAudioFormatFlagIsFloat) {
+                return isPlanar ? AV_SAMPLE_FMT_FLTP : AV_SAMPLE_FMT_FLT;
+            }
+            else if(descr.mFormatFlags & kAudioFormatFlagIsSignedInteger) {
+                return isPlanar ? AV_SAMPLE_FMT_S32P : AV_SAMPLE_FMT_S32;
+            }
+        }
+    }
+    NSLog(@"Unsupported core audio format");
+    return AV_SAMPLE_FMT_NONE;
+}
+
+AudioFormat
+audioFormatFromDescription(const AudioStreamBasicDescription& descr) {
+    return AudioFormat {static_cast<unsigned int>(descr.mSampleRate),
+                        static_cast<unsigned int>(descr.mChannelsPerFrame),
+                        getFormatFromStreamDescription(descr)};
+}
+
 // AudioLayer implementation.
 CoreLayer::CoreLayer(const AudioPreference& pref)
     : AudioLayer(pref)
@@ -116,7 +142,7 @@ CoreLayer::initAudioLayerIO(AudioDeviceType stream)
 
     auto comp = AudioComponentFindNext(nullptr, &desc);
     if (comp == nullptr) {
-        JAMI_ERR("Can't find default output audio component.");
+        JAMI_ERR("Unable to find default output audio component.");
         return;
     }
 
@@ -226,7 +252,8 @@ CoreLayer::initAudioLayerIO(AudioDeviceType stream)
                                   &size));
 
     audioFormat_ = {static_cast<unsigned int>(outSampleRate_),
-                    static_cast<unsigned int>(info.mChannelsPerFrame)};
+                    static_cast<unsigned int>(info.mChannelsPerFrame),
+                    getFormatFromStreamDescription(info)};
 
     outChannelsPerFrame_ = info.mChannelsPerFrame;
 
@@ -261,7 +288,8 @@ CoreLayer::initAudioLayerIO(AudioDeviceType stream)
                                   &size));
 
     audioInputFormat_ = {static_cast<unsigned int>(inSampleRate_),
-                         static_cast<unsigned int>(info.mChannelsPerFrame)};
+                         static_cast<unsigned int>(info.mChannelsPerFrame),
+                         getFormatFromStreamDescription(info)};
     hardwareInputFormatAvailable(audioInputFormat_);
     // Keep everything else and change only sample rate (or else SPLOSION!!!)
     info.mSampleRate = audioInputFormat_.sample_rate;
