@@ -1,23 +1,18 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "libav_deps.h"
@@ -46,7 +41,7 @@ Resampler::reinit(const AVFrame* in, const AVFrame* out)
     // NOTE swr_set_matrix should be called on an uninitialized context
     auto swrCtx = swr_alloc();
     if (!swrCtx) {
-        JAMI_ERR() << "Cannot allocate resampler context";
+        JAMI_ERR() << "Unable to allocate resampler context";
         throw std::bad_alloc();
     }
 
@@ -59,8 +54,8 @@ Resampler::reinit(const AVFrame* in, const AVFrame* out)
     av_opt_set_sample_fmt(swrCtx, "osf", static_cast<AVSampleFormat>(out->format), 0);
 
     /**
-     * Downmixing from 5.1 requires extra setup, since libswresample can't do it automatically
-     * (not yet implemented).
+     * Downmixing from 5.1 requires extra setup, since libswresample is unable to do it
+     * automatically (not yet implemented).
      *
      * Source: https://www.atsc.org/wp-content/uploads/2015/03/A52-201212-17.pdf
      * Section 7.8.2 for the algorithm
@@ -69,9 +64,8 @@ Resampler::reinit(const AVFrame* in, const AVFrame* out)
      * LFE downmixing is optional, so any coefficient can be used, we use +6dB for mono and
      * +0dB in each channel for stereo.
      */
-    if (in->ch_layout.u.mask == AV_CH_LAYOUT_5POINT1
-        || in->ch_layout.u.mask == AV_CH_LAYOUT_5POINT1_BACK) {
-        // NOTE MSVC can't allocate dynamic size arrays on the stack
+    if (in->ch_layout.u.mask == AV_CH_LAYOUT_5POINT1 || in->ch_layout.u.mask == AV_CH_LAYOUT_5POINT1_BACK) {
+        // NOTE: MSVC is unable to allocate dynamic size arrays on the stack
         if (out->ch_layout.nb_channels == 2) {
             double matrix[2][6];
             // L = 1.0*FL + 0.707*FC + 0.707*BL + 1.0*LFE
@@ -165,8 +159,7 @@ Resampler::resample(std::shared_ptr<AudioFrame>&& in, const AudioFormat& format)
         return {};
     }
 
-    if (inPtr->sample_rate == (int) format.sample_rate
-        && inPtr->ch_layout.nb_channels == (int) format.nb_channels
+    if (inPtr->sample_rate == (int) format.sample_rate && inPtr->ch_layout.nb_channels == (int) format.nb_channels
         && (AVSampleFormat) inPtr->format == format.sampleFormat) {
         return std::move(in);
     }
