@@ -1,23 +1,18 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Tristan Matthews <tristan.matthews@savoirfairelinux.com>
- *  Author: Vivien Didelot <vivien.didelot@savoirfairelinux.com>
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,6 +38,7 @@
 #ifdef _MSC_VER
 #include <io.h> // for access
 #else
+#include <sys/syscall.h>
 #include <unistd.h>
 #endif
 extern "C" {
@@ -142,8 +138,7 @@ VideoInput::getPixelFormat() const
 void
 VideoInput::setRotation(int angle)
 {
-    std::shared_ptr<AVBufferRef> displayMatrix {av_buffer_alloc(sizeof(int32_t) * 9),
-                                                [](AVBufferRef* buf) {
+    std::shared_ptr<AVBufferRef> displayMatrix {av_buffer_alloc(sizeof(int32_t) * 9), [](AVBufferRef* buf) {
                                                     av_buffer_unref(&buf);
                                                 }};
     if (displayMatrix) {
@@ -229,22 +224,16 @@ VideoInput::flushBuffers()
 }
 
 void
-VideoInput::configureFilePlayback(const std::string&,
-                                  std::shared_ptr<MediaDemuxer>& demuxer,
-                                  int index)
+VideoInput::configureFilePlayback(const std::string&, std::shared_ptr<MediaDemuxer>& demuxer, int index)
 {
     deleteDecoder();
     clearOptions();
 
-    auto decoder = std::make_unique<MediaDecoder>(demuxer,
-                                                  index,
-                                                  [this](std::shared_ptr<MediaFrame>&& frame) {
-                                                      publishFrame(
-                                                          std::static_pointer_cast<VideoFrame>(
-                                                              frame));
-                                                  });
-    decoder->setInterruptCallback(
-        [](void* data) -> int { return not static_cast<VideoInput*>(data)->isCapturing(); }, this);
+    auto decoder = std::make_unique<MediaDecoder>(demuxer, index, [this](std::shared_ptr<MediaFrame>&& frame) {
+        publishFrame(std::static_pointer_cast<VideoFrame>(frame));
+    });
+    decoder->setInterruptCallback([](void* data) -> int { return not static_cast<VideoInput*>(data)->isCapturing(); },
+                                  this);
     decoder->emulateRate();
 
     decoder_ = std::move(decoder);
@@ -264,7 +253,7 @@ VideoInput::configureFilePlayback(const std::string&,
     if (fmt != AV_PIX_FMT_NONE) {
         decOpts_.pixel_format = av_get_pix_fmt_name(fmt);
     } else {
-        JAMI_WARN("Could not determine pixel format, using default");
+        JAMI_WARN("Unable to determine pixel format, using default");
         decOpts_.pixel_format = av_get_pix_fmt_name(AV_PIX_FMT_YUV420P);
     }
 
@@ -297,28 +286,28 @@ VideoInput::createDecoder()
         return;
     }
 
-    auto decoder = std::make_unique<MediaDecoder>(
-        [this](const std::shared_ptr<MediaFrame>& frame) mutable {
-            publishFrame(std::static_pointer_cast<VideoFrame>(frame));
-        });
+    auto decoder = std::make_unique<MediaDecoder>([this](const std::shared_ptr<MediaFrame>& frame) mutable {
+        publishFrame(std::static_pointer_cast<VideoFrame>(frame));
+    });
 
     if (emulateRate_)
         decoder->emulateRate();
 
-    decoder->setInterruptCallback(
-        [](void* data) -> int { return not static_cast<VideoInput*>(data)->isCapturing(); }, this);
+    decoder->setInterruptCallback([](void* data) -> int { return not static_cast<VideoInput*>(data)->isCapturing(); },
+                                  this);
 
     bool ready = false, restartSink = false;
-    if ((decOpts_.format == "x11grab" || decOpts_.format == "dxgigrab") && !decOpts_.is_area) {
+    if ((decOpts_.format == "x11grab" || decOpts_.format == "dxgigrab" || decOpts_.format == "pipewiregrab")
+        && !decOpts_.is_area) {
         decOpts_.width = 0;
         decOpts_.height = 0;
     }
     while (!ready && !isStopped_) {
         // Retry to open the video till the input is opened
-        auto ret = decoder->openInput(decOpts_);
+        int ret = decoder->openInput(decOpts_);
         ready = ret >= 0;
         if (ret < 0 && -ret != EBUSY) {
-            JAMI_ERR("Could not open input \"%s\" with status %i", decOpts_.input.c_str(), ret);
+            JAMI_ERR("Unable to open input \"%s\" with status %i", decOpts_.input.c_str(), ret);
             foundDecOpts(decOpts_);
             return;
         } else if (-ret == EBUSY) {
@@ -357,7 +346,7 @@ VideoInput::createDecoder()
     if (fmt != AV_PIX_FMT_NONE) {
         decOpts_.pixel_format = av_get_pix_fmt_name(fmt);
     } else {
-        JAMI_WARN("Could not determine pixel format, using default");
+        JAMI_WARN("Unable to determine pixel format, using default");
         decOpts_.pixel_format = av_get_pix_fmt_name(AV_PIX_FMT_YUV420P);
     }
 
@@ -391,13 +380,6 @@ VideoInput::deleteDecoder()
     decoder_.reset();
 }
 
-void
-VideoInput::stopInput()
-{
-    clearOptions();
-    loop_.stop();
-}
-
 void
 VideoInput::clearOptions()
 {
@@ -417,8 +399,11 @@ VideoInput::isCapturing() const noexcept
 bool
 VideoInput::initCamera(const std::string& device)
 {
-    decOpts_ = jami::getVideoDeviceMonitor().getDeviceParams(device);
-    return true;
+    if (auto dm = jami::getVideoDeviceMonitor()) {
+        decOpts_ = dm->getDeviceParams(device);
+        return true;
+    }
+    return false;
 }
 
 static constexpr unsigned
@@ -427,23 +412,71 @@ round2pow(unsigned i, unsigned n)
     return (i >> n) << n;
 }
 
+#if !defined(WIN32) && !defined(__APPLE__)
 bool
-VideoInput::initX11(const std::string& display)
+VideoInput::initLinuxGrab(const std::string& display)
 {
-    // Patterns
-    // full screen sharing : :1+0,0 2560x1440 - SCREEN 1, POSITION 0X0, RESOLUTION 2560X1440
-    // area sharing : :1+882,211 1532x779 - SCREEN 1, POSITION 882x211, RESOLUTION 1532x779
-    // window sharing : :+1,0 0x0 window-id:0x0340021e - POSITION 0X0
+    auto deviceMonitor = jami::getVideoDeviceMonitor();
+    if (!deviceMonitor)
+        return false;
+    // Patterns (all platforms except Linux with Wayland)
+    // full screen sharing:            :1+0,0 2560x1440                (SCREEN 1, POSITION 0X0, RESOLUTION 2560X1440)
+    // area sharing:                   :1+882,211 1532x779             (SCREEN 1, POSITION 882x211, RESOLUTION 1532x779)
+    // window sharing:                 :+1,0 0x0 window-id:0x0340021e  (POSITION 0X0)
+    //
+    // Pattern (Linux with Wayland)
+    // full screen or window sharing:  pipewire pid:2861 fd:23 node:68
     size_t space = display.find(' ');
     std::string windowIdStr = "window-id:";
     size_t winIdPos = display.find(windowIdStr);
 
-    DeviceParams p = jami::getVideoDeviceMonitor().getDeviceParams(DEVICE_DESKTOP);
+    DeviceParams p = deviceMonitor->getDeviceParams(DEVICE_DESKTOP);
     if (winIdPos != std::string::npos) {
-        p.window_id = display.substr(winIdPos + windowIdStr.size()); // "0x0340021e";
+        size_t endPos = display.find(' ', winIdPos + windowIdStr.size());
+        p.window_id = display.substr(winIdPos + windowIdStr.size(),
+                                     endPos - (winIdPos + windowIdStr.size())); // "0x0340021e";
         p.is_area = 0;
     }
-    if (space != std::string::npos) {
+    std::string fpsStr = "fps:";
+    if (display.find(fpsStr) != std::string::npos) {
+        size_t fpsPos = display.find(fpsStr) + fpsStr.size();
+        int fps = std::stoi(display.substr(fpsPos));
+        p.framerate = fps;
+        JAMI_LOG("Custom framerate set to {} fps", fps);
+    }
+    if (display.find("pipewire") != std::string::npos) {
+        std::string pidStr = "pid:";
+        std::string fdStr = "fd:";
+        std::string nodeStr = "node:";
+
+        size_t pidPos = display.find(pidStr) + pidStr.size();
+        size_t fdPos = display.find(fdStr) + fdStr.size();
+        size_t nodePos = display.find(nodeStr) + nodeStr.size();
+
+        pid_t pid = std::stol(display.substr(pidPos));
+        int fd = std::stoi(display.substr(fdPos));
+        if (pid != getpid()) {
+#ifdef SYS_pidfd_getfd
+            // We are unable to directly use a file descriptor that was opened in a different
+            // process, so we try to duplicate it in the current process.
+            int pidfd = syscall(SYS_pidfd_open, pid, 0);
+            if (pidfd < 0) {
+                JAMI_ERROR("Unable to duplicate PipeWire fd: call to pidfd_open failed (errno = {})", errno);
+                return false;
+            }
+            fd = syscall(SYS_pidfd_getfd, pidfd, fd, 0);
+            if (fd < 0) {
+                JAMI_ERROR("Unable to duplicate PipeWire fd: call to pidfd_getfd failed (errno = {})", errno);
+                return false;
+            }
+#else
+            JAMI_ERROR("Unable to duplicate PipeWire fd: pidfd_getfd syscall not available");
+            return false;
+#endif
+        }
+        p.fd = fd;
+        p.node = display.substr(nodePos);
+    } else if (space != std::string::npos) {
         p.input = display.substr(1, space);
         if (p.window_id.empty()) {
             p.input = display.substr(0, space);
@@ -460,21 +493,21 @@ VideoInput::initX11(const std::string& display)
         p.is_area = 1;
     }
 
-    auto dec = std::make_unique<MediaDecoder>();
-    if (dec->openInput(p) < 0 || dec->setupVideo() < 0)
-        return initCamera(jami::getVideoDeviceMonitor().getDefaultDevice());
-
-    clearOptions();
     decOpts_ = p;
-    decOpts_.width = round2pow(dec->getStream().width, 3);
-    decOpts_.height = round2pow(dec->getStream().height, 3);
+    emulateRate_ = false;
 
     return true;
 }
+#endif
 
+#ifdef __APPLE__
 bool
 VideoInput::initAVFoundation(const std::string& display)
 {
+    auto deviceMonitor = jami::getVideoDeviceMonitor();
+    if (!deviceMonitor)
+        return false;
+
     size_t space = display.find(' ');
 
     clearOptions();
@@ -482,7 +515,7 @@ VideoInput::initAVFoundation(const std::string& display)
     decOpts_.pixel_format = "nv12";
     decOpts_.name = "Capture screen 0";
     decOpts_.input = "Capture screen 0";
-    decOpts_.framerate = jami::getVideoDeviceMonitor().getDeviceParams(DEVICE_DESKTOP).framerate;
+    decOpts_.framerate = deviceMonitor->getDeviceParams(DEVICE_DESKTOP).framerate;
 
     if (space != std::string::npos) {
         std::istringstream iss(display.substr(space + 1));
@@ -497,11 +530,16 @@ VideoInput::initAVFoundation(const std::string& display)
     }
     return true;
 }
+#endif
 
 #ifdef WIN32
 bool
 VideoInput::initWindowsGrab(const std::string& display)
 {
+    auto deviceMonitor = jami::getVideoDeviceMonitor();
+    if (!deviceMonitor)
+        return false;
+
     // Patterns
     // full screen sharing : :1+0,0 2560x1440 - SCREEN 1, POSITION 0X0, RESOLUTION 2560X1440
     // area sharing : :1+882,211 1532x779 - SCREEN 1, POSITION 882x211, RESOLUTION 1532x779
@@ -510,10 +548,13 @@ VideoInput::initWindowsGrab(const std::string& display)
     std::string windowIdStr = "window-id:";
     size_t winHandlePos = display.find(windowIdStr);
 
-    DeviceParams p = jami::getVideoDeviceMonitor().getDeviceParams(DEVICE_DESKTOP);
+    DeviceParams p = deviceMonitor->getDeviceParams(DEVICE_DESKTOP);
     if (winHandlePos != std::string::npos) {
-        p.input = display.substr(winHandlePos + windowIdStr.size()); // "HANDLE";
-        p.name = display.substr(winHandlePos + windowIdStr.size());  // "HANDLE";
+        size_t endPos = display.find(' ', winHandlePos + windowIdStr.size());
+        p.input = display.substr(winHandlePos + windowIdStr.size(),
+                                 endPos - (winHandlePos + windowIdStr.size())); // "HANDLE";
+        p.name = display.substr(winHandlePos + windowIdStr.size(),
+                                endPos - (winHandlePos + windowIdStr.size())); // "HANDLE";
         p.is_area = 0;
     } else {
         p.input = display.substr(1);
@@ -540,10 +581,17 @@ VideoInput::initWindowsGrab(const std::string& display)
             p.height = default_grab_height;
         }
     }
+    std::string fpsStr = "fps:";
+    if (display.find(fpsStr) != std::string::npos) {
+        size_t fpsPos = display.find(fpsStr) + fpsStr.size();
+        int fps = std::stoi(display.substr(fpsPos));
+        p.framerate = fps;
+        JAMI_LOG("Custom framerate set to {} fps", fps);
+    }
 
     auto dec = std::make_unique<MediaDecoder>();
     if (dec->openInput(p) < 0 || dec->setupVideo() < 0)
-        return initCamera(jami::getVideoDeviceMonitor().getDefaultDevice());
+        return initCamera(deviceMonitor->getDefaultDevice());
 
     clearOptions();
     decOpts_ = p;
@@ -557,6 +605,10 @@ VideoInput::initWindowsGrab(const std::string& display)
 bool
 VideoInput::initFile(std::string path)
 {
+    auto deviceMonitor = jami::getVideoDeviceMonitor();
+    if (!deviceMonitor)
+        return false;
+
     size_t dot = path.find_last_of('.');
     std::string ext = dot == std::string::npos ? "" : path.substr(dot + 1);
 
@@ -567,14 +619,14 @@ VideoInput::initFile(std::string path)
     }
 
     // check if file has video, fall back to default device if none
-    // FIXME the way this is done is hackish, but it can't be done in createDecoder because that
-    // would break the promise returned in switchInput
+    // FIXME the way this is done is hackish, but it is unable to be done in createDecoder
+    // because that would break the promise returned in switchInput
     DeviceParams p;
     p.input = path;
     p.name = path;
     auto dec = std::make_unique<MediaDecoder>();
     if (dec->openInput(p) < 0 || dec->setupVideo() < 0) {
-        return initCamera(jami::getVideoDeviceMonitor().getDefaultDevice());
+        return initCamera(deviceMonitor->getDefaultDevice());
     }
 
     clearOptions();
@@ -650,7 +702,7 @@ VideoInput::switchInput(const std::string& resource)
 #elif defined(WIN32)
         ready = initWindowsGrab(suffix);
 #else
-        ready = initX11(suffix);
+        ready = initLinuxGrab(suffix);
 #endif
     } else if (prefix == libjami::Media::VideoProtocolPrefix::FILE) {
         /* Pathname */
@@ -674,13 +726,7 @@ VideoInput::getInfo() const
     }
     auto opts = futureDecOpts_.get();
     rational<int> fr(opts.framerate.numerator(), opts.framerate.denominator());
-    return MediaStream("v:local",
-                       av_get_pix_fmt(opts.pixel_format.c_str()),
-                       1 / fr,
-                       opts.width,
-                       opts.height,
-                       0,
-                       fr);
+    return MediaStream("v:local", av_get_pix_fmt(opts.pixel_format.c_str()), 1 / fr, opts.width, opts.height, 0, fr);
 }
 
 void
