@@ -1,18 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3, or (at your option)
- *  any later version.
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #pragma once
 #include "sipaccountbase_config.h"
@@ -20,8 +20,11 @@
 namespace jami {
 constexpr static std::string_view ACCOUNT_TYPE_SIP = "SIP";
 
-struct SipAccountConfig : public SipAccountBaseConfig {
-    SipAccountConfig(const std::string& id = {}, const std::string& path = {}): SipAccountBaseConfig(std::string(ACCOUNT_TYPE_SIP), id, path) {}
+struct SipAccountConfig : public SipAccountBaseConfig
+{
+    SipAccountConfig(const std::string& id = {}, const std::filesystem::path& path = {})
+        : SipAccountBaseConfig(std::string(ACCOUNT_TYPE_SIP), id, path)
+    {}
     void serialize(YAML::Emitter& out) const override;
     void unserialize(const YAML::Node& node) override;
     std::map<std::string, std::string> toMap() const override;
@@ -45,7 +48,7 @@ struct SipAccountConfig : public SipAccountBaseConfig {
     /**
      * interface name on which this account is bound
      */
-    std::string interface {ip_utils::DEFAULT_INTERFACE};
+    std::string interface {dhtnet::ip_utils::DEFAULT_INTERFACE};
 
     /**
      * Determine if STUN public address resolution is required to register this account. In this
@@ -127,4 +130,4 @@ struct SipAccountConfig : public SipAccountBaseConfig {
     void setCredentials(const std::vector<std::map<std::string, std::string>>& creds);
 };
 
-}
+} // namespace jami
