@@ -1,23 +1,19 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #ifdef HAVE_CONFIG_H
@@ -27,12 +23,14 @@
 #include "account.h"
 
 #include "connectivity/sip_utils.h"
-#include "connectivity/ip_utils.h"
-#include "connectivity/turn_cache.h"
 #include "noncopyable.h"
 #include "im/message_engine.h"
 #include "sipaccountbase_config.h"
 
+#include <dhtnet/turn_cache.h>
+#include <dhtnet/ip_utils.h>
+#include <dhtnet/ice_options.h>
+
 #include <array>
 #include <deque>
 #include <map>
@@ -86,10 +84,7 @@ public:
 
     virtual ~SIPAccountBase() noexcept;
 
-    const SipAccountBaseConfig& config() const
-    {
-        return *static_cast<const SipAccountBaseConfig*>(&Account::config());
-    }
+    const SipAccountBaseConfig& config() const { return *static_cast<const SipAccountBaseConfig*>(&Account::config()); }
 
     void loadConfig() override;
 
@@ -143,9 +138,9 @@ public:
      */
     std::string getPublishedAddress() const { return config().publishedIp; }
 
-    IpAddr getPublishedIpAddress(uint16_t family = PF_UNSPEC) const;
+    virtual dhtnet::IpAddr getPublishedIpAddress(uint16_t family = PF_UNSPEC) const;
 
-    void setPublishedAddress(const IpAddr& ip_addr);
+    void setPublishedAddress(const dhtnet::IpAddr& ip_addr);
 
     /**
      * Get a flag which determine the usage in sip headers of either the local
@@ -162,7 +157,7 @@ public:
 
     /**
      * Socket port generators for media
-     * Note: given ports are application wide, a port cannot be given again
+     * Note: given ports are application wide, a port is unable to be given again
      * by any account instances until it's released by the static method
      * releasePort().
      */
@@ -172,7 +167,7 @@ public:
 #endif
     static void releasePort(uint16_t port) noexcept;
 
-    IceTransportOptions getIceOptions() const noexcept;
+    virtual dhtnet::IceTransportOptions getIceOptions() const;
 
     virtual void sendMessage(const std::string& to,
                              const std::string& deviceId,
@@ -196,19 +191,11 @@ public:
         return messageEngine_.sendMessage(to, deviceId, payloads, refreshToken);
     }
 
-    im::MessageStatus getMessageStatus(uint64_t id) const override
-    {
-        return messageEngine_.getStatus(id);
-    }
-
-    bool cancelMessage(uint64_t id) override
-    {
-        return messageEngine_.cancel(id);
-    }
+    im::MessageStatus getMessageStatus(uint64_t id) const override { return messageEngine_.getStatus(id); }
 
     virtual void onTextMessage(const std::string& id,
                                const std::string& from,
-                               const std::string& deviceId,
+                               const std::shared_ptr<dht::crypto::Certificate>& peerCert,
                                const std::map<std::string, std::string>& payloads);
 
     /* Returns true if the username and/or hostname match this account */
@@ -249,7 +236,7 @@ protected:
      * configuration
      *
      */
-    IpAddr publishedIp_[2] {};
+    dhtnet::IpAddr publishedIp_[2] {};
 
     pj_status_t transportStatus_ {PJSIP_SC_TRYING};
     std::string transportError_ {};
@@ -269,12 +256,7 @@ protected:
     static constexpr size_t MAX_WAITING_MESSAGES_SIZE = 1000;
     std::deque<libjami::Message> lastMessages_;
 
-    std::string composingUri_;
-    std::chrono::steady_clock::time_point composingTime_ {
-        std::chrono::steady_clock::time_point::min()};
-    std::shared_ptr<Task> composingTimeout_;
-
-    std::shared_ptr<TurnCache> turnCache_;
+    std::shared_ptr<dhtnet::TurnCache> turnCache_;
 
 private:
     NON_COPYABLE(SIPAccountBase);
