@@ -50,11 +50,10 @@ class Handler
 public:
     Handler(const char* symbol_name)
     {
-        signal_alist
-            = scm_cons(scm_cons(scm_from_utf8_symbol(symbol_name),
-                                scm_cons(scm_from_pointer(static_cast<void*>(&callbacks_), nullptr),
-                                         scm_from_pointer(static_cast<void*>(&mutex_), nullptr))),
-                       signal_alist);
+        signal_alist = scm_cons(scm_cons(scm_from_utf8_symbol(symbol_name),
+                                         scm_cons(scm_from_pointer(static_cast<void*>(&callbacks_), nullptr),
+                                                  scm_from_pointer(static_cast<void*>(&mutex_), nullptr))),
+                                signal_alist);
     }
 
     struct cb_ctx
@@ -147,8 +146,7 @@ on_signal_binding(SCM signal_sym, SCM handler_proc)
 
 template<typename T, typename... Args>
 void
-add_handler(std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>>& handlers,
-            const char* name)
+add_handler(std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>>& handlers, const char* name)
 {
     static Handler<Args...> handler(name);
 
@@ -166,18 +164,14 @@ install_signal_primitives(void*)
 
     std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>> handlers;
 
-    add_handler<libjami::CallSignal::StateChange,
-                const std::string&,
-                const std::string&,
-                const std::string&,
-                signed>(handlers, "state-changed");
+    add_handler<libjami::CallSignal::StateChange, const std::string&, const std::string&, const std::string&, signed>(
+        handlers, "state-changed");
 
     add_handler<libjami::CallSignal::TransferFailed>(handlers, "transfer-failed");
 
     add_handler<libjami::CallSignal::TransferSucceeded>(handlers, "transfer-succeeded");
 
-    add_handler<libjami::CallSignal::RecordPlaybackStopped,
-                const std::string&>(handlers, "record-playback-stopped");
+    add_handler<libjami::CallSignal::RecordPlaybackStopped, const std::string&>(handlers, "record-playback-stopped");
 
     add_handler<libjami::CallSignal::VoiceMailNotify, const std::string&, int32_t, int32_t, int32_t>(
         handlers, "voice-mail-notify");
@@ -188,10 +182,8 @@ install_signal_primitives(void*)
                 const std::string&,
                 const std::map<std::string, std::string>&>(handlers, "incoming-message");
 
-    add_handler<libjami::CallSignal::IncomingCall,
-                const std::string&,
-                const std::string&,
-                const std::string&>(handlers, "incoming-call");
+    add_handler<libjami::CallSignal::IncomingCall, const std::string&, const std::string&, const std::string&>(
+        handlers, "incoming-call");
 
     add_handler<libjami::CallSignal::IncomingCallWithMedia,
                 const std::string&,
@@ -202,34 +194,28 @@ install_signal_primitives(void*)
     add_handler<libjami::CallSignal::MediaChangeRequested,
                 const std::string&,
                 const std::string&,
-                const std::vector<std::map<std::string, std::string>>&>(handlers,
-                                                                        "media-change-requested");
+                const std::vector<std::map<std::string, std::string>>&>(handlers, "media-change-requested");
 
     add_handler<libjami::CallSignal::RecordPlaybackFilepath, const std::string&, const std::string&>(
         handlers, "record-playback-filepath");
 
-    add_handler<libjami::CallSignal::ConferenceCreated,
-                const std::string&,
-                const std::string&,
-                const std::string&>(handlers, "conference-created");
+    add_handler<libjami::CallSignal::ConferenceCreated, const std::string&, const std::string&, const std::string&>(
+        handlers, "conference-created");
 
-    add_handler<libjami::CallSignal::ConferenceChanged,
-                const std::string&,
-                const std::string&,
-                const std::string&>(handlers, "conference-changed");
+    add_handler<libjami::CallSignal::ConferenceChanged, const std::string&, const std::string&, const std::string&>(
+        handlers, "conference-changed");
 
     add_handler<libjami::CallSignal::UpdatePlaybackScale, const std::string&, unsigned, unsigned>(
         handlers, "update-playback-scale");
 
-    add_handler<libjami::CallSignal::ConferenceRemoved, const std::string&, const std::string&>(
-        handlers, "conference-removed");
+    add_handler<libjami::CallSignal::ConferenceRemoved, const std::string&, const std::string&>(handlers,
+                                                                                                "conference-removed");
 
-    add_handler<libjami::CallSignal::RecordingStateChanged, const std::string&, int>(
-        handlers, "recording-state-changed");
+    add_handler<libjami::CallSignal::RecordingStateChanged, const std::string&, int>(handlers,
+                                                                                     "recording-state-changed");
 
-    add_handler<libjami::CallSignal::RtcpReportReceived,
-                const std::string&,
-                const std::map<std::string, int>&>(handlers, "rtcp-report-received");
+    add_handler<libjami::CallSignal::RtcpReportReceived, const std::string&, const std::map<std::string, int>&>(
+        handlers, "rtcp-report-received");
 
     add_handler<libjami::CallSignal::PeerHold, const std::string&, bool>(handlers, "peer-hold");
 
@@ -237,31 +223,24 @@ install_signal_primitives(void*)
 
     add_handler<libjami::CallSignal::AudioMuted, const std::string&, bool>(handlers, "audio-muted");
 
-    add_handler<libjami::CallSignal::SmartInfo,
-                const std::map<std::string, std::string>&>(handlers, "smart-info");
+    add_handler<libjami::CallSignal::SmartInfo, const std::map<std::string, std::string>&>(handlers, "smart-info");
 
-    add_handler<libjami::CallSignal::ConnectionUpdate, const std::string&, int>(
-        handlers, "connection-update");
+    add_handler<libjami::CallSignal::ConnectionUpdate, const std::string&, int>(handlers, "connection-update");
 
     add_handler<libjami::CallSignal::OnConferenceInfosUpdated,
                 const std::string&,
-                const std::vector<std::map<std::string, std::string>>&>(handlers,
-                                                                        "conference-infos-updated");
+                const std::vector<std::map<std::string, std::string>>&>(handlers, "conference-infos-updated");
 
-    add_handler<libjami::CallSignal::RemoteRecordingChanged,
-                const std::string&,
-                const std::string&,
-                bool>(handlers, "remote-recording-changed");
+    add_handler<libjami::CallSignal::RemoteRecordingChanged, const std::string&, const std::string&, bool>(
+        handlers, "remote-recording-changed");
 
     add_handler<libjami::CallSignal::MediaNegotiationStatus,
                 const std::string&,
                 const std::string&,
-                const std::vector<std::map<std::string, std::string>>&>(handlers,
-                                                                        "media-negotiation-status");
+                const std::vector<std::map<std::string, std::string>>&>(handlers, "media-negotiation-status");
 
     /* Configuration */
-    add_handler<libjami::ConfigurationSignal::VolumeChanged, const std::string&, double>(
-        handlers, "volume-changed");
+    add_handler<libjami::ConfigurationSignal::VolumeChanged, const std::string&, double>(handlers, "volume-changed");
 
     add_handler<libjami::ConfigurationSignal::Error, int>(handlers, "configuration-error");
 
@@ -271,8 +250,7 @@ install_signal_primitives(void*)
                 const std::string&,
                 const std::map<std::string, std::string>&>(handlers, "account-details-changed");
 
-    add_handler<libjami::ConfigurationSignal::StunStatusFailed,
-                const std::string&>(handlers, "stun-status-failed");
+    add_handler<libjami::ConfigurationSignal::StunStatusFailed, const std::string&>(handlers, "stun-status-failed");
 
     add_handler<libjami::ConfigurationSignal::RegistrationStateChanged,
                 const std::string&,
@@ -297,10 +275,8 @@ install_signal_primitives(void*)
                 const std::string&,
                 int>(handlers, "account-message-status-changed");
 
-    add_handler<libjami::ConfigurationSignal::ProfileReceived,
-                const std::string&,
-                const std::string&,
-                const std::string&>(handlers, "profile-received");
+    add_handler<libjami::ConfigurationSignal::ProfileReceived, const std::string&, const std::string&, const std::string&>(
+        handlers, "profile-received");
 
     add_handler<libjami::ConfigurationSignal::ComposingStatusChanged,
                 const std::string&,
@@ -315,20 +291,14 @@ install_signal_primitives(void*)
                 const std::vector<uint8_t>&,
                 time_t>(handlers, "incoming-trust-request");
 
-    add_handler<libjami::ConfigurationSignal::ContactAdded,
-                const std::string&,
-                const std::string&,
-                bool>(handlers, "contact-added");
+    add_handler<libjami::ConfigurationSignal::ContactAdded, const std::string&, const std::string&, bool>(
+        handlers, "contact-added");
 
-    add_handler<libjami::ConfigurationSignal::ContactRemoved,
-                const std::string&,
-                const std::string&,
-                bool>(handlers, "contact-removed");
+    add_handler<libjami::ConfigurationSignal::ContactRemoved, const std::string&, const std::string&, bool>(
+        handlers, "contact-removed");
 
-    add_handler<libjami::ConfigurationSignal::NameRegistrationEnded,
-                const std::string&,
-                int,
-                const std::string&>(handlers, "name-registration-ended");
+    add_handler<libjami::ConfigurationSignal::NameRegistrationEnded, const std::string&, int, const std::string&>(
+        handlers, "name-registration-ended");
 
     add_handler<libjami::ConfigurationSignal::KnownDevicesChanged,
                 const std::string&,
@@ -344,34 +314,28 @@ install_signal_primitives(void*)
                 const std::string&,
                 int,
                 const std::string&,
-                const std::vector<std::map<std::string, std::string>>&>(handlers,
-                                                                        "user-search-ended");
+                const std::vector<std::map<std::string, std::string>>&>(handlers, "user-search-ended");
 
-    add_handler<libjami::ConfigurationSignal::CertificatePinned,
-                const std::string&>(handlers, "certificate-pinned");
+    add_handler<libjami::ConfigurationSignal::CertificatePinned, const std::string&>(handlers, "certificate-pinned");
 
-    add_handler<libjami::ConfigurationSignal::CertificatePathPinned,
-                const std::string&,
-                const std::vector<std::string>&>(handlers, "certificate-path-pinned");
+    add_handler<libjami::ConfigurationSignal::CertificatePathPinned, const std::string&, const std::vector<std::string>&>(
+        handlers, "certificate-path-pinned");
 
-    add_handler<libjami::ConfigurationSignal::CertificateExpired,
-                const std::string&>(handlers, "certificate-expired");
+    add_handler<libjami::ConfigurationSignal::CertificateExpired, const std::string&>(handlers, "certificate-expired");
 
     add_handler<libjami::ConfigurationSignal::CertificateStateChanged,
                 const std::string&,
                 const std::string&,
                 const std::string&>(handlers, "certificate-state-changed");
 
-    add_handler<libjami::ConfigurationSignal::MediaParametersChanged,
-                const std::string&>(handlers, "media-parameters-changed");
+    add_handler<libjami::ConfigurationSignal::MediaParametersChanged, const std::string&>(handlers,
+                                                                                          "media-parameters-changed");
 
     add_handler<libjami::ConfigurationSignal::MigrationEnded, const std::string&, const std::string&>(
         handlers, "migration-ended");
 
-    add_handler<libjami::ConfigurationSignal::DeviceRevocationEnded,
-                const std::string&,
-                const std::string&,
-                int>(handlers, "device-revocation-ended");
+    add_handler<libjami::ConfigurationSignal::DeviceRevocationEnded, const std::string&, const std::string&, int>(
+        handlers, "device-revocation-ended");
 
     add_handler<libjami::ConfigurationSignal::AccountProfileReceived,
                 const std::string&,
@@ -383,30 +347,23 @@ install_signal_primitives(void*)
                 std::vector<int32_t>*>(handlers, "get-hardware-audio-format");
 #endif
 #if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
-    add_handler<libjami::ConfigurationSignal::GetAppDataPath,
-                const std::string&,
-                std::vector<std::string>*>(handlers, "get-app-data-path");
+    add_handler<libjami::ConfigurationSignal::GetAppDataPath, const std::string&, std::vector<std::string>*>(
+        handlers, "get-app-data-path");
 
-    add_handler<libjami::ConfigurationSignal::GetDeviceName,
-                std::vector<std::string>*>(handlers, "get-device-name");
+    add_handler<libjami::ConfigurationSignal::GetDeviceName, std::vector<std::string>*>(handlers, "get-device-name");
 #endif
-    add_handler<libjami::ConfigurationSignal::HardwareDecodingChanged,
-                bool>(handlers, "hardware-decoding-changed");
+    add_handler<libjami::ConfigurationSignal::HardwareDecodingChanged, bool>(handlers, "hardware-decoding-changed");
 
-    add_handler<libjami::ConfigurationSignal::HardwareEncodingChanged,
-                bool>(handlers, "hardware-encoding-changed");
+    add_handler<libjami::ConfigurationSignal::HardwareEncodingChanged, bool>(handlers, "hardware-encoding-changed");
 
-    add_handler<libjami::ConfigurationSignal::MessageSend, const std::string&>(handlers,
-                                                                               "message-send");
+    add_handler<libjami::ConfigurationSignal::MessageSend, const std::string&>(handlers, "message-send");
 
     /* Presence */
     add_handler<libjami::PresenceSignal::NewServerSubscriptionRequest,
                 const std::string&>(handlers, "new-server-subscription-request");
 
-    add_handler<libjami::PresenceSignal::ServerError,
-                const std::string&,
-                const std::string&,
-                const std::string&>(handlers, "server-error");
+    add_handler<libjami::PresenceSignal::ServerError, const std::string&, const std::string&, const std::string&>(
+        handlers, "server-error");
 
     add_handler<libjami::PresenceSignal::NewBuddyNotification,
                 const std::string&,
@@ -420,16 +377,13 @@ install_signal_primitives(void*)
                 int,
                 const std::string&>(handlers, "nearby-peer-notification");
 
-    add_handler<libjami::PresenceSignal::SubscriptionStateChanged,
-                const std::string&,
-                const std::string&,
-                int>(handlers, "subscription-state-changed");
+    add_handler<libjami::PresenceSignal::SubscriptionStateChanged, const std::string&, const std::string&, int>(
+        handlers, "subscription-state-changed");
 
     /* Audio */
     add_handler<libjami::AudioSignal::DeviceEvent>(handlers, "audio-device-event");
 
-    add_handler<libjami::AudioSignal::AudioMeter, const std::string&, float>(handlers,
-                                                                             "audio-meter");
+    add_handler<libjami::AudioSignal::AudioMeter, const std::string&, float>(handlers, "audio-meter");
 
     /* DataTransfer */
     add_handler<libjami::DataTransferSignal::DataTransferEvent,
@@ -441,19 +395,14 @@ install_signal_primitives(void*)
 
 #ifdef ENABLE_VIDEO
     /* MediaPlayer */
-    add_handler<libjami::MediaPlayerSignal::FileOpened,
-                const std::string&,
-                std::map<std::string, std::string>>(handlers, "media-file-opened");
+    add_handler<libjami::MediaPlayerSignal::FileOpened, const std::string&, std::map<std::string, std::string>>(
+        handlers, "media-file-opened");
 
     /* Video */
     add_handler<libjami::VideoSignal::DeviceEvent>(handlers, "device-event");
 
-    add_handler<libjami::VideoSignal::DecodingStarted,
-                const std::string&,
-                const std::string&,
-                int,
-                int,
-                bool>(handlers, "video-decoding-started");
+    add_handler<libjami::VideoSignal::DecodingStarted, const std::string&, const std::string&, int, int, bool>(
+        handlers, "video-decoding-started");
 
     add_handler<libjami::VideoSignal::DecodingStopped, const std::string&, const std::string&, bool>(
         handlers, "video-decoding-stopped");
@@ -465,29 +414,21 @@ install_signal_primitives(void*)
                 std::vector<unsigned>*,
                 std::vector<unsigned>*>(handlers, "video-get-camera-info");
 
-    add_handler<libjami::VideoSignal::SetParameters,
-                const std::string&,
-                const int,
-                const int,
-                const int,
-                const int>(handlers, "video-set-parameters");
+    add_handler<libjami::VideoSignal::SetParameters, const std::string&, const int, const int, const int, const int>(
+        handlers, "video-set-parameters");
 
     add_handler<libjami::VideoSignal::RequestKeyFrame>(handlers, "video-request-key-frame");
 
-    add_handler<libjami::VideoSignal::SetBitrate, const std::string&, const int>(
-        handlers, "video-set-bitrate");
+    add_handler<libjami::VideoSignal::SetBitrate, const std::string&, const int>(handlers, "video-set-bitrate");
 
 #endif
-    add_handler<libjami::VideoSignal::StartCapture, const std::string&>(handlers,
-                                                                        "video-start-capture");
+    add_handler<libjami::VideoSignal::StartCapture, const std::string&>(handlers, "video-start-capture");
 
     add_handler<libjami::VideoSignal::StopCapture>(handlers, "video-stop-capture");
 
-    add_handler<libjami::VideoSignal::DeviceAdded, const std::string&>(handlers,
-                                                                       "video-device-added");
+    add_handler<libjami::VideoSignal::DeviceAdded, const std::string&>(handlers, "video-device-added");
 
-    add_handler<libjami::VideoSignal::ParametersChanged,
-                const std::string&>(handlers, "video-parameters-changed");
+    add_handler<libjami::VideoSignal::ParametersChanged, const std::string&>(handlers, "video-parameters-changed");
 #endif
 
     /* Conversation */
@@ -513,17 +454,14 @@ install_signal_primitives(void*)
                 const std::string&,
                 std::map<std::string, std::string>>(handlers, "conversation-request-received");
 
-    add_handler<libjami::ConversationSignal::ConversationRequestDeclined,
-                const std::string&,
-                const std::string&>(handlers, "conversation-request-declined");
+    add_handler<libjami::ConversationSignal::ConversationRequestDeclined, const std::string&, const std::string&>(
+        handlers, "conversation-request-declined");
 
-    add_handler<libjami::ConversationSignal::ConversationReady,
-                const std::string&,
-                const std::string&>(handlers, "conversation-ready");
+    add_handler<libjami::ConversationSignal::ConversationReady, const std::string&, const std::string&>(
+        handlers, "conversation-ready");
 
-    add_handler<libjami::ConversationSignal::ConversationRemoved,
-                const std::string&,
-                const std::string&>(handlers, "conversation-removed");
+    add_handler<libjami::ConversationSignal::ConversationRemoved, const std::string&, const std::string&>(
+        handlers, "conversation-removed");
 
     add_handler<libjami::ConversationSignal::ConversationMemberEvent,
                 const std::string&,
