@@ -336,7 +336,7 @@ SwarmMessageSpread::distribution()
     std::vector<unsigned> dist(10);
     int mean = 0;
     for (const auto& sm : swarmManagers) {
-        auto val = sm.second->getRoutingTable().getRoutingTableNodeCount();
+        auto val = sm.second->getRoutingTable().getNodeCount();
         if (dist.size() <= val)
             dist.resize(val + 1);
 
