@@ -1,8 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Savoir-faire Linux Inc.
- * Author : Edric Ladent Milaret<edric.ladent - milaret @savoirfairelinux.com>
- * Author : Andreas Traczyk<andreas.traczyk @savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +22,11 @@
 #include "api/devicemodel.h"
 
 #ifdef Q_OS_LINUX
+#include "screencastportal.h"
 #include "xrectsel.h"
+#ifndef ENABLE_LIBWRAP
+#include <sys/prctl.h>
+#endif
 #endif
 
 #include <QtConcurrent/QtConcurrent>
@@ -40,24 +41,21 @@ AvAdapter::AvAdapter(LRCInstance* instance, QObject* parent)
     , rendererInformationListModel_(std::make_unique<RendererInformationListModel>())
 {
     set_renderersInfoList(QVariant::fromValue(rendererInformationListModel_.get()));
-    connect(&lrcInstance_->avModel(),
-            &lrc::api::AVModel::audioDeviceEvent,
-            this,
-            &AvAdapter::onAudioDeviceEvent);
+    connect(&lrcInstance_->avModel(), &lrc::api::AVModel::audioDeviceEvent, this, &AvAdapter::onAudioDeviceEvent);
     // QueuedConnection mandatory to avoid deadlock
     connect(&lrcInstance_->avModel(),
             &lrc::api::AVModel::rendererStarted,
             this,
             &AvAdapter::onRendererStarted,
             Qt::QueuedConnection);
-    connect(&lrcInstance_->avModel(),
-            &lrc::api::AVModel::rendererStopped,
+    connect(&lrcInstance_->avModel(), &lrc::api::AVModel::rendererStopped, this, &AvAdapter::onRendererStopped);
+    connect(&lrcInstance_->avModel(), &lrc::api::AVModel::onRendererFpsChange, this, &AvAdapter::updateRenderersFPSInfo);
+#ifdef Q_OS_LINUX
+    connect(&lrcInstance_->behaviorController(),
+            &BehaviorController::callStatusChanged,
             this,
-            &AvAdapter::onRendererStopped);
-    connect(&lrcInstance_->avModel(),
-            &lrc::api::AVModel::onRendererFpsChange,
-            this,
-            &AvAdapter::updateRenderersFPSInfo);
+            &AvAdapter::onCallStatusChanged);
+#endif
 }
 
 // The top left corner of primary screen is (0, 0).
@@ -79,14 +77,12 @@ AvAdapter::getAllScreensBoundingRect()
 
         if (screenRect.y() < 0 && p1.y() < abs(screenRect.y()))
             p1.setY(abs(screenRect.y()));
-        else if (screenRect.y() >= 0
-                 && p1.x() < screenRect.y() + screenRect.height() * devicePixelRatio)
+        else if (screenRect.y() >= 0 && p1.x() < screenRect.y() + screenRect.height() * devicePixelRatio)
             p1.setX(screenRect.y() + screenRect.height() * devicePixelRatio);
 
         if (screenRect.x() < 0 && p0.y() < abs(screenRect.x()))
             p0.setY(abs(screenRect.x()));
-        else if (screenRect.x() >= 0
-                 && p0.x() < screenRect.x() + screenRect.width() * devicePixelRatio)
+        else if (screenRect.x() >= 0 && p0.x() < screenRect.x() + screenRect.width() * devicePixelRatio)
             p0.setX(screenRect.x() + screenRect.width() * devicePixelRatio);
     }
 
@@ -107,18 +103,105 @@ AvAdapter::shareEntireScreen(int screenNumber)
     rect.moveTop(0);
 #endif
 
-    auto resource = lrcInstance_->getCurrentCallModel()
-                        ->getDisplay(getScreenNumber(screenNumber),
-                                     rect.x(),
-                                     rect.y(),
-                                     rect.width() * screen->devicePixelRatio(),
-                                     rect.height() * screen->devicePixelRatio());
+    auto resource = lrcInstance_->getCurrentCallModel()->getDisplay(getScreenNumber(screenNumber),
+                                                                    rect.x(),
+                                                                    rect.y(),
+                                                                    rect.width() * screen->devicePixelRatio(),
+                                                                    rect.height() * screen->devicePixelRatio());
     auto callId = lrcInstance_->getCurrentCallId();
     muteCamera_ = !isCapturing();
-    lrcInstance_->getCurrentCallModel()
-        ->addMedia(callId, resource, lrc::api::CallModel::MediaRequestType::SCREENSHARING);
+    lrcInstance_->getCurrentCallModel()->addMedia(callId,
+                                                  resource,
+                                                  lrc::api::CallModel::MediaRequestType::SCREENSHARING);
 }
 
+#ifdef Q_OS_LINUX
+static std::map<QString, std::unique_ptr<ScreenCastPortal>> callPortal;
+
+void
+AvAdapter::onCallStatusChanged(const QString& accountId, const QString& callId)
+{
+    auto& accInfo = lrcInstance_->accountModel().getAccountInfo(accountId);
+    auto& callModel = accInfo.callModel;
+    const auto call = callModel->getCall(callId);
+
+    if (call.status == lrc::api::call::Status::ENDED) {
+        closePortal(callId);
+    }
+}
+
+void
+AvAdapter::closePortal(const QString& callId)
+{
+    if (callPortal.count(callId)) {
+        lrcInstance_->avModel().stopPreview(callPortal[callId]->videoInputId);
+        callPortal.erase(callId);
+    }
+}
+
+void
+AvAdapter::shareWayland(bool entireScreen)
+{
+    QString callId = lrcInstance_->getCurrentCallId();
+    closePortal(callId);
+
+    PortalCaptureType captureType = entireScreen ? PortalCaptureType::SCREEN : PortalCaptureType::WINDOW;
+    auto portal = std::make_unique<ScreenCastPortal>(captureType);
+
+    int err = portal->getPipewireFd();
+    if (err == EACCES) {
+        qInfo() << "Unable to share screen: permission denied";
+        return;
+    } else if (err != 0) {
+        qWarning() << "Failed to get PipeWire fd. Error code:" << err;
+        return;
+    }
+    QString resource = QString("%1%2pipewire pid:%3 fd:%4 node:%5")
+                           .arg(libjami::Media::VideoProtocolPrefix::DISPLAY)
+                           .arg(libjami::Media::VideoProtocolPrefix::SEPARATOR)
+                           .arg(getpid())
+                           .arg(portal->pipewireFd)
+                           .arg(portal->pipewireNode);
+#ifndef ENABLE_LIBWRAP
+    // If the daemon is running as a separate process, then it is unable to directly use the
+    // PipeWire file descriptor opened by the client, so it will attempt to duplicate
+    // it using the pidfd_getfd system call. This requires the daemon process to have
+    // ptrace permission on the client process. On some systems, this will be true by
+    // default (as long as the client and daemon processes have the same uid), but it
+    // may not be if the Yama Linux Security Module is used. The call to prctl below
+    // will grant permission if the Yama LSM is enabled and set to mode 1.
+    //
+    // References:
+    // https://man7.org/linux/man-pages/man2/pidfd_getfd.2.html
+    // https://man7.org/linux/man-pages/man2/prctl.2.html
+    // https://github.com/torvalds/linux/blob/master/Documentation/admin-guide/LSM/Yama.rst
+    prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY);
+#endif
+    // We open the video input here (instead of letting the daemon do it) to ensure
+    // that the daemon doesn't try to restart it while we still need it, since this
+    // would require getting a new file descriptor for PipeWire.
+    portal->videoInputId = lrcInstance_->avModel().startPreview(resource);
+
+    callPortal[callId] = std::move(portal);
+    muteCamera_ = !isCapturing();
+    lrcInstance_->getCurrentCallModel()->addMedia(callId,
+                                                  resource,
+                                                  lrc::api::CallModel::MediaRequestType::SCREENSHARING);
+}
+
+void
+AvAdapter::shareEntireScreenWayland()
+{
+    shareWayland(true);
+}
+
+void
+AvAdapter::shareWindowWayland()
+{
+    shareWayland(false);
+}
+#endif // Q_OS_LINUX
+
 void
 AvAdapter::shareAllScreens()
 {
@@ -131,8 +214,9 @@ AvAdapter::shareAllScreens()
                                                                     arrangementRect.height());
     auto callId = lrcInstance_->getCurrentCallId();
     muteCamera_ = !isCapturing();
-    lrcInstance_->getCurrentCallModel()
-        ->addMedia(callId, resource, lrc::api::CallModel::MediaRequestType::SCREENSHARING);
+    lrcInstance_->getCurrentCallModel()->addMedia(callId,
+                                                  resource,
+                                                  lrc::api::CallModel::MediaRequestType::SCREENSHARING);
 }
 
 void
@@ -195,8 +279,26 @@ AvAdapter::shareFile(const QString& filePath)
     auto callId = lrcInstance_->getCurrentCallId();
     if (!callId.isEmpty()) {
         muteCamera_ = !isCapturing();
-        lrcInstance_->getCurrentCallModel()
-            ->addMedia(callId, filePath, lrc::api::CallModel::MediaRequestType::FILESHARING);
+        auto resource = QString("%1%2%3")
+                            .arg(libjami::Media::VideoProtocolPrefix::FILE)
+                            .arg(libjami::Media::VideoProtocolPrefix::SEPARATOR)
+                            .arg(QUrl(filePath).toLocalFile());
+
+        Utils::oneShotConnect(&lrcInstance_->avModel(),
+                              &lrc::api::AVModel::fileOpened,
+                              this,
+                              [this, callId, filePath, resource](bool hasAudio, bool hasVideo) {
+                                  lrcInstance_->avModel().setAutoRestart(resource, true);
+                                  lrcInstance_->getCurrentCallModel()
+                                      ->addMedia(callId,
+                                                 filePath,
+                                                 lrc::api::CallModel::MediaRequestType::FILESHARING,
+                                                 false,
+                                                 hasAudio);
+                                  lrcInstance_->avModel().pausePlayer(resource, false);
+                              });
+
+        lrcInstance_->avModel().createMediaPlayer(resource);
     }
 }
 
@@ -217,8 +319,9 @@ AvAdapter::shareScreenArea(unsigned x, unsigned y, unsigned width, unsigned heig
                                                                         width < 128 ? 128 : width,
                                                                         height < 128 ? 128 : height);
         auto callId = lrcInstance_->getCurrentCallId();
-        lrcInstance_->getCurrentCallModel()
-            ->addMedia(callId, resource, lrc::api::CallModel::MediaRequestType::SCREENSHARING);
+        lrcInstance_->getCurrentCallModel()->addMedia(callId,
+                                                      resource,
+                                                      lrc::api::CallModel::MediaRequestType::SCREENSHARING);
     });
 #else
     auto resource = lrcInstance_->getCurrentCallModel()->getDisplay(getScreenNumber(),
@@ -227,24 +330,26 @@ AvAdapter::shareScreenArea(unsigned x, unsigned y, unsigned width, unsigned heig
                                                                     width < 128 ? 128 : width,
                                                                     height < 128 ? 128 : height);
     auto callId = lrcInstance_->getCurrentCallId();
-    lrcInstance_->getCurrentCallModel()
-        ->addMedia(callId, resource, lrc::api::CallModel::MediaRequestType::SCREENSHARING);
+    lrcInstance_->getCurrentCallModel()->addMedia(callId,
+                                                  resource,
+                                                  lrc::api::CallModel::MediaRequestType::SCREENSHARING);
 #endif
 }
 
 void
-AvAdapter::shareWindow(const QString& windowProcessId, const QString& windowId)
+AvAdapter::shareWindow(const QString& windowProcessId, const QString& windowId, const int fps)
 {
-    auto resource = lrcInstance_->getCurrentCallModel()->getDisplay(windowProcessId, windowId);
+    auto resource = lrcInstance_->getCurrentCallModel()->getDisplay(windowProcessId, windowId, fps);
     auto callId = lrcInstance_->getCurrentCallId();
 
     muteCamera_ = !isCapturing();
-    lrcInstance_->getCurrentCallModel()
-        ->addMedia(callId, resource, lrc::api::CallModel::MediaRequestType::SCREENSHARING);
+    lrcInstance_->getCurrentCallModel()->addMedia(callId,
+                                                  resource,
+                                                  lrc::api::CallModel::MediaRequestType::SCREENSHARING);
 }
 
 QString
-AvAdapter::getSharingResource(int screenId, const QString& windowProcessId, const QString& windowId)
+AvAdapter::getSharingResource(int screenId, const QString& windowProcessId, const QString& windowId, const int fps)
 {
     if (screenId == -1) {
         const auto arrangementRect = getAllScreensBoundingRect();
@@ -270,12 +375,10 @@ AvAdapter::getSharingResource(int screenId, const QString& windowProcessId, cons
         return lrcInstance_->getCurrentCallModel()->getDisplay(getScreenNumber(screenId),
                                                                rect.x(),
                                                                rect.y(),
-                                                               rect.width()
-                                                                   * screen->devicePixelRatio(),
-                                                               rect.height()
-                                                                   * screen->devicePixelRatio());
+                                                               rect.width() * screen->devicePixelRatio(),
+                                                               rect.height() * screen->devicePixelRatio());
     } else if (!windowId.isEmpty()) {
-        return lrcInstance_->getCurrentCallModel()->getDisplay(windowProcessId, windowId);
+        return lrcInstance_->getCurrentCallModel()->getDisplay(windowProcessId, windowId, fps);
     }
 
     return "";
@@ -293,21 +396,24 @@ void
 AvAdapter::stopSharing(const QString& source)
 {
     auto callId = lrcInstance_->getCurrentCallId();
+#ifdef Q_OS_LINUX
+    closePortal(callId);
+#endif
     if (!source.isEmpty() && !callId.isEmpty()) {
         if (source.startsWith(libjami::Media::VideoProtocolPrefix::DISPLAY)) {
             qDebug() << "Stopping display: " << source;
-            lrcInstance_->getCurrentCallModel()
-                ->removeMedia(callId,
-                              libjami::Media::Details::MEDIA_TYPE_VIDEO,
-                              libjami::Media::VideoProtocolPrefix::DISPLAY,
-                              muteCamera_);
+            lrcInstance_->getCurrentCallModel()->removeMedia(callId,
+                                                             libjami::Media::Details::MEDIA_TYPE_VIDEO,
+                                                             libjami::Media::VideoProtocolPrefix::DISPLAY,
+                                                             muteCamera_,
+                                                             true);
         } else {
             qDebug() << "Stopping file: " << source;
-            lrcInstance_->getCurrentCallModel()
-                ->removeMedia(callId,
-                              libjami::Media::Details::MEDIA_TYPE_VIDEO,
-                              libjami::Media::VideoProtocolPrefix::FILE,
-                              muteCamera_);
+            lrcInstance_->getCurrentCallModel()->removeMedia(callId,
+                                                             libjami::Media::Details::MEDIA_TYPE_VIDEO,
+                                                             libjami::Media::VideoProtocolPrefix::FILE,
+                                                             muteCamera_,
+                                                             true);
         }
     }
 }
@@ -381,10 +487,8 @@ AvAdapter::isCapturing() const
         auto callModel = lrcInstance_->getCurrentCallModel();
         auto call = callModel->getCall(callId);
         for (const auto& m : call.mediaList) {
-            if (m[libjami::Media::MediaAttributeKey::SOURCE].startsWith(
-                    libjami::Media::VideoProtocolPrefix::CAMERA)
-                && m[libjami::Media::MediaAttributeKey::MEDIA_TYPE]
-                       == libjami::Media::Details::MEDIA_TYPE_VIDEO)
+            if (m[libjami::Media::MediaAttributeKey::SOURCE].startsWith(libjami::Media::VideoProtocolPrefix::CAMERA)
+                && m[libjami::Media::MediaAttributeKey::MEDIA_TYPE] == libjami::Media::Details::MEDIA_TYPE_VIDEO)
                 return m[libjami::Media::MediaAttributeKey::MUTED] == FALSE_STR;
         }
         return false;
@@ -402,10 +506,8 @@ AvAdapter::hasCamera() const
         auto call = callModel->getCall(callId);
         // TODO enum
         for (const auto& m : call.mediaList) {
-            if (m[libjami::Media::MediaAttributeKey::SOURCE].startsWith(
-                    libjami::Media::VideoProtocolPrefix::CAMERA)
-                && m[libjami::Media::MediaAttributeKey::MEDIA_TYPE]
-                       == libjami::Media::Details::MEDIA_TYPE_VIDEO)
+            if (m[libjami::Media::MediaAttributeKey::SOURCE].startsWith(libjami::Media::VideoProtocolPrefix::CAMERA)
+                && m[libjami::Media::MediaAttributeKey::MEDIA_TYPE] == libjami::Media::Details::MEDIA_TYPE_VIDEO)
                 return true;
         }
         return false;
@@ -484,8 +586,7 @@ AvAdapter::setRendererInfo()
 {
     auto& avModel = lrcInstance_->avModel();
     for (auto rendererInfo : avModel.getRenderersInfo()) {
-        rendererInformationListModel_->addElement(
-            qMakePair(rendererInfo["RENDERER_ID"], rendererInfo));
+        rendererInformationListModel_->addElement(qMakePair(rendererInfo["RENDERER_ID"], rendererInfo));
     }
 }
 
