@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Savoir-faire Linux Inc.
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,11 +19,12 @@
 
 #include "qmladapterbase.h"
 #include "smartlistmodel.h"
-#include "conversationlistmodel.h"
 
 #include <QObject>
 #include <QSortFilterProxyModel>
 #include <QString>
+#include <QQmlEngine>   // QML registration
+#include <QApplication> // QML registration
 
 class LRCInstance;
 
@@ -79,8 +79,14 @@ private:
 class ContactAdapter final : public QmlAdapterBase
 {
     Q_OBJECT
+    QML_SINGLETON
 
 public:
+    static ContactAdapter* create(QQmlEngine*, QJSEngine*)
+    {
+        return new ContactAdapter(qApp->property("LRCInstance").value<LRCInstance*>());
+    }
+
     explicit ContactAdapter(LRCInstance* instance, QObject* parent = nullptr);
     ~ContactAdapter() = default;
 
@@ -107,6 +113,5 @@ private:
 
     QStringList defaultModerators_;
 
-    bool hasDifferentMembers(const VectorString& currentMembers,
-                             const VectorString& convMembers) const;
+    bool hasDifferentMembers(const VectorString& currentMembers, const VectorString& convMembers) const;
 };
