@@ -1,7 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Savoir-faire Linux Inc.
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +19,11 @@
 
 #include "qtutils.h"
 #include "systemtray.h"
-#include "qmlregister.h"
+
+#ifdef Q_OS_LINUX
+#include <namedirectory.h>
+#endif
+#include <api/contact.h>
 
 #include <QApplication>
 #include <QJsonObject>
@@ -30,18 +32,21 @@ using namespace lrc::api;
 
 ConversationsAdapter::ConversationsAdapter(SystemTray* systemTray,
                                            LRCInstance* instance,
+                                           ConversationListProxyModel* convProxyModel,
+                                           SelectableListProxyModel* searchProxyModel,
                                            QObject* parent)
     : QmlAdapterBase(instance, parent)
     , systemTray_(systemTray)
     , convSrcModel_(new ConversationListModel(lrcInstance_))
-    , convModel_(new ConversationListProxyModel(convSrcModel_.get()))
+    , convModel_(convProxyModel)
     , searchSrcModel_(new SearchResultsListModel(lrcInstance_))
-    , searchModel_(new SelectableListProxyModel(searchSrcModel_.get()))
+    , searchModel_(searchProxyModel)
 {
-    QML_REGISTERSINGLETONTYPE_POBJECT(NS_MODELS, convModel_.get(), "ConversationListModel");
-    QML_REGISTERSINGLETONTYPE_POBJECT(NS_MODELS, searchModel_.get(), "SearchResultsListModel");
+    convModel_->bindSourceModel(convSrcModel_.get());
+    searchModel_->bindSourceModel(searchSrcModel_.get());
 
-    new SelectableListProxyGroupModel({convModel_.data(), searchModel_.data()}, this);
+    set_convListProxyModel(QVariant::fromValue(convModel_));
+    set_searchListProxyModel(QVariant::fromValue(searchModel_));
 
     // this will trigger when the invite filter tab is selected
     connect(this, &ConversationsAdapter::filterRequestsChanged, [this]() {
@@ -85,18 +90,21 @@ ConversationsAdapter::ConversationsAdapter(SystemTray* systemTray,
     // notification responses
     connect(systemTray_,
             &SystemTray::openConversationActivated,
+            this,
             [this](const QString& accountId, const QString& convUid) {
                 Q_EMIT lrcInstance_->notificationClicked();
                 lrcInstance_->selectConversation(convUid, accountId);
             });
     connect(systemTray_,
             &SystemTray::acceptPendingActivated,
+            this,
             [this](const QString& accountId, const QString& convUid) {
                 auto& accInfo = lrcInstance_->getAccountInfo(accountId);
                 accInfo.conversationModel->acceptConversationRequest(convUid);
             });
     connect(systemTray_,
             &SystemTray::refusePendingActivated,
+            this,
             [this](const QString& accountId, const QString& convUid) {
                 auto& accInfo = lrcInstance_->getAccountInfo(accountId);
                 accInfo.conversationModel->removeConversation(convUid);
@@ -106,32 +114,30 @@ ConversationsAdapter::ConversationsAdapter(SystemTray* systemTray,
     connect(&lrcInstance_->behaviorController(),
             &BehaviorController::newUnreadInteraction,
             this,
-            &ConversationsAdapter::onNewUnreadInteraction,
-            Qt::UniqueConnection);
+            &ConversationsAdapter::onNewUnreadInteraction);
 
     connect(&lrcInstance_->behaviorController(),
             &BehaviorController::newReadInteraction,
             this,
-            &ConversationsAdapter::onNewReadInteraction,
-            Qt::UniqueConnection);
+            &ConversationsAdapter::onNewReadInteraction);
 
     connect(&lrcInstance_->behaviorController(),
             &BehaviorController::newTrustRequest,
             this,
-            &ConversationsAdapter::onNewTrustRequest,
-            Qt::UniqueConnection);
+            &ConversationsAdapter::onNewTrustRequest);
 
     connect(&lrcInstance_->behaviorController(),
             &BehaviorController::trustRequestTreated,
             this,
-            &ConversationsAdapter::onTrustRequestTreated,
-            Qt::UniqueConnection);
+            &ConversationsAdapter::onTrustRequestTreated);
+
+    connect(lrcInstance_, &LRCInstance::currentAccountIdChanged, this, &ConversationsAdapter::onCurrentAccountIdChanged);
 
     connect(lrcInstance_,
-            &LRCInstance::currentAccountIdChanged,
+            &LRCInstance::currentAccountRemoved,
             this,
-            &ConversationsAdapter::onCurrentAccountIdChanged,
-            Qt::UniqueConnection);
+            &ConversationsAdapter::onCurrentAccountRemoved,
+            Qt::DirectConnection);
 
     connectConversationModel();
 }
@@ -162,11 +168,20 @@ ConversationsAdapter::onNewUnreadInteraction(const QString& accountId,
         if (interaction.authorUri == accountInfo.profileInfo.uri)
             return;
         auto from = accountInfo.contactModel->bestNameForContact(interaction.authorUri);
-        auto to = lrcInstance_->accountModel().bestNameForAccount(accountId);
-        auto body_ = interaction.body;
+        QString displayedString;
 
-        if (interaction.type == interaction::Type::DATA_TRANSFER) {
-            body_ = interaction.commit.value("displayName");
+        // Add special handling for member events
+        if (interaction.type == interaction::Type::CONTACT) {
+            auto action = interaction.commit.value("action");
+            if (action == "join") {
+                displayedString = tr("%1 has joined the conversation.").arg(from);
+            } else if (action == "remove") {
+                displayedString = tr("%1 has left the conversation.").arg(from);
+            }
+        } else if (interaction.type == interaction::Type::DATA_TRANSFER) {
+            displayedString = from + ": " + interaction.commit.value("displayName");
+        } else {
+            displayedString = from + ": " + interaction.body;
         }
 
         auto preferences = accountInfo.conversationModel->getConversationPreferences(convUid);
@@ -174,15 +189,13 @@ ConversationsAdapter::onNewUnreadInteraction(const QString& accountId,
         if (preferences["ignoreNotifications"] == "true")
             return;
 #ifdef Q_OS_LINUX
-        auto contactPhoto = Utils::contactPhoto(lrcInstance_,
-                                                interaction.authorUri,
-                                                QSize(50, 50),
-                                                accountId);
-        auto notifId = QString("%1;%2;%3").arg(accountId).arg(convUid).arg(interactionId);
+        auto to = lrcInstance_->accountModel().bestNameForAccount(accountId);
+        auto contactPhoto = Utils::contactPhoto(lrcInstance_, interaction.authorUri, QSize(50, 50), accountId);
+        auto notifId = QString("%1;%2;%3").arg(accountId, convUid, interactionId);
         systemTray_->showNotification(notifId,
                                       tr("%1 received a new message").arg(to),
-                                      from + ": " + body_,
-                                      NotificationType::CHAT,
+                                      displayedString,
+                                      SystemTray::NotificationType::CHAT,
                                       Utils::QImageToByteArray(contactPhoto));
 
 #else
@@ -207,7 +220,7 @@ ConversationsAdapter::onNewReadInteraction(const QString& accountId,
 {
 #ifdef Q_OS_LINUX
     // hide notification
-    auto notifId = QString("%1;%2;%3").arg(accountId).arg(convUid).arg(interactionId);
+    auto notifId = QString("%1;%2;%3").arg(accountId, convUid, interactionId);
     systemTray_->hideNotification(notifId);
 #else
     Q_UNUSED(accountId)
@@ -217,9 +230,7 @@ ConversationsAdapter::onNewReadInteraction(const QString& accountId,
 }
 
 void
-ConversationsAdapter::onNewTrustRequest(const QString& accountId,
-                                        const QString& convId,
-                                        const QString& peerUri)
+ConversationsAdapter::onNewTrustRequest(const QString& accountId, const QString& convId, const QString& peerUri)
 {
 #ifdef Q_OS_LINUX
     if (!QApplication::focusWindow() || accountId != lrcInstance_->get_currentAccountId()) {
@@ -229,21 +240,38 @@ ConversationsAdapter::onNewTrustRequest(const QString& accountId,
             if (convInfo.uid.isEmpty())
                 return;
         }
-        auto& accInfo = lrcInstance_->getAccountInfo(accountId);
-        auto from = accInfo.contactModel->bestNameForContact(peerUri);
         auto to = lrcInstance_->accountModel().bestNameForAccount(accountId);
 
-        auto preferences = accInfo.conversationModel->getConversationPreferences(convId);
-        // Ignore notifications for this conversation
-        if (preferences["ignoreNotifications"] == "true")
-            return;
-        auto contactPhoto = Utils::contactPhoto(lrcInstance_, peerUri, QSize(50, 50), accountId);
-        auto notifId = QString("%1;%2").arg(accountId).arg(conv);
-        systemTray_->showNotification(notifId,
-                                      tr("%1 received a new trust request").arg(to),
-                                      "New request from " + from,
-                                      NotificationType::REQUEST,
-                                      Utils::QImageToByteArray(contactPhoto));
+        auto cb = [this, to, accountId, conv, peerUri](QString peerBestName) {
+            auto contactPhoto = Utils::contactPhoto(lrcInstance_, peerUri, QSize(50, 50), accountId);
+            auto notifId = QString("%1;%2").arg(accountId, conv);
+            systemTray_->showNotification(notifId,
+                                          tr("%1 received a new invitation").arg(to),
+                                          "New invitation from " + peerBestName,
+                                          SystemTray::NotificationType::REQUEST,
+                                          Utils::QImageToByteArray(contactPhoto));
+        };
+
+        // This peer is not yet a contact, so we don't have a name for it,
+        // but we can attempt to look it up using the name service before
+        // falling back to the bestNameForContact.
+        Utils::oneShotConnect(&NameDirectory::instance(),
+                              &NameDirectory::registeredNameFound,
+                              this,
+                              [this, accountId, peerUri, cb](NameDirectory::LookupStatus status,
+                                                             const QString& address,
+                                                             const QString& registeredName,
+                                                             const QString& requestedName) {
+                                  if (address == peerUri) {
+                                      if (status == NameDirectory::LookupStatus::SUCCESS)
+                                          cb(registeredName);
+                                      else {
+                                          auto& accInfo = lrcInstance_->getAccountInfo(accountId);
+                                          cb(accInfo.contactModel->bestNameForContact(peerUri));
+                                      }
+                                  }
+                              });
+        std::ignore = NameDirectory::instance().lookupAddress(accountId, peerUri);
     }
 #else
     Q_UNUSED(accountId)
@@ -257,7 +285,7 @@ ConversationsAdapter::onTrustRequestTreated(const QString& accountId, const QStr
 {
 #ifdef Q_OS_LINUX
     // hide notification
-    auto notifId = QString("%1;%2").arg(accountId).arg(peerUri);
+    auto notifId = QString("%1;%2").arg(accountId, peerUri);
     systemTray_->hideNotification(notifId);
 #else
     Q_UNUSED(accountId)
@@ -492,28 +520,26 @@ ConversationsAdapter::restartConversation(const QString& convId)
     auto contactInfo = accInfo.contactModel->getContact(peerUri);
     contactInfo.profileInfo.type = profile::Type::TEMPORARY;
 
-    Utils::oneShotConnect(
-        accInfo.contactModel.get(),
-        &ContactModel::contactRemoved,
-        [this, &accInfo, contactInfo](const QString& peerUri) {
-            // setup a callback to select another ONE_TO_ONE conversation for this peer
-            // once the new conversation becomes ready
-            Utils::oneShotConnect(
-                accInfo.conversationModel.get(),
-                &ConversationModel::conversationReady,
-                [this, peerUri, &accInfo](const QString& convId) {
-                    const auto& convInfo = lrcInstance_->getConversationFromConvUid(convId);
-                    // 3. filter for the correct contact-conversation and select it
-                    if (!convInfo.uid.isEmpty() && convInfo.isCoreDialog()
-                        && peerUri
-                               == accInfo.conversationModel->peersForConversation(convId).at(0)) {
-                        lrcInstance_->selectConversation(convId);
-                    }
-                });
+    Utils::oneShotConnect(accInfo.contactModel.get(),
+                          &ContactModel::contactRemoved,
+                          [this, &accInfo, contactInfo](const QString& peerUri) {
+                              // setup a callback to select another ONE_TO_ONE conversation for this peer
+                              // once the new conversation becomes ready
+                              Utils::oneShotConnect(
+                                  accInfo.conversationModel.get(),
+                                  &ConversationModel::conversationReady,
+                                  [this, peerUri, &accInfo](const QString& convId) {
+                                      const auto& convInfo = lrcInstance_->getConversationFromConvUid(convId);
+                                      // 3. filter for the correct contact-conversation and select it
+                                      if (!convInfo.uid.isEmpty() && convInfo.isCoreDialog()
+                                          && peerUri == accInfo.conversationModel->peersForConversation(convId).at(0)) {
+                                          lrcInstance_->selectConversation(convId);
+                                      }
+                                  });
 
-            // 2. add the contact and await the conversationReady signal
-            accInfo.contactModel->addContact(contactInfo);
-        });
+                              // 2. add the contact and await the conversationReady signal
+                              accInfo.contactModel->addContact(contactInfo);
+                          });
 
     // 1. remove the contact and await the contactRemoved signal
     accInfo.contactModel->removeContact(peerUri);
@@ -546,8 +572,7 @@ ConversationsAdapter::ignoreActiveCall(const QString& convId,
 }
 
 void
-ConversationsAdapter::updateConversationDescription(const QString& convId,
-                                                    const QString& newDescription)
+ConversationsAdapter::updateConversationDescription(const QString& convId, const QString& newDescription)
 {
     auto convModel = lrcInstance_->getCurrentConversationModel();
     QMap<QString, QString> details;
@@ -573,79 +598,43 @@ ConversationsAdapter::openDialogConversationWith(const QString& peerUri)
     lrcInstance_->selectConversation(convInfo.uid);
 }
 
+void
+ConversationsAdapter::onCurrentAccountRemoved()
+{
+    // Unbind proxy model source models if there is no current account
+    if (lrcInstance_->get_currentAccountId().isEmpty()) {
+        convModel_->bindSourceModel(nullptr);
+        searchModel_->bindSourceModel(nullptr);
+    }
+}
+
 void
 ConversationsAdapter::connectConversationModel()
 {
     // Signal connections
-    auto currentConversationModel = lrcInstance_->getCurrentConversationModel();
-    if (currentConversationModel == nullptr) {
+    auto model = lrcInstance_->getCurrentConversationModel();
+    if (!model) {
         return;
     }
 
-    QObject::connect(currentConversationModel,
-                     &ConversationModel::modelChanged,
-                     this,
-                     &ConversationsAdapter::onModelChanged,
-                     Qt::UniqueConnection);
+    auto connectObjectSignal = [this](auto obj, auto signal, auto slot) {
+        connect(obj, signal, this, slot, Qt::UniqueConnection);
+    };
 
-    QObject::connect(lrcInstance_->getCurrentContactModel(),
-                     &ContactModel::profileUpdated,
-                     this,
-                     &ConversationsAdapter::onProfileUpdated,
-                     Qt::UniqueConnection);
+    connectObjectSignal(model, &ConversationModel::modelChanged, &ConversationsAdapter::onModelChanged);
+    connectObjectSignal(model, &ConversationModel::profileUpdated, &ConversationsAdapter::onProfileUpdated);
+    connectObjectSignal(model, &ConversationModel::conversationUpdated, &ConversationsAdapter::onConversationUpdated);
+    connectObjectSignal(model, &ConversationModel::conversationRemoved, &ConversationsAdapter::onConversationRemoved);
+    connectObjectSignal(model, &ConversationModel::filterChanged, &ConversationsAdapter::onFilterChanged);
+    connectObjectSignal(model, &ConversationModel::conversationCleared, &ConversationsAdapter::onConversationCleared);
+    connectObjectSignal(model, &ConversationModel::searchStatusChanged, &ConversationsAdapter::onSearchStatusChanged);
+    connectObjectSignal(model, &ConversationModel::searchResultUpdated, &ConversationsAdapter::onSearchResultUpdated);
+    connectObjectSignal(model, &ConversationModel::searchResultEnded, &ConversationsAdapter::onSearchResultEnded);
+    connectObjectSignal(model, &ConversationModel::conversationReady, &ConversationsAdapter::onConversationReady);
 
-    QObject::connect(currentConversationModel,
-                     &ConversationModel::conversationUpdated,
-                     this,
-                     &ConversationsAdapter::onConversationUpdated,
-                     Qt::UniqueConnection);
-    QObject::connect(currentConversationModel,
-                     &ConversationModel::conversationRemoved,
-                     this,
-                     &ConversationsAdapter::onConversationRemoved,
-                     Qt::UniqueConnection);
-
-    QObject::connect(currentConversationModel,
-                     &ConversationModel::filterChanged,
-                     this,
-                     &ConversationsAdapter::onFilterChanged,
-                     Qt::UniqueConnection);
-
-    QObject::connect(currentConversationModel,
-                     &ConversationModel::conversationCleared,
-                     this,
-                     &ConversationsAdapter::onConversationCleared,
-                     Qt::UniqueConnection);
-
-    QObject::connect(currentConversationModel,
-                     &ConversationModel::searchStatusChanged,
-                     this,
-                     &ConversationsAdapter::onSearchStatusChanged,
-                     Qt::UniqueConnection);
-
-    QObject::connect(currentConversationModel,
-                     &ConversationModel::searchResultUpdated,
-                     this,
-                     &ConversationsAdapter::onSearchResultUpdated,
-                     Qt::UniqueConnection);
-
-    QObject::connect(currentConversationModel,
-                     &ConversationModel::searchResultEnded,
-                     this,
-                     &ConversationsAdapter::onSearchResultEnded,
-                     Qt::UniqueConnection);
-
-    QObject::connect(currentConversationModel,
-                     &ConversationModel::conversationReady,
-                     this,
-                     &ConversationsAdapter::onConversationReady,
-                     Qt::UniqueConnection);
-
-    QObject::connect(lrcInstance_->getCurrentContactModel(),
-                     &ContactModel::bannedStatusChanged,
-                     this,
-                     &ConversationsAdapter::onBannedStatusChanged,
-                     Qt::UniqueConnection);
+    connectObjectSignal(lrcInstance_->getCurrentContactModel(),
+                        &ContactModel::bannedStatusChanged,
+                        &ConversationsAdapter::onBannedStatusChanged);
 
     convSrcModel_.reset(new ConversationListModel(lrcInstance_));
     convModel_->bindSourceModel(convSrcModel_.get());
@@ -662,8 +651,12 @@ ConversationsAdapter::createSwarm(const QString& title,
                                   const VectorString& participants)
 {
     auto convModel = lrcInstance_->getCurrentConversationModel();
-    return convModel->createConversation(participants,
-                                         {{"title", title},
-                                         {"description", description},
-                                         {"avatar", avatar}});
+    MapStringString details;
+    if (!title.isEmpty())
+        details["title"] = title;
+    if (!description.isEmpty())
+        details["description"] = description;
+    if (!avatar.isEmpty())
+        details["avatar"] = avatar;
+    return convModel->createConversation(participants, details);
 }
