@@ -1,8 +1,5 @@
 /*
- * Copyright (C) 2019-2023 Savoir-faire Linux Inc.
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Isa Nanic <isa.nanic@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2019-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,20 +21,19 @@
 #undef ERROR
 #endif
 
-#include "updatemanager.h"
+#include "appversionmanager.h"
 #include "qtutils.h"
 #include "utils.h"
 
-#include "api/lrc.h"
-#include "api/account.h"
-#include "api/avmodel.h"
-#include "api/behaviorcontroller.h"
-#include "api/contact.h"
-#include "api/contactmodel.h"
-#include "api/conversation.h"
-#include "api/conversationmodel.h"
-#include "api/accountmodel.h"
-#include "api/callmodel.h"
+#include <api/lrc.h>
+#include <api/account.h>
+#include <api/avmodel.h>
+#include <api/behaviorcontroller.h>
+#include <api/contactmodel.h>
+#include <api/conversation.h>
+#include <api/conversationmodel.h>
+#include <api/accountmodel.h>
+#include <api/callmodel.h>
 
 #include <QObject>
 #include <QThreadPool>
@@ -48,29 +44,26 @@ class ConnectivityMonitor;
 
 using namespace lrc::api;
 
-using migrateCallback = std::function<void()>;
 using getConvPredicate = std::function<bool(const conversation::Info& conv)>;
 
 class LRCInstance : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(QString selectedConvUid READ get_selectedConvUid WRITE set_selectedConvUid NOTIFY
-                   selectedConvUidChanged)
+    Q_PROPERTY(QString selectedConvUid READ get_selectedConvUid WRITE set_selectedConvUid NOTIFY selectedConvUidChanged)
     QML_PROPERTY(QString, currentAccountId)
     QML_RO_PROPERTY(lrc::api::profile::Type, currentAccountType)
     QML_PROPERTY(bool, currentAccountAvatarSet)
 
 public:
-    explicit LRCInstance(migrateCallback willMigrateCb,
-                         migrateCallback didMigrateCb,
-                         const QString& updateUrl,
+    explicit LRCInstance(const QString& updateUrl,
                          ConnectivityMonitor* connectivityMonitor,
-                         bool muteDring);
+                         bool debugMode,
+                         bool muteDaemon);
     ~LRCInstance() = default;
 
     void finish();
 
-    UpdateManager* getUpdateManager();
+    AppVersionManager* getAppVersionManager();
 
     AccountModel& accountModel();
     ConversationModel* getCurrentConversationModel();
@@ -78,6 +71,7 @@ public:
     ContactModel* getCurrentContactModel();
     AVModel& avModel();
     PluginModel& pluginModel();
+    ConnectivityMonitor& connectivityMonitor();
     BehaviorController& behaviorController();
 
     void subscribeToDebugReceived();
@@ -91,26 +85,21 @@ public:
     QString getCurrentCallId(bool forceCallOnly = false);
     QString getCallIdForConversationUid(const QString& convUid, const QString& accountId);
     const call::Info* getCallInfo(const QString& callId, const QString& accountId);
-    const call::Info* getCallInfoForConversation(const conversation::Info& convInfo,
-                                                 bool forceCallOnly = false);
-    const conversation::Info& getConversationFromConvUid(const QString& convUid,
-                                                         const QString& accountId = {});
-    const conversation::Info& getConversationFromPeerUri(const QString& peerUri,
-                                                         const QString& accountId = {});
-    const conversation::Info& getConversationFromCallId(const QString& callId,
-                                                        const QString& accountId = {});
+    const call::Info* getCallInfoForConversation(const conversation::Info& convInfo, bool forceCallOnly = false);
+    const conversation::Info& getConversationFromConvUid(const QString& convUid, const QString& accountId = {});
+    const conversation::Info& getConversationFromPeerUri(const QString& peerUri, const QString& accountId = {});
+    const conversation::Info& getConversationFromCallId(const QString& callId, const QString& accountId = {});
 
     Q_INVOKABLE void selectConversation(const QString& convId, const QString& accountId = {});
     Q_INVOKABLE void deselectConversation();
-    Q_INVOKABLE void makeConversationPermanent(const QString& convId = {},
-                                               const QString& accountId = {});
-    Q_INVOKABLE QString getContentDraft(const QString& convUid, const QString& accountId);
+    Q_INVOKABLE void makeConversationPermanent(const QString& convId = {}, const QString& accountId = {});
+    Q_INVOKABLE QVariantMap getContentDraft(const QString& convUid, const QString& accountId);
     Q_INVOKABLE void setContentDraft(const QString& convUid,
                                      const QString& accountId,
-                                     const QString& content);
-    Q_INVOKABLE int indexOfActiveCall(const QString& confId,
-                                      const QString& uri,
-                                      const QString& deviceId);
+                                     const QString& textDraft,
+                                     const QList<QString>& filePathDraft);
+
+    Q_INVOKABLE int indexOfActiveCall(const QString& confId, const QString& uri, const QString& deviceId);
 
     int getCurrentAccountIndex();
     void setCurrAccDisplayName(const QString& displayName);
@@ -133,8 +122,13 @@ public:
         return debugMode_;
     }
 
+    VectorMapStringString getConnectionList(const QString& accountId, const QString& uid = {});
+
+    VectorMapStringString getChannelList(const QString& accountId, const QString& uid = {});
+
 Q_SIGNALS:
     void accountListChanged();
+    void currentAccountRemoved();
     void selectedConvUidChanged();
     void restoreAppRequested();
     void notificationClicked();
@@ -142,17 +136,24 @@ Q_SIGNALS:
     void draftSaved(const QString& convId);
     void base64SwarmAvatarChanged();
 
+private Q_SLOTS:
+    void onAccountRemoved(const QString& accountId);
+
 private:
     std::unique_ptr<Lrc> lrc_;
-    std::unique_ptr<UpdateManager> updateManager_;
+    std::unique_ptr<AppVersionManager> updateManager_;
+
+    ConnectivityMonitor& connectivityMonitor_;
 
     QString selectedConvUid_;
     MapStringString contentDrafts_;
     MapStringString lastConferences_;
+    MapStringListString fileDrafts_;
 
-    conversation::Info invalid {};
+    conversation::Info invalid {"", nullptr};
 
     bool debugMode_ {false};
+    bool muteDaemon_ {true};
 
     QThreadPool* threadPool_;
 };
