@@ -1,6 +1,5 @@
 /*!
- * Copyright (C) 2020-2023 Savoir-faire Linux Inc.
- * Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +23,8 @@
 #include "networkmanager.h"
 #include "lrcinstance.h"
 #include "appsettingsmanager.h"
-#include "qmlregister.h"
+
+#include "api/pluginmodel.h"
 
 #include <QJsonArray>
 #include <QJsonDocument>
@@ -33,10 +33,7 @@
 #include <QDir>
 #include <QString>
 
-PluginAdapter::PluginAdapter(LRCInstance* instance,
-                             AppSettingsManager* settingsManager,
-                             QObject* parent,
-                             QString baseUrl)
+PluginAdapter::PluginAdapter(LRCInstance* instance, AppSettingsManager* settingsManager, QObject* parent)
     : QmlAdapterBase(instance, parent)
     , pluginStoreListModel_(new PluginStoreListModel(instance, this))
     , pluginVersionManager_(new PluginVersionManager(instance, settingsManager, this))
@@ -44,8 +41,9 @@ PluginAdapter::PluginAdapter(LRCInstance* instance,
     , lrcInstance_(instance)
     , settingsManager_(settingsManager)
 {
-    QML_REGISTERSINGLETONTYPE_POBJECT(NS_MODELS, pluginStoreListModel_, "PluginStoreListModel");
-    QML_REGISTERSINGLETONTYPE_POBJECT(NS_MODELS, pluginListModel_, "PluginListModel")
+    pluginListModel_ = qApp->property("PluginListModel").value<PluginListModel*>();
+    pluginStoreListModel_ = qApp->property("PluginStoreListModel").value<PluginStoreListModel*>();
+
     updateHandlersListCount();
     connect(&lrcInstance_->pluginModel(),
             &lrc::api::PluginModel::modelUpdated,
@@ -59,10 +57,7 @@ PluginAdapter::PluginAdapter(LRCInstance* instance,
             &PluginVersionManager::versionStatusChanged,
             pluginStoreListModel_,
             &PluginStoreListModel::onVersionStatusChanged);
-    connect(pluginStoreListModel_,
-            &PluginStoreListModel::pluginAdded,
-            this,
-            &PluginAdapter::getPluginDetails);
+    connect(pluginStoreListModel_, &PluginStoreListModel::pluginAdded, this, &PluginAdapter::getPluginDetails);
     connect(pluginListModel_,
             &PluginListModel::versionCheckRequested,
             pluginVersionManager_,
@@ -94,26 +89,30 @@ PluginAdapter::getPluginsFromStore()
     QMap<QString, QByteArray> header;
     const auto& language = settingsManager_->getLanguage();
     header["Accept-Language"] = QByteArray(language.toStdString().c_str(), language.size());
-    pluginVersionManager_
-        ->sendGetRequest(QUrl(baseUrl()
-                              + "?arch=" + lrcInstance_->pluginModel().getPlatformInfo()["os"]),
-                         header,
-                         [this, errorHandler](const QByteArray& data) {
-                             auto result = QJsonDocument::fromJson(data).array();
-                             auto pluginsInstalled = lrcInstance_->pluginModel().getPluginsId();
-                             QList<QVariantMap> plugins;
-                             for (const auto& plugin : result) {
-                                 auto qPlugin = plugin.toVariant().toMap();
-                                 if (!qPlugin.contains("id")) {
-                                     qPlugin["id"] = qPlugin["name"];
-                                 }
-                                 if (!pluginsInstalled.contains(qPlugin["id"].toString())) {
-                                     plugins.append(qPlugin);
-                                 }
-                             }
-                             pluginStoreListModel_->setPlugins(plugins);
-                             disconnect(errorHandler);
-                         });
+    pluginVersionManager_->sendGetRequest(QUrl(baseUrl()
+                                               + "?arch=" + lrcInstance_->pluginModel().getPlatformInfo()["os"]),
+                                          header,
+                                          [this, errorHandler](const QByteArray& data) {
+                                              auto result = QJsonDocument::fromJson(data).array();
+                                              auto pluginsInstalled = lrcInstance_->pluginModel().getPluginsId();
+                                              QList<QVariantMap> plugins;
+                                              if (result.size() == 0) {
+                                                  Q_EMIT storeNotAvailableForPlatform();
+                                                  return;
+                                              }
+                                              for (const auto& plugin : result) {
+                                                  auto qPlugin = plugin.toVariant().toMap();
+
+                                                  if (!qPlugin.contains("id")) {
+                                                      qPlugin["id"] = qPlugin["name"];
+                                                  }
+                                                  if (!pluginsInstalled.contains(qPlugin["id"].toString())) {
+                                                      plugins.append(qPlugin);
+                                                  }
+                                              }
+                                              pluginStoreListModel_->setPlugins(plugins);
+                                              disconnect(errorHandler);
+                                          });
 }
 
 void
@@ -122,20 +121,19 @@ PluginAdapter::getPluginDetails(const QString& pluginId)
     QMap<QString, QByteArray> header;
     const auto& language = settingsManager_->getLanguage();
     header["Accept-Language"] = QByteArray(language.toStdString().c_str(), language.size());
-    pluginVersionManager_
-        ->sendGetRequest(QUrl(baseUrl() + "/details/" + pluginId
-                              + "?arch=" + lrcInstance_->pluginModel().getPlatformInfo()["os"]),
-                         header,
-                         [this](const QByteArray& data) {
-                             auto result = QJsonDocument::fromJson(data).object();
-                             // my response is a json object and I want to convert
-                             // it to a QVariantMap
-                             auto plugin = result.toVariantMap();
-                             if (!plugin.contains("id")) {
-                                 plugin["id"] = plugin["name"];
-                             }
-                             pluginStoreListModel_->addPlugin(plugin);
-                         });
+    pluginVersionManager_->sendGetRequest(QUrl(baseUrl() + "/details/" + pluginId
+                                               + "?arch=" + lrcInstance_->pluginModel().getPlatformInfo()["os"]),
+                                          header,
+                                          [this](const QByteArray& data) {
+                                              auto result = QJsonDocument::fromJson(data).object();
+                                              // my response is a json object and I want to convert
+                                              // it to a QVariantMap
+                                              auto plugin = result.toVariantMap();
+                                              if (!plugin.contains("id")) {
+                                                  plugin["id"] = plugin["name"];
+                                              }
+                                              pluginStoreListModel_->addPlugin(plugin);
+                                          });
 }
 
 void
@@ -165,8 +163,7 @@ PluginAdapter::cancelDownload(const QString& pluginId)
 QVariant
 PluginAdapter::getMediaHandlerSelectableModel(const QString& callId)
 {
-    pluginHandlerListModel_.reset(
-        new PluginHandlerListModel(this, callId, QString(""), lrcInstance_));
+    pluginHandlerListModel_.reset(new PluginHandlerListModel(this, callId, QString(""), lrcInstance_));
     return QVariant::fromValue(pluginHandlerListModel_.get());
 }
 
@@ -178,9 +175,7 @@ PluginAdapter::getChatHandlerSelectableModel(const QString& accountId, const QSt
 }
 
 QVariant
-PluginAdapter::getPluginPreferencesCategories(const QString& pluginId,
-                                              const QString& accountId,
-                                              bool removeLast)
+PluginAdapter::getPluginPreferencesCategories(const QString& pluginId, const QString& accountId, bool removeLast)
 {
     QStringList categories;
     auto preferences = lrcInstance_->pluginModel().getPluginPreferences(pluginId, accountId);
@@ -210,19 +205,17 @@ PluginAdapter::checkVersionStatus(const QString& pluginId)
 QString
 PluginAdapter::baseUrl() const
 {
-    return settingsManager_->getValue("PluginStoreEndpoint").toString();
+    return settingsManager_->getValue(Settings::Key::PluginStoreEndpoint).toString();
 }
 
 QString
 PluginAdapter::getIconUrl(const QString& pluginId) const
 {
-    return baseUrl() + "/icons/" + pluginId
-           + "?arch=" + lrcInstance_->pluginModel().getPlatformInfo()["os"];
+    return baseUrl() + "/icons/" + pluginId + "?arch=" + lrcInstance_->pluginModel().getPlatformInfo()["os"];
 }
 
 QString
 PluginAdapter::getBackgroundImageUrl(const QString& pluginId) const
 {
-    return baseUrl() + "/backgrounds/" + pluginId
-           + "?arch=" + lrcInstance_->pluginModel().getPlatformInfo()["os"];
+    return baseUrl() + "/backgrounds/" + pluginId + "?arch=" + lrcInstance_->pluginModel().getPlatformInfo()["os"];
 }
