@@ -1,6 +1,5 @@
 /**
- * Copyright (C) 2019-2024 Savoir-faire Linux Inc.
- * Author: Aline Gondim Santos   <aline.gondimsantos@savoirfairelinux.com>
+ * Copyright (C) 2019-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,8 +39,7 @@ PluginListPreferenceModel::populateLists()
         preferences.append(lrcInstance_->pluginModel().getPluginPreferences(pluginId_, accountId_));
     for (const auto& preference : preferences) {
         if (preference["key"] == preferenceKey_) {
-            if (preference.find("entries") != preference.end()
-                && preference.find("entryValues") != preference.end())
+            if (preference.find("entries") != preference.end() && preference.find("entryValues") != preference.end())
                 preferenceList_ = preference["entries"].split(",");
             preferenceValuesList_ = preference["entryValues"].split(",");
             break;
