@@ -1,19 +1,20 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ * Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program. If not, see <https://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
+
 #include "connectionmanager.h"
 #include "peer_connection.h"
 #include "upnp/upnp_control.h"
@@ -30,16 +31,31 @@
 #include <algorithm>
 #include <mutex>
 #include <map>
-#include <condition_variable>
+#include <random>
 #include <set>
-#include <charconv>
-#include <fstream>
 
 namespace dhtnet {
 static constexpr std::chrono::seconds DHT_MSG_TIMEOUT {30};
-static constexpr uint64_t ID_MAX_VAL = 9007199254740992;
+static constexpr dht::Value::Id ID_MAX_VAL = 9007199254740992;
 
 using ValueIdDist = std::uniform_int_distribution<dht::Value::Id>;
+using namespace std::literals;
+
+/**
+ * A PeerConnectionRequest is a request which ask for an initial connection
+ * It contains the ICE request an ID and if it's an answer
+ * Transmitted via the UDP DHT
+ */
+struct PeerConnectionRequest : public dht::EncryptedValue<PeerConnectionRequest>
+{
+    static const constexpr dht::ValueType& TYPE = dht::ValueType::USER_DATA;
+    static constexpr auto key_prefix = "peer:"sv; ///< base to compute the DHT listen key
+    dht::Value::Id id = dht::Value::INVALID_ID;
+    std::string ice_msg {};
+    bool isAnswer {false};
+    std::string connType {}; // Used for push notifications to know why we open a new connection
+    MSGPACK_DEFINE_MAP(id, ice_msg, isAnswer, connType)
+};
 
 std::string
 callbackIdToString(const dhtnet::DeviceId& did, const dht::Value::Id& vid)
@@ -75,6 +91,12 @@ createConfig(std::shared_ptr<ConnectionManager::Config> config_)
                 ret.emplace_back(std::move(cert));
             return ret;
         };
+        dhtContext.certificateStorePkId = [c = config_->certStore](const dht::PkId& pk_id) {
+            std::vector<std::shared_ptr<dht::crypto::Certificate>> ret;
+            if (auto cert = c->getCertificate(pk_id.toString()))
+                ret.emplace_back(std::move(cert));
+            return ret;
+        };
         config_->dht = std::make_shared<dht::DhtRunner>();
         config_->dht->run(dhtConfig, std::move(dhtContext));
         config_->dht->bootstrap("bootstrap.sfl.io");
@@ -150,8 +172,10 @@ struct PendingCb {
     std::string connType;
     ConnectCallback cb;
     bool requested {false};
-    /** Carry user preference and prevents retry mechanism to
-     * open a new connection if the channel request failed */
+    /*
+     * Carry user preference and prevents retry mechanism to
+     * open a new connection if the channel request failed
+     */
     bool noNewSocket {false};
 };
 
@@ -227,7 +251,7 @@ struct DeviceInfo {
         } else if (auto n = connecting.extract(vid)) {
             ret.emplace_back(std::move(n.mapped()));
             // If sock is nullptr, execute if it's the last connecting operation
-            // If accepted is false, it means that underlying socket is ok, but channel is declined
+            // If accepted is false, it means that underlying socket is OK, but channel is declined
             if (!sock && connecting.empty() && accepted) {
                 for (auto& [vid, cb] : waiting)
                     ret.emplace_back(std::move(cb));
@@ -240,7 +264,7 @@ struct DeviceInfo {
         return ret;
     }
 
-    /**
+    /*
      * A socket failed. Return failure callbacks and reset operations that can be retried.
      * Sets noNewSocket to true for retryable operations, because we should never open more than one socket
      * for a specific channel.
@@ -519,11 +543,11 @@ public:
                          const std::shared_ptr<dht::crypto::Certificate>& cert,
                          const std::string& connType);
 
-    /**
+    /*
      * Send a ChannelRequest on the TLS socket. Triggers cb when ready
      * @param sock      socket used to send the request
      * @param name      channel's name
-     * @param vid       channel's id
+     * @param vid       channel's ID
      * @param deviceId  to identify the linked ConnectCallback
      */
     void sendChannelRequest(const std::weak_ptr<DeviceInfo>& dinfo,
@@ -531,7 +555,7 @@ public:
                             const std::shared_ptr<MultiplexedSocket>& sock,
                             const std::string& name,
                             const dht::Value::Id& vid);
-    /**
+    /*
      * Triggered when a PeerConnectionRequest comes from the DHT
      */
     void answerTo(IceTransport& ice,
@@ -541,7 +565,7 @@ public:
     bool onRequestOnNegoDone(const std::weak_ptr<DeviceInfo>& dinfo, const std::shared_ptr<ConnectionInfo>& info, const PeerConnectionRequest& req);
     void onDhtPeerRequest(const PeerConnectionRequest& req,
                           const std::shared_ptr<dht::crypto::Certificate>& cert);
-    /**
+    /*
      * Triggered when a new TLS socket is ready to use
      * @param ok        If succeed
      * @param deviceId  Related device
@@ -559,8 +583,8 @@ public:
     void onPeerResponse(PeerConnectionRequest&& req);
     void onDhtConnected(const dht::crypto::PublicKey& devicePk);
 
-    /**
-     * Try reconnecting when a connection fails before a channel request is answered.
+    /*
+     * Attempt reconnecting when a connection fails before a channel request is answered.
      * This ensures that every call to connectDevice() leads to a channel request when possible,
      * even if the connection fails after sending the first request.
      * In conjunction with beacon messages, this allows to reconnect to a device
@@ -574,53 +598,52 @@ public:
     mutable std::mutex messageMutex_ {};
     fileutils::IdList treatedMessages_;
 
-    /// \return true if the given DHT message identifier has been treated
-    /// \note if message has not been treated yet this method st/ore this id and returns true at
-    /// further calls
+    // @return true if the given DHT message identifier has been treated
+    // NOTE: If message has not been treated yet this method stores this identifier and returns
+    // true at further calls
     bool isMessageTreated(dht::Value::Id id);
 
     const std::shared_ptr<dht::log::Logger>& logger() const { return config_->logger; }
 
-    /**
+    /*
      * Published IPv4/IPv6 addresses, used only if defined by the user in account
      * configuration
-     *
      */
     IpAddr publishedIp_[2] {};
 
-    /**
-     * interface name on which this account is bound
+    /*
+     * Interface name on which this account is bound
      */
     std::string interface_ {"default"};
 
-    /**
+    /*
      * Get the local interface name on which this account is bound.
      */
     const std::string& getLocalInterface() const { return interface_; }
 
-    /**
+    /*
      * Get the published IP address, fallbacks to NAT if family is unspecified
      * Prefers the usage of IPv4 if possible.
      */
     IpAddr getPublishedIpAddress(uint16_t family = PF_UNSPEC) const;
 
-    /**
+    /*
      * Set published IP address according to given family
      */
     void setPublishedAddress(const IpAddr& ip_addr);
 
-    /**
+    /*
      * Store the local/public addresses used to register
      */
     void storeActiveIpAddress(std::function<void()>&& cb = {});
 
-    /**
+    /*
      * Create and return ICE options.
      */
     void getIceOptions(std::function<void(IceTransportOptions&&)> cb) noexcept;
     IceTransportOptions getIceOptions() const noexcept;
 
-    /**
+    /*
      * Inform that a potential peer device have been found.
      * Returns true only if the device certificate is a valid device certificate.
      * In that case (true is returned) the account_id parameter is set to the peer account ID.
@@ -685,7 +708,7 @@ ConnectionManager::Impl::connectDeviceStartIce(
     // Prepare connection request as a DHT message
     PeerConnectionRequest val;
 
-    val.id = vid; /* Random id for the message unicity */
+    val.id = vid; /* Random identifier for the message unicity */
     val.ice_msg = icemsg.str();
     val.connType = connType;
 
@@ -695,15 +718,15 @@ ConnectionManager::Impl::connectDeviceStartIce(
     // Send connection request through DHT
     if (config_->logger)
         config_->logger->debug("[device {}] Sending connection request", deviceId);
-    dht()->putEncrypted(dht::InfoHash::get(PeerConnectionRequest::key_prefix
-                                           + devicePk->getId().toString()),
+    dht()->putEncrypted(dht::InfoHash::get(concat(PeerConnectionRequest::key_prefix
+                                           , devicePk->getId().to_view())),
                         devicePk,
                         value,
                         [l=config_->logger,deviceId](bool ok) {
                             if (l)
                                 l->debug("[device {}] Sent connection request. Put encrypted {:s}",
-                                       deviceId,
-                                       (ok ? "OK" : "failed"));
+                                         deviceId,
+                                         (ok ? "OK" : "failed"));
                         });
     // Wait for call to onResponse() operated by DHT
     if (isDestroying_) {
@@ -825,7 +848,7 @@ ConnectionManager::Impl::connectDevice(const DeviceId& deviceId,
         cb(nullptr, deviceId);
         return;
     }
-    if (deviceId.toString() == identity().second->getLongId().toString()) {
+    if (deviceId == identity().second->getLongId()) {
         cb(nullptr, deviceId);
         return;
     }
@@ -840,9 +863,7 @@ ConnectionManager::Impl::connectDevice(const DeviceId& deviceId,
                         if (!cert) {
                             if (auto shared = w.lock())
                                 if (shared->config_->logger)
-                                    shared->config_->logger->error(
-                                        "No valid certificate found for device {}",
-                                        deviceId);
+                                    shared->config_->logger->error("[device {}] No valid certificate found.", deviceId);
                             cb(nullptr, deviceId);
                             return;
                         }
@@ -870,7 +891,7 @@ ConnectionManager::Impl::connectDevice(const dht::InfoHash& deviceId,
         cb(nullptr, deviceId);
         return;
     }
-    if (deviceId.toString() == identity().second->getLongId().toString()) {
+    if (deviceId == identity().second->getId()) {
         cb(nullptr, deviceId);
         return;
     }
@@ -885,9 +906,7 @@ ConnectionManager::Impl::connectDevice(const dht::InfoHash& deviceId,
                         if (!cert) {
                             if (auto shared = w.lock())
                                 if (shared->config_->logger)
-                                    shared->config_->logger->error(
-                                        "No valid certificate found for device {}",
-                                        deviceId);
+                                    shared->config_->logger->error("[device {}] No valid certificate found.", deviceId);
                             cb(nullptr, deviceId);
                             return;
                         }
@@ -913,7 +932,7 @@ ConnectionManager::Impl::connectDevice(const std::shared_ptr<dht::crypto::Certif
                                        bool forceNewSocket,
                                        const std::string& connType)
 {
-    // Avoid dht operation in a DHT callback to avoid deadlocks
+    // Avoid DHT operation in a DHT callback to avoid deadlocks
     dht::ThreadPool::computation().run([w = weak_from_this(),
                      name = std::move(name),
                      cert = std::move(cert),
@@ -939,7 +958,7 @@ ConnectionManager::Impl::connectDevice(const std::shared_ptr<dht::crypto::Certif
         // Check if already connecting
         auto isConnectingToDevice = di->isConnecting();
         auto useExistingConnection = isConnectingToDevice && !forceNewSocket;
-        // Note: we can be in a state where first
+        // NOTE: We can be in a state where first
         // socket is negotiated and first channel is pending
         // so return only after we checked the info
         auto& diw = (useExistingConnection)
@@ -983,7 +1002,7 @@ ConnectionManager::Impl::startConnection(const std::shared_ptr<DeviceInfo>& di,
                                          const std::shared_ptr<dht::crypto::Certificate>& cert,
                                          const std::string& connType)
 {
-    // Note: used when the ice negotiation fails to erase
+    // NOTE: Used when the ICE negotiation fails to erase
     // all stored structures.
     auto eraseInfo = [w = weak_from_this(), diw=std::weak_ptr(di), vid] {
         if (auto di = diw.lock()) {
@@ -1088,8 +1107,8 @@ ConnectionManager::Impl::startConnection(const std::shared_ptr<DeviceInfo>& di,
             eraseInfo();
             return;
         }
-        // We need to detect any shutdown if the ice session is destroyed before going to the
-        // TLS session;
+        // We need to detect any shutdown if the ICE session is destroyed before going to the
+        // TLS session.
         info->ice_->setOnShutdown([eraseInfo]() {
             dht::ThreadPool::io().run([eraseInfo = std::move(eraseInfo)] { eraseInfo(); });
         });
@@ -1145,7 +1164,7 @@ ConnectionManager::Impl::sendChannelRequest(const std::weak_ptr<DeviceInfo>& din
                           buffer.size(),
                           ec);
     if (res < 0) {
-        // TODO check if we should handle errors here
+        // TODO: Check if we should handle errors here
         if (config_->logger)
             config_->logger->error("sendChannelRequest failed - error: {}", ec.message());
     }
@@ -1155,7 +1174,8 @@ void
 ConnectionManager::Impl::onPeerResponse(PeerConnectionRequest&& req)
 {
     auto device = req.owner->getLongId();
-    if (auto info = infos_.getInfo(device, req.id)) {
+    auto reqId = req.id;
+    if (auto info = infos_.getInfo(device, reqId)) {
         if (config_->logger)
             config_->logger->debug("[device {}] New response received", device);
         std::lock_guard lk {info->mutex_};
@@ -1167,7 +1187,7 @@ ConnectionManager::Impl::onPeerResponse(PeerConnectionRequest&& req)
                                                    std::placeholders::_1,
                                                    std::weak_ptr(info),
                                                    device,
-                                                   req.id));
+                                                   reqId));
     } else {
         if (config_->logger)
             config_->logger->warn("[device {}] Response received, but unable to find request", device);
@@ -1180,7 +1200,7 @@ ConnectionManager::Impl::onDhtConnected(const dht::crypto::PublicKey& devicePk)
     if (!dht())
         return;
     dht()->listen<PeerConnectionRequest>(
-        dht::InfoHash::get(PeerConnectionRequest::key_prefix + devicePk.getId().toString()),
+        dht::InfoHash::get(concat(PeerConnectionRequest::key_prefix, devicePk.getId().to_view())),
         [w = weak_from_this()](PeerConnectionRequest&& req) {
             auto shared = w.lock();
             if (!shared)
@@ -1238,8 +1258,8 @@ ConnectionManager::Impl::onTlsNegotiationDone(const std::shared_ptr<DeviceInfo>&
 {
     if (isDestroying_)
         return;
-    // Note: only handle pendingCallbacks here for TLS initied by connectDevice()
-    // Note: if not initied by connectDevice() the channel name will be empty (because no channel
+    // NOTE: Only handle pendingCallbacks here for TLS initied by connectDevice()
+    // NOTE: If not initied by connectDevice() the channel name will be empty (because no channel
     // asked yet)
     auto isDhtRequest = name.empty();
     if (!ok) {
@@ -1279,7 +1299,7 @@ ConnectionManager::Impl::onTlsNegotiationDone(const std::shared_ptr<DeviceInfo>&
                                         vid);
         }
 
-        // Note: do not remove pending there it's done in sendChannelRequest
+        // NOTE: Do not remove pending here it's done in sendChannelRequest
         std::unique_lock lk2 {dinfo->mutex_};
         auto pendingIds = dinfo->requestPendingOps();
         auto previousConnections = dinfo->getConnectedInfos();
@@ -1291,9 +1311,9 @@ ConnectionManager::Impl::onTlsNegotiationDone(const std::shared_ptr<DeviceInfo>&
         lk2.unlock();
         // send beacon to existing connections for this device
         if (config_->logger and not previousConnections.empty())
-            config_->logger->warn("[device {}] Sending beacon to {} existing connections",
-                                        deviceId,
-                                        previousConnections.size());
+            config_->logger->warn("[device {}] Sending beacon to {} existing connection(s)",
+                                  deviceId,
+                                  previousConnections.size());
         for (const auto& cinfo: previousConnections) {
             std::lock_guard lk {cinfo->mutex_};
             if (cinfo->socket_) {
@@ -1304,7 +1324,8 @@ ConnectionManager::Impl::onTlsNegotiationDone(const std::shared_ptr<DeviceInfo>&
         for (const auto& [id, name]: pendingIds) {
             if (config_->logger)
                 config_->logger->debug("[device {}] Send request on TLS socket for channel {}",
-                    deviceId, name);
+                                       deviceId,
+                                       name);
             sendChannelRequest(dinfo, info, info->socket_, name, id);
         }
     }
@@ -1334,8 +1355,7 @@ ConnectionManager::Impl::answerTo(IceTransport& ice,
 
     if (config_->logger)
         config_->logger->debug("[device {}] Connection accepted, DHT reply", from->getLongId());
-    dht()->putEncrypted(dht::InfoHash::get(PeerConnectionRequest::key_prefix
-                                           + from->getId().toString()),
+    dht()->putEncrypted(dht::InfoHash::get(concat(PeerConnectionRequest::key_prefix, from->getId().to_view())),
                         from,
                         value,
                         [from,l=config_->logger](bool ok) {
@@ -1429,7 +1449,7 @@ ConnectionManager::Impl::onRequestOnNegoDone(const std::weak_ptr<DeviceInfo>& di
         [w = weak_from_this(), dinfo, winfo=std::weak_ptr(info), deviceId = std::move(deviceId), vid = std::move(req.id)](bool ok) {
             if (auto shared = w.lock())
                 if (auto info = winfo.lock()) {
-                    shared->onTlsNegotiationDone(dinfo.lock(), winfo.lock(), ok, deviceId, vid);
+                    shared->onTlsNegotiationDone(dinfo.lock(), info, ok, deviceId, vid);
                     // Make another reference to info to avoid destruction (could lead to a deadlock/crash).
                     dht::ThreadPool::io().run([info = std::move(info)] {});
                 }
@@ -1461,7 +1481,7 @@ ConnectionManager::Impl::onDhtPeerRequest(const PeerConnectionRequest& req,
         auto wdi = std::weak_ptr(di);
         auto winfo = std::weak_ptr(info);
 
-        // Note: used when the ice negotiation fails to erase
+        // NOTE: Used when the ICE negotiation fails to erase
         // all stored structures.
         auto eraseInfo = [w, wdi, id = req.id] {
             auto shared = w.lock();
@@ -1544,7 +1564,7 @@ ConnectionManager::Impl::onDhtPeerRequest(const PeerConnectionRequest& req,
             eraseInfo();
             return;
         }
-        // We need to detect any shutdown if the ice session is destroyed before going to the TLS session;
+        // We need to detect any shutdown if the ICE session is destroyed before going to the TLS session;
         info->ice_->setOnShutdown([eraseInfo]() {
             dht::ThreadPool::io().run([eraseInfo = std::move(eraseInfo)] { eraseInfo(); });
         });
@@ -1662,7 +1682,7 @@ ConnectionManager::Impl::getPublishedIpAddress(uint16_t family) const
 
     assert(family == AF_UNSPEC);
 
-    // If family is not set, prefere IPv4 if available. It's more
+    // If family is not set, prefer IPv4 if available. It's more
     // likely to succeed behind NAT.
     if (publishedIp_[0])
         return publishedIp_[0];
@@ -1767,8 +1787,8 @@ ConnectionManager::Impl::getIceOptions() const noexcept
                                                 .setPassword(config_->turnServerPwd)
                                                 .setRealm(config_->turnServerRealm));
         }
-        // NOTE: first test with ipv6 turn was not concluant and resulted in multiple
-        // co issues. So this needs some debug. for now just disable
+        // NOTE: The first test with IPv6 TURN was inconclusive and resulted in multiple
+        // CoTURN issues. So this requires debugging. For now, just disable it.
         // if (cacheTurnV6 && *cacheTurnV6) {
         //    opts.turnServers.emplace_back(TurnServerInfo()
         //                                      .setUri(cacheTurnV6->toString(true))
@@ -1819,9 +1839,9 @@ ConnectionManager::Impl::foundPeerDevice(const std::shared_ptr<dht::crypto::Cert
     account_id = crt->issuer->getId();
     if (logger)
         logger->warn("Found peer device: {} account:{} CA:{}",
-              crt->getLongId(),
-              account_id,
-              top_issuer->getId());
+                     crt->getLongId(),
+                     account_id,
+                     top_issuer->getId());
     return true;
 }
 
@@ -1832,8 +1852,15 @@ ConnectionManager::Impl::findCertificate(
     if (auto cert = certStore().getCertificate(id.toString())) {
         if (cb)
             cb(cert);
-    } else if (cb)
-        cb(nullptr);
+    } else
+        dht()->findCertificate(id,
+                              [cb = std::move(cb), this](
+                                  const std::shared_ptr<dht::crypto::Certificate>& crt) {
+                                  if (crt)
+                                      certStore().pinCertificate(crt);
+                                  if (cb)
+                                      cb(crt);
+                              });
     return true;
 }
 
