@@ -1,7 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2024 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -53,7 +51,7 @@ class AccountModel;
 class CallParticipants;
 
 /**
- *  @brief Class that manages call informations.
+ *  @brief Class that manages call information.
  */
 class LIB_EXPORT CallModel : public QObject
 {
@@ -78,11 +76,9 @@ public:
      * Create a new call with a contact
      * @param  uri of the contact to call
      * @param  isAudioOnly, set to false by default
-     * @return the call uid created. Empty string is returned if call couldn't be created.
+     * @return the call uid created. Empty string is returned if call is unable to be created.
      */
-    QString createCall(const QString& uri,
-                       bool isAudioOnly = false,
-                       VectorMapStringString mediaList = {});
+    QString createCall(const QString& uri, bool isAudioOnly = false, VectorMapStringString mediaList = {});
     /**
      * Add a new media to the current list
      * @param callId
@@ -127,11 +123,8 @@ public:
      * @param mute
      * @param removeAll     Remove Audio/Video
      */
-    void removeMedia(const QString& callId,
-                     const QString& mediaType,
-                     const QString& type,
-                     bool muteCamera,
-                     bool removeAll);
+    void removeMedia(
+        const QString& callId, const QString& mediaType, const QString& type, bool muteCamera, bool removeAll);
 
     /**
      * Get the call from its call id
@@ -287,12 +280,12 @@ public:
     void setCurrentCall(const QString& callId) const;
 
     /**
-     * Update call mediaList to be used in the call answering
+     * Set whether the user's video media should be muted
      *
      * @param callId
-     * @param acceptVideo
+     * @param videoMuted
      */
-    void updateCallMediaList(const QString& callId, bool acceptVideo);
+    void setVideoMuted(const QString& callId, bool videoMuted);
 
     /**
      * Change the conference layout
@@ -307,11 +300,8 @@ public:
      * @param sinkId        Peer's sinkId
      * @param state         new state wanted
      */
-    void setActiveStream(const QString& confId,
-                         const QString& accountUri,
-                         const QString& deviceId,
-                         const QString& sinkId,
-                         bool state);
+    void setActiveStream(
+        const QString& confId, const QString& accountUri, const QString& deviceId, const QString& sinkId, bool state);
 
     /**
      * Check if a participant is a moderator or not
@@ -344,10 +334,7 @@ public:
      * @param deviceId      DeviceId of the participant to change
      * @param state         State of the change (true set hand raised / false unset hand raised)
      */
-    void raiseHand(const QString& confId,
-                   const QString& accountUri,
-                   const QString& deviceId,
-                   bool state);
+    void raiseHand(const QString& confId, const QString& accountUri, const QString& deviceId, bool state);
 
     /**
      * Mute/unmute sink
@@ -369,9 +356,7 @@ public:
      * @param accountUri    Uri of the participant to mute
      * @param deviceId      Device Id of the participant to mute
      */
-    void hangupParticipant(const QString& confId,
-                           const QString& accountUri,
-                           const QString& deviceId);
+    void hangupParticipant(const QString& confId, const QString& accountUri, const QString& deviceId);
 
     /**
      * Check if a call is a conference or not
@@ -387,7 +372,7 @@ public:
     const QList<call::PendingConferenceeInfo>& getPendingConferencees();
 
     /**
-     * Get informations on the rendered device
+     * Get information on the rendered device
      * @param call_id linked call to the renderer
      * @return the device rendered
      */
@@ -408,7 +393,7 @@ public:
      * @param windowProcessId
      * @param windowId
      */
-    QString getDisplay(const QString& windowProcessId, const QString& windowId);
+    QString getDisplay(const QString& windowProcessId, const QString& windowId, const int fps = -1);
 
     void emplaceConversationConference(const QString& callId);
 
@@ -448,7 +433,7 @@ Q_SIGNALS:
      * Emitted when a call state changes
      * @param callId
      */
-    void callStatusChanged(const QString& callId, int code) const;
+    void callStatusChanged(const QString& accountId, const QString& callId, int code) const;
     /**
      * Emitted when the rendered image changed
      * @param confId
@@ -480,9 +465,10 @@ Q_SIGNALS:
     /**
      * Emitted when a call is added to a conference
      * @param callId
+     * @param conversationId
      * @param confId
      */
-    void callAddedToConference(const QString& callId, const QString& confId) const;
+    void callAddedToConference(const QString& callId, const QString& conversationId, const QString& confId) const;
 
     /**
      * Emitted when a voice mail notice arrives
@@ -491,10 +477,7 @@ Q_SIGNALS:
      * @param oldCount
      * @param urgentCount
      */
-    void voiceMailNotify(const QString& accountId,
-                         int newCount,
-                         int oldCount,
-                         int urgentCount) const;
+    void voiceMailNotify(const QString& accountId, int newCount, int oldCount, int urgentCount) const;
 
     /**
      * Provides notification of a new set of recording peers once a change has occured,
