@@ -1,7 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2023 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -73,7 +71,7 @@ struct AccountConversation
 typedef QVector<QVector<AccountConversation>> ConferenceableValue;
 
 /**
- *  @brief Class that manages conversation informations.
+ *  @brief Class that manages conversation information.
  */
 class LIB_EXPORT ConversationModel : public QObject
 {
@@ -135,24 +133,22 @@ public:
      * @param  search name filter
      * @return filtered conversations
      */
-    QMap<ConferenceableItem, ConferenceableValue> getConferenceableConversations(
-        const QString& convId, const QString& filter = {}) const;
+    QMap<ConferenceableItem, ConferenceableValue> getConferenceableConversations(const QString& convId,
+                                                                                 const QString& filter = {}) const;
     /**
      * Get a custom filtered set of conversations
      * @return conversations filtered
      */
-    const ConversationQueueProxy& getFilteredConversations(
-        const FilterType& filter = FilterType::INVALID,
-        bool forceUpdate = false,
-        const bool includeBanned = false) const;
+    const ConversationQueueProxy& getFilteredConversations(const FilterType& filter = FilterType::INVALID,
+                                                           bool forceUpdate = false,
+                                                           const bool includeBanned = false) const;
     /**
      * Get a custom filtered set of conversations from profile type
      * @return conversations filtered
      */
-    const ConversationQueueProxy& getFilteredConversations(
-        const profile::Type& profileType = profile::Type::INVALID,
-        bool forceUpdate = false,
-        const bool includeBanned = false) const;
+    const ConversationQueueProxy& getFilteredConversations(const profile::Type& profileType = profile::Type::INVALID,
+                                                           bool forceUpdate = false,
+                                                           const bool includeBanned = false) const;
     /**
      * Get the conversation at row in the filtered conversations
      * @param  row
@@ -193,8 +189,9 @@ public:
      * Remove a conversation and the contact if it's a dialog
      * @param uid of the conversation
      * @param banned if we want to ban the contact.
+     * @param keepContact if we want to keep the contact. New conversation could be created
      */
-    void removeConversation(const QString& uid, bool banned = false);
+    void removeConversation(const QString& uid, bool banned = false, bool keepContact = false);
     /**
      * Get the action wanted by the user when they click on the conversation
      * @param uid of the conversation
@@ -210,11 +207,8 @@ public:
      * @param uid of the conversation
      */
     void placeAudioOnlyCall(const QString& uid);
-    void joinCall(const QString& uid,
-                  const QString& confId,
-                  const QString& uri,
-                  const QString& deviceId,
-                  bool isAudioOnly);
+    void joinCall(
+        const QString& uid, const QString& confId, const QString& uri, const QString& deviceId, bool isAudioOnly);
     /**
      * Send a message to the conversation
      * @param uid of the conversation
@@ -241,6 +235,7 @@ public:
      * @param filter the new filter
      */
     void setFilter(const QString& filter);
+    void setFilterString(const QString& filter);
     /**
      * Modify the current filter (will change the result of getFilteredConversations)
      * @param filter the new filter (example: SIP,  RING,  REQUEST)
@@ -258,12 +253,6 @@ public:
      * @param uid of the conversation
      */
     void clearHistory(const QString& uid);
-    /**
-     * change the status of the interaction from UNREAD to READ
-     * @param convId, id of the conversation
-     * @param msgId, id of the interaction
-     */
-    void setInteractionRead(const QString& convId, const QString& msgId);
     /**
      * Clears the unread text messages of a conversation
      * @param convId, uid of the conversation
@@ -273,36 +262,20 @@ public:
      * clear all history
      */
     void clearAllHistory();
-    /**
-     * Clear one interaction from the history
-     * @param convId
-     * @param interactionId
-     */
-    void clearInteractionFromConversation(const QString& convId, const QString& interactionId);
-    /**
-     * Clear the cache for interactions in the conversation
-     * @param convId
-     */
-    void clearInteractionsCache(const QString& convId);
     /**
      * @param convId
      * @param interactionId
      * @param participant uri
      * @return whether the interaction is last displayed for the conversation
      */
-    bool isLastDisplayed(const QString& convId,
-                         const QString& interactionId,
-                         const QString participant);
+    bool isLastDisplayed(const QString& convId, const QString& interactionId, const QString participant);
     /**
      * delete obsolete history from the database
      * @param days, number of days from today. Below this date, interactions will be deleted
      */
     void deleteObsoleteHistory(int date);
 
-    void sendFile(const QString& convUid,
-                  const QString& path,
-                  const QString& filename,
-                  const QString& parent);
+    void sendFile(const QString& convUid, const QString& path, const QString& filename, const QString& parent);
 
     void acceptTransfer(const QString& convUid, const QString& interactionId);
 
@@ -311,14 +284,12 @@ public:
     void getTransferInfo(const QString& conversationId,
                          const QString& interactionId,
                          api::datatransfer::Info& info) const;
+    void removeFile(const QString& conversationId, const QString& interactionId, const QString& path);
 
     /**
      * Starts a search of all medias in a conversation
      */
-    void getConvMediasInfos(const QString& accountId,
-                            const QString& conversationId,
-                            const QString& text,
-                            bool isMedia);
+    void getConvMediasInfos(const QString& accountId, const QString& conversationId, const QString& text, bool isMedia);
     /**
      * @param convUid, uid of the conversation
      * @return the number of unread messages for the conversation
@@ -337,7 +308,6 @@ public:
      * @return id for loading request. -1 if not loaded
      */
     int loadConversationMessages(const QString& conversationId, const int size = 1);
-    int loadConversationUntil(const QString& conversationId, const QString& to);
     /**
      * accept request for conversation
      * @param conversationId conversation's id
@@ -398,10 +368,7 @@ public:
      * @param uri
      * @param device
      */
-    void ignoreActiveCall(const QString& convId,
-                          const QString& id,
-                          const QString& uri,
-                          const QString& device);
+    void ignoreActiveCall(const QString& convId, const QString& id, const QString& uri, const QString& device);
 
     /**
      * @return if conversations requests exists.
@@ -415,6 +382,7 @@ public:
      * @return number of conversations requests + unread
      */
     int notificationsCount() const;
+    void reloadHistory() const;
     const VectorString peersForConversation(const QString& conversationId);
 
     // Presentation
@@ -454,9 +422,7 @@ Q_SIGNALS:
      * @param interactionId
      * @param interactionInfo
      */
-    void newInteraction(const QString& uid,
-                        QString& interactionId,
-                        const interaction::Info& interactionInfo) const;
+    void newInteraction(const QString& uid, QString& interactionId, const interaction::Info& interactionInfo) const;
     /**
      * Emitted when an interaction got removed from the conversation
      * @param convUid conversation which owns the interaction
@@ -477,7 +443,7 @@ Q_SIGNALS:
      * Emitted when a conversation detects an error
      * @param uid
      */
-    void onConversationErrorsUpdated(const QString& uid) const;
+    void conversationErrorsUpdated(const QString& uid) const;
     /**
      * Emitted when conversation's preferences has been updated
      * @param uid
@@ -523,20 +489,7 @@ Q_SIGNALS:
      * @param contactUri    contact's uri
      * @param isComposing   if contact is composing a message
      */
-    void composingStatusChanged(const QString& uid,
-                                const QString& contactUri,
-                                bool isComposing) const;
-    /**
-     * Emitted when last displayed interaction changed
-     * @param uid of conversation
-     * @param participant URI
-     * @param previousUid uid of a previous displayed interaction
-     * @param newdUid uid of a new displayed interaction
-     */
-    void displayedInteractionChanged(const QString& uid,
-                                     const QString& participantURI,
-                                     const QString& previousUid,
-                                     const QString& newdUid) const;
+    void composingStatusChanged(const QString& uid, const QString& contactUri, bool isComposing) const;
 
     /**
      * Emitted when search status changed
