@@ -1,6 +1,5 @@
 /*!
- *    Copyright (C) 2018-2023 Savoir-faire Linux Inc.
- *   Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
+ *   Copyright (C) 2018-2025 Savoir-faire Linux Inc.
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -136,9 +135,7 @@ public:
     /**
      * Toggle media handler
      */
-    Q_INVOKABLE void toggleCallMediaHandler(const QString& mediaHandlerId,
-                                            const QString& callId,
-                                            bool toggle);
+    Q_INVOKABLE void toggleCallMediaHandler(const QString& mediaHandlerId, const QString& callId, bool toggle);
 
     VectorString getChatHandlers() const;
 
@@ -170,8 +167,7 @@ public:
      * Get preferences map of installed plugin
      * @return Plugin preferences infos vector
      */
-    Q_INVOKABLE VectorMapStringString getPluginPreferences(const QString& path,
-                                                           const QString& accountId);
+    Q_INVOKABLE VectorMapStringString getPluginPreferences(const QString& path, const QString& accountId);
 
     /**
      * Modify preference of installed plugin
