@@ -53,25 +53,30 @@ SecureDht::SecureDht(std::unique_ptr<DhtInterface> dht, SecureDht::Config conf,
         auto certLongId = certificate_->getLongId();
         if (key_ and (certId != key_->getPublicKey().getId() or certLongId != key_->getPublicKey().getLongId()))
             throw DhtException("SecureDht: provided certificate doesn't match private key.");
-        dht_->addOnConnectedCallback([this, certId, certLongId, cb=std::move(iacb)]{
+
+        auto cb = iacb ? [
+            this,
+            completedState = std::make_shared<std::pair<unsigned,bool>>(2, true),
+            iacb = std::move(iacb)
+        ](bool ok) {
+            if (logger_)
+                logger_->d("SecureDht: certificate announcement %s", ok ? "succeeded" : "failed");
+            completedState->second = completedState->second and ok;
+            if (--completedState->first == 0)
+                iacb(completedState->second);
+        } : iacb;
+
+        dht_->addOnConnectedCallback([this, certId, certLongId, cb=std::move(cb)]{
             dht_->put(certId, Value {
                 CERTIFICATE_TYPE,
                 *certificate_,
                 1
-            }, [this, certId, cb=std::move(cb)](bool ok) {
-                if (cb) cb(ok);
-                if (logger_)
-                    logger_->d(certId, "SecureDht: certificate announcement %s", ok ? "succeeded" : "failed");
-            }, {}, true);
+            }, cb, {}, true);
             dht_->put(InfoHash::get(certLongId), Value {
                 CERTIFICATE_TYPE,
                 *certificate_,
                 1
-            }, [this, cb=std::move(cb)](bool ok) {
-                if (cb) cb(ok);
-                if (logger_)
-                    logger_->debug("SecureDht: certificate announcement {}", ok ? "succeeded" : "failed");
-            }, {}, true);
+            }, cb, {}, true);
         });
     }
 }
@@ -93,7 +98,7 @@ SecureDht::secureType(ValueType&& type)
             return type.editPolicy(id, o, n, nid, a);
         if (*o->owner != *n->owner or not n->isSigned()) {
             if (logger_)
-                logger_->w("Edition forbidden: not signed or wrong owner.");
+                logger_->w("Edition forbidden: not signed or incorrect owner.");
             return false;
         }
         if (not n->checkSignature()) {
@@ -228,12 +233,13 @@ SecureDht::findCertificate(const InfoHash& node, const std::function<void(const
             cb(b);
         return;
     }
-    if (localQueryMethod_) {
-        auto res = localQueryMethod_(node);
+    if (localQueryMethodLegacy_) {
+        auto res = localQueryMethodLegacy_(node);
         if (not res.empty()) {
             if (logger_)
                 logger_->d("Registering certificate from local store for %s", node.to_c_str());
             nodesCertificates_.emplace(node, res.front());
+            nodesCertificatesLong_.emplace(res.front()->getLongId(), res.front());
             if (cb)
                 cb(res.front());
             return;
@@ -296,6 +302,19 @@ SecureDht::findCertificate(const PkId& node, const std::function<void(const Sp<c
         return;
     }
 
+    if (localQueryMethod_) {
+        auto res = localQueryMethod_(node);
+        if (not res.empty()) {
+            if (logger_)
+                logger_->debug("Registering certificate from local store for {}", node.to_c_str());
+            nodesCertificates_.emplace(res.front()->getId(), res.front());
+            nodesCertificatesLong_.emplace(node, res.front());
+            if (cb)
+                cb(res.front());
+            return;
+        }
+    }
+
     auto found = std::make_shared<bool>(false);
     dht_->get(InfoHash::get(node), [cb,node,found,this](const std::vector<Sp<Value>>& vals) {
         for (const auto& v : vals) {
