@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -240,8 +240,11 @@ CertificateStore::findIssuer(const std::shared_ptr<crypto::Certificate>& crt) co
             logger_->warn("gnutls_x509_crt_verify failed: {:s}", gnutls_strerror(err));
         return {};
     }
-    if (verify_out & GNUTLS_CERT_INVALID)
+    if (verify_out & GNUTLS_CERT_INVALID) {
+        if (logger_)
+            logger_->warn("gnutls_x509_crt_verify failed: invalid certificate");
         return {};
+    }
     return ret;
 }
 
@@ -268,7 +271,7 @@ readCertificates(const std::filesystem::path& path, const std::string& crl_path)
                 ret.emplace_back(certs[i]);
             gnutls_free(certs);
         } catch (const std::exception& e) {
-        };
+        }
     }
     return ret;
 }
@@ -277,7 +280,7 @@ void
 CertificateStore::pinCertificatePath(const std::string& path,
                                      std::function<void(const std::vector<std::string>&)> cb)
 {
-    dht::ThreadPool::computation().run([&, path, cb]() {
+    dht::ThreadPool::computation().run([&, path, cb=std::move(cb)]() {
         auto certs = readCertificates(path, crlPath_.string());
         std::vector<std::string> ids;
         std::vector<std::weak_ptr<crypto::Certificate>> scerts;
@@ -332,7 +335,7 @@ CertificateStore::pinCertificate(const std::vector<uint8_t>& cert, bool local) n
 {
     try {
         return pinCertificate(crypto::Certificate(cert), local);
-    } catch (const std::exception& e) {
+    } catch (...) {
     }
     return {};
 }
@@ -346,17 +349,17 @@ CertificateStore::pinCertificate(crypto::Certificate&& cert, bool local)
 std::vector<std::string>
 CertificateStore::pinCertificate(const std::shared_ptr<crypto::Certificate>& cert, bool local)
 {
+    if (!cert)
+        return {};
     bool sig {false};
     std::vector<std::string> ids {};
     {
         auto c = cert;
         std::lock_guard l(lock_);
         while (c) {
-            bool inserted;
             auto id = c->getId().toString();
             auto longId = c->getLongId().toString();
-            decltype(certs_)::iterator it;
-            std::tie(it, inserted) = certs_.emplace(id, c);
+            auto [it, inserted] = certs_.emplace(id, c);
             if (not inserted)
                 it->second = c;
             std::tie(it, inserted) = certs_.emplace(longId, c);
@@ -469,11 +472,11 @@ CertificateStore::pinOcspResponse(const dht::crypto::Certificate& cert)
     }
 
     dht::ThreadPool::io().run([l=logger_,
-                               path = dir / serialhex,
                                dir = std::move(dir),
                                id = std::move(id),
                                serialhex = std::move(serialhex),
                                ocspResponse = cert.ocspResponse] {
+        auto path = dir / serialhex;
         if (l) l->d("Saving OCSP Response of device %s with serial %s", id.c_str(), serialhex.c_str());
         std::lock_guard lock(fileutils::getFileLock(path));
         fileutils::check_dir(dir.c_str());
